@@ -17,12 +17,12 @@
 #      along with this program.
 #
 #  File: check.tcl
-#  Last change:  4 February 2002
+#  Last change:  22 October 2002
 #
 
 proc CheckName {errproc name} {
     # check length and characters of name; call $errproc on error
-    global NAMELENGTH NOLOWERCASE MYGPS RECNAMECHARS MESS
+    global ACCEPTALLCHARS NAMELENGTH NOLOWERCASE MYGPS RECNAMECHARS MESS
 
     set n [string length $name]
     if { $n > $NAMELENGTH } {
@@ -33,6 +33,7 @@ proc CheckName {errproc name} {
 	$errproc $MESS(namevoid)
 	return 0
     }
+    if { $ACCEPTALLCHARS } { return 1 }
     if { ! $NOLOWERCASE } {
 	set name [string toupper $name]
     }
@@ -69,6 +70,7 @@ proc CheckConvDate {string} {
     if { $n > 1 } {
 	# there are "-"s
 	if { $n == 3 } {
+	    # YYYY-MM-DD HH:MM:SS
 	    set d [string trimleft [lindex $l 0] 0] ; set s 0
 	    if { [set m [Month [lindex $l 1]]] } {
 		set n [scan [lindex $l 2] "%d %d:%d:%d" y h mn s]
@@ -77,12 +79,21 @@ proc CheckConvDate {string} {
 			         [DateToSecs $y $m $d $h $mn $s]]
 		}
 	    }
+	} elseif { $n == 2 } {
+	    # YYYY/MM/DD-HH:MM:SS
+	    set n [scan [lindex $l 0] "%d/%d/%d" y m d]
+	    incr n [scan [lindex $l 1] "%d:%d:%d" h mn s]
+	    if { $n == 6 && [CheckDateEls $y $m $d $h $mn $s] } {
+		return [list [FormatDate $DateFormat $y $m $d $h $mn $s] \
+			        [DateToSecs $y $m $d $h $mn $s]]
+	    }
 	}
     } else {
 	set l [split $string /] ; set n [llength $l]
 	if { $n > 1 } {
 	    # there are "/"s
 	    if { $n == 3 } {
+		# MM/DD/YYYY HH:MM:SS
 		set m [string trimleft [lindex $l 0] 0] ; set s 0
 		set d [string trimleft [lindex $l 1] 0]
 		set n [scan [lindex $l 2] "%d %d:%d:%d" y h mn s]
@@ -96,6 +107,7 @@ proc CheckConvDate {string} {
 	    set l [split $string .] ; set n [llength $l]
 	    if { $n > 1 } {
 		if { $n == 3 } {
+		    # YYYY.MM.DD HH:MM:SS
 		    set y [string trimleft [lindex $l 0] 0] ; set s 0
 		    set m [string trimleft [lindex $l 1] 0]
 		    set n [scan [lindex $l 2] "%d %d:%d:%d" d h mn s]
@@ -212,8 +224,9 @@ proc CheckComment {errproc comm} {
 
 proc CheckChars {errproc string} {
     # check characters in comment string; call $errproc on error
-    global NOLOWERCASE MESS
+    global ACCEPTALLCHARS NOLOWERCASE MESS
 
+    if { $ACCEPTALLCHARS } { return 1 }
     if { ! $NOLOWERCASE || [regexp {^[-A-Z0-9 -]*$} $string] } {
 	return 1
     }
@@ -299,6 +312,13 @@ proc BadAltitude {a} {
     return 1
 }
 
+proc BadWidth {w} {
+    # check value for line width
+
+    if { [regexp {^[1-9][0-9]?$} $w] } { return 0 }
+    return 1
+}
+
 proc BadParam {name type value} {
     # check $value for numeric parameter of definition $name
     #  $type as used in MAPPROJDTYPE array (projections.tcl)
