@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2001 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2003 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,10 @@
 #      along with this program.
 #
 #  File: compute.tcl
-#  Last change:  14 November 2001
+#  Last change:  21 January 2003
+#
+# Includes contributions by Matt Martin (matt.martin@ieee.org)
+#  marked "MGM contribution"
 #
 
 ## Some formulae kindly supplied by
@@ -34,6 +37,7 @@
 ### positions and coordinates
 
 proc PosType {pformt} {
+    global ZGRID
 
     switch $pformt {
 	DMS -
@@ -41,8 +45,11 @@ proc PosType {pformt} {
 	DDD     { return latlong }
 	UTM/UPS { return utm }
 	MH      { return mh }
-	default { return grid }
     }
+    if { $ZGRID($pformt) } {
+	return grid
+    }
+    return nzgrid
 }
 
 proc Coord {pformt coord negh} {
@@ -80,8 +87,8 @@ proc CreatePos {latd longd pformt type datum} {
     #  $type==latlong: lat and long in external format
     #  $type==utm: zones east and north and x y coordinates
     #  $type==grid: zone name and x y coordinates
+    #  $type==nzgrid: x y coordinates
     #  $type==mh: Maidenhead-locator (6 characters)
-    global ZGRID
 
     switch $type {
 	latlong {
@@ -103,11 +110,11 @@ proc CreatePos {latd longd pformt type datum} {
 	    return [linsert $p 0 $latd $longd]
 	}
 	grid {
-	    if { $ZGRID($pformt) } {
-		set p [DegreesTo$pformt $latd $longd $datum]
-	    } else {
-		set p [DegreesToNZGrid $pformt $latd $longd $datum]
-	    }
+	    set p [DegreesTo$pformt $latd $longd $datum]
+	    return [linsert $p 0 $latd $longd]
+	}
+	nzgrid {
+	    set p [DegreesToNZGrid $pformt $latd $longd $datum]
 	    return [linsert $p 0 $latd $longd]
 	}
 	mh {
@@ -182,6 +189,42 @@ proc ComputeDist {p1 p2 datum} {
 	         acos(cos($lo1-$lo2)*cos($la1)*cos($la2)+sin($la1)*sin($la2))]
 }
 
+proc ComputeBear {p1 p2 datum} {
+    # bearing from position $p1 to $p2 with same datum
+    #  $datum not used here but kept for compatibility with replacement
+    #    proc in acccomp.tcl
+            # formulae kindly supplied by Luisa Bastos, Universidade do Porto
+            #   and Gil Goncalves, Universidade de Coimbra
+
+    set lad1 [lindex $p1 0] ; set lod1 [lindex $p1 1]
+    set lad2 [lindex $p2 0] ; set lod2 [lindex $p2 1]
+    if { $lad1==$lad2 && $lod1==$lod2 } { return 0 }
+    set la1 [expr $lad1*0.01745329251994329576]
+    set lo1 [expr $lod1*0.01745329251994329576]
+    set la2 [expr $lad2*0.01745329251994329576]
+    set lo2 [expr $lod2*0.01745329251994329576]
+    set da [expr $la2-$la1] ; set do [expr $lo2-$lo1]
+    if { [expr abs($da)] < 1e-20 } {
+ 	if { [expr abs($do)] < 1e-20 } {
+ 	    set b 0
+ 	} elseif { $do < 0 } {
+ 	    set b 270
+ 	} else { set b 90 }
+    } elseif { [expr abs($do)] < 1e-20 } {
+ 	if { $da < 0 } {
+ 	    set b 180
+ 	} else { set b 0 }
+    } else {
+ 	set b [expr round(atan2(sin($do), \
+ 		                tan($la2)*cos($la1)-sin($la1)*cos($do)) \
+ 			  *57.29577951308232087684)]
+	if { $b < 0 } {
+	    if { $do < 0 } { incr b 360 } else { incr b 180 }
+	} elseif { $do < 0 } { incr b 180 }
+    }
+    return $b
+}    
+
 proc ComputeDistBear {p1 p2 datum} {
     # distance between and bearing from positions $p1 and $p2 with same datum
             # formulae kindly supplied by Luisa Bastos, Universidade do Porto
@@ -212,8 +255,8 @@ proc ComputeDistBear {p1 p2 datum} {
  	    set b 180
  	} else { set b 0 }
     } else {
- 	set b [expr round(atan(sin($do)/ \
- 		               (tan($la2)*cos($la1)-sin($la1)*cos($do))) \
+ 	set b [expr round(atan2(sin($do), \
+ 		                tan($la2)*cos($la1)-sin($la1)*cos($do)) \
  			  *57.29577951308232087684)]
 	if { $b < 0 } {
 	    if { $do < 0 } { incr b 360 } else { incr b 180 }
@@ -283,8 +326,8 @@ proc ComputeDistBearFD {p1 p2} {
  	    set b 180
  	} else { set b 0 }
     } else {
- 	set b [expr round(atan(sin($do)/ \
- 		               (tan($la2)*cos($la1)-sin($la1)*cos($do))) \
+ 	set b [expr round(atan2(sin($do), \
+ 		                tan($la2)*cos($la1)-sin($la1)*cos($do)) \
  			  *57.29577951308232087684)]
 	if { $b < 0 } {
 	    if { $do < 0 } { incr b 360 } else { incr b 180 }
@@ -460,21 +503,44 @@ proc Today {dformt} {
     return [FormatDate $dformt $y $m $d $h $mn $s]
 }
 
+proc FormatDay {dformt y m d} {
+    # build representation of date (without time of day) under format $dformt
+    # (see proc FormatDate for date with time of day)
+    #  $dformt in
+    #   {YYYYMMDD, YYYY-MM-DD, MMDDYYYY, DDMMMYYYY, YYYY/MM/DD}
+    # changes in proc FormatDate are likely to affect this proc!
+
+    set cdate [FormatDate $dformt $y $m $d 0 0 0]
+    if { "$dformt" == "YYYY/MM/DD" } {
+	return [string range $cdate 0 9]
+    }
+    return [lindex $cdate 0]
+}
+
 proc FormatDate {dformt y m d h mn s} {
-    # build representation of date under format $dformt
-    #  $dformt in {YYYYMMDD, MMDDYYYY, DDMMMYYYY}
-    # result assumed elsewhere to be a list whose head is the information on
-    #  year, month and day
+    # build representation of date (including time of day) under format $dformt
+    # (see proc FormatDay for date without time of day)
+    #  $dformt either in
+    #   {YYYYMMDD, YYYY-MM-DD, MMDDYYYY, DDMMMYYYY, YYYY/MM/DD}
+    #   or DDMMYY in which case the date will have no time of day
+    # changes here must be reflected in proc FormatDay
+    # when adding new formats here, array DATEW must be updated in main.tcl
     global MONTHNAMES
 
     set h [format "%02d:%02d:%02d" $h $mn $s]
     switch $dformt {
-	YYYYMMDD { return [format "%4d.%02d.%02d %s" $y $m $d $h] }
+	DDMMYY {
+	    # MGM contribution
+	    return [format "%02d%02d%02d" $d $m [expr $y % 100]]
+	}
+    	YYYYMMDD { return [format "%4d.%02d.%02d %s" $y $m $d $h] }
+	YYYY-MM-DD { return [format "%4d-%02d-%02d %s" $y $m $d $h] }
 	MMDDYYYY { return [format "%02d/%02d/%4d %s" $m $d $y $h] }
 	DDMMMYYYY {
 	    incr m -1 ; set m [lindex $MONTHNAMES $m]
 	    return [format "%02d-%s-%4d %s" $d $m $y $h]
 	}
+	YYYY/MM/DD { return [format "%4d/%02d/%02d-%s" $y $m $d $h] }
     }
 }
 
@@ -508,10 +574,17 @@ set DAYSOF(9) 30 ; set DAYSOF(10) 31 ; set DAYSOF(11) 30 ; set DAYSOF(12) 31
 
 proc DateToSecs {y m d h mn s} {
     # convert date to seconds ellapsed since beginning of $YEAR0 (a leap year)
-    global DAYSOF YEAR0
+    global YEAR0
 
-    set days [expr 365*($y-$YEAR0)+$d-1]
-    set yy $YEAR0
+    return [DateToSecsFrom $y $m $d $h $mn $s $YEAR0]
+}
+
+proc DateToSecsFrom {y m d h mn s year0} {
+    # convert date to seconds ellapsed since beginning of $year0 (a leap year)
+    global DAYSOF
+
+    set days [expr 365*($y-$year0)+$d-1]
+    set yy $year0
     while { $yy < $y } {
 	if { $yy%100!=0 || $yy%400==0 } { incr days }
 	incr yy 4
@@ -527,7 +600,38 @@ proc DateFromSecs {secs} {
     #  using default format
     global DateFormat
 
-    return [DateFromSecsFmt $secs $DateFormat]
+    return [eval FormatDate $DateFormat [DateIntsFromSecs $secs]]
+}
+
+proc DateIntsFromSecs {secs} {
+    # compute date from seconds ellapsed since beginning of $YEAR0
+    #  (a leap year)
+    # return list with year, month, day, hour, minutes, seconds as integers
+    global DAYSOF YEAR0
+
+    set s [expr $secs%60] ; set x [expr ($secs-$s)/60]
+    set mn [expr $x%60] ; set x [expr ($x-$mn)/60]
+    set h [expr $x%24] ; set x [expr ($x-$h)/24]
+    set y [expr int($x/365)] ; set yd [expr $y*365]
+    set yy $YEAR0 ; incr y $yy
+    while { $yy < $y } {
+	if { $yy%100!=0 || $yy%400==0 } { incr yd }
+	incr yy 4
+    }
+    if { $yd > $x } {
+	incr y -1
+	if { $y%4==0 && ($y%100!=0 || $y%400==0) } { incr yd -1 }
+	incr yd -365
+    }
+    incr x [expr 1-$yd] ; set m 1
+    while { $x > $DAYSOF($m) } {
+	if { $m==2 && $y%4==0 && ($y%100!=0 || $y%400==0) } {
+	    if { $x == 29 } { break }
+	    incr x -1
+	}
+	incr x -$DAYSOF($m) ; incr m
+    }
+    return [list $y $m $x $h $mn $s]
 }
 
 proc DateFromSecsFmt {secs fmt} {
@@ -614,8 +718,22 @@ proc CompatibleDates {y0 m0 d0 secs1} {
     #  $secs1 is the other date in seconds since $YEAR0
     # return 1 if compatible
 
-    set dt1 [lindex [DateFromSecsFmt $secs1 DDMMMYYYY] 0]
-    if { "$d0" != "*" && $d0<10 } { set d0 0$d0 }
-    if { [string match $d0-$m0-$y0 $dt1] } { return 1 }
+    foreach "y1 m1 d1 h1 mn1 s1" [DateIntsFromSecs $secs1] {}
+    if { [string match $d0-$m0-$y0 $d1-$m1-$y1] } { return 1 }
     return 0
 }
+
+### varia
+
+proc VectorBearing {vx vy} {
+    # compute bearing (angle from y-axis clockwise, in 0..359) of vector
+    #  with given components
+    # return "_" if components are too small
+
+    if { abs($vy)+abs($vx) > 1e-20 } {
+	set b [expr round(atan2($vx,$vy)*57.29577951308232087684)]
+	if { $b < 0 } { incr b 360 }
+    } else { set b "_" }
+    return $b
+}
+
