@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2001 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2003 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: garmin_protocols.tcl
-#  Last change:  26 October 2001
+#  Last change:  14 March 2003
 #
 
 # description of Garmin protocols based on Garmin GPS Interface
@@ -52,7 +52,6 @@ array set PROTCAT {
     A600  DtTm
     A700  Posn
     A800  PVT
-    A900  undef
 }
 
    # protocol requirements
@@ -111,9 +110,20 @@ array set PDTSIZE {
 }
 
     # protocol data types
+
+      # data type for ACK/NAK packet; this is now set in proc FixACKNAKType
+      #  when the first such packet is received
+      # sending 16-bit int according to Garmin specifications versions < 3
+      #  but accepting either int or byte as in versions <= 3
+set PDTYPE(ACK) union=int,byte
+set PDTYPE(NAK) union=int,byte
+
+      # sending byte according to Garmin specifications version 3
+      #  and accepting either int or byte as in versions <= 3
+# set PDTYPE(ACK) union=byte,int
+# set PDTYPE(NAK) union=byte,int
+
 array set PDTYPE {
-    ACK  union=byte,int
-    NAK  union=byte,int
     PArray  starray=char,word
     PrdReq  ignored
     PrdData  {int int string ignored}
@@ -128,6 +138,8 @@ array set PDTYPE {
     D107  {charray=6 semicircle unused=4 charray=40 byte byte float byte}
     D108  {byte byte byte byte int bytes=18 semicircle float float float
            charray=2 charray=2 string string string string string string}
+    D109  {byte byte byte byte int bytes=18 semicircle float float float
+           charray=2 charray=2 long string string string string string string}
     D150  {charray=6 charray=2 byte semicircle int charray=24 charray=2
 	   charray=30 charray=40}
     D151  {charray=6 semicircle unused=4 charray=40 float charray=30
@@ -156,6 +168,9 @@ array set PDTYPE {
            int long}
 }
 
+## RT Header protocols with a numeric identifier
+set PRTNUMID {D200 D201}
+
     # product identifiers; new entries should also be added to recmodels.tcl
     #  numbers followed by a letter are defined here to support older
     #  software versions; not following Garmin specs in this
@@ -213,11 +228,17 @@ array set PRODID {
     "GPS III Plus" 119
     "GPSMAP 295" 128
     eTrex  130
+    "GPS 12 4.58" 138
     "eTrex Summit"  141
+    "GPSMAP 196" 145
     "eTrex Venture/Mariner"  154
     "eTrex Euro"  156
-    "eTrek Vista" 169
-    "eTrek Legend" 179
+    "eTrex Vista" 169
+    "GPS 76" 173
+    "GPSMAP 76" 177
+    "eTrex Legend" 179
+    "GPSMAP 76S" 194
+    "GPS 72" 247
 }
 
     # product names and how to obain its product specific protocols
@@ -277,11 +298,17 @@ array set PNAME {
     116  "GPS 12CX"
     128  "GPSMAP 295"
     130  eTrex
+    138  "GPS 12"
     141  "eTrex Summit"
+    145  "GPSMAP 196"
     154  "eTrex Venture/Mariner"
     156  "eTrex Euro"
     169  "eTrex Vista"
+    173  "GPS 76"
+    177  "GPSMAP 76"
     179  "eTrex Legend"
+    194  "GPSMAP 76S"
+    247  "GPS 72"
 }
 
 # the descriptions below are valid for all versions except:
@@ -289,6 +316,17 @@ array set PNAME {
 #  36 version >= 3.0; for older versions see=22
 #  77 version >= 3.61; may work for some older versions
 #  77a defined for 77 version < 3.01
+#  111 version <= 2.7
+#  111a version > 2.7
+
+      # the pairs in the following entries have a comparison to be made
+      #  to the receiver version and the identifier to be used if the
+      #  comparison succeeds
+array set PRTCLVERSION {
+    36  {{{< 300} 22}}
+    77  {{{< 301} 77a}}
+    111 {{{> 270} 111a}}
+}
 
 array set PRTCLDEF {
     13  diff
@@ -333,15 +371,22 @@ array set PRTCLDEF {
     105  see=77
     106  see=77
     111  array
+    111a diff
     116  array
     119  array
     128  see=111
     130  diff
+    138  see=77
     141  see=130
+    145  array
     154  see=130
     156  see=130
     169  see=130
+    173  see=177
+    177  array
     179  see=130
+    194  see=177
+    247  see=116
 }
 
 ### there is no information on which receivers use the PVT protocol
@@ -427,6 +472,52 @@ array set PSPID {
     119,PosnData  D700
     119,PVT  A800
     119,PVTData D800
+
+    145,Link  L001
+    145,DevCmd  A010
+    145,WP  A100
+    145,WPData  D109
+    145,RT  A201
+    145,RTHeader  D202
+    145,RTWPData  D109
+    145,RTLinkData  D210
+    145,TR  A301
+    145,TRHeader  D310
+    145,TRData  D301
+    145,Prx  A400
+    145,PrxWPData  D109
+    145,AL  A500
+    145,ALData  D501
+    145,DtTm  A600
+    145,DtTmData  D600
+    145,Posn  A700
+    145,PosnData  D700
+    145,PVT  A800
+    145,PVTData  D800
+    145,unknown  A650+D650+A900+A901+D901+A902+A903+A904
+
+    177,Link  L001
+    177,DevCmd  A010
+    177,WP  A100
+    177,WPData  D109
+    177,RT  A201
+    177,RTHeader  D202
+    177,RTWPData  D109
+    177,RTLinkData  D210
+    177,TR  A301
+    177,TRHeader  D310
+    177,TRData  D301
+    177,Prx  A400
+    177,PrxWPData D109
+    177,AL  A500
+    177,ALData  D501
+    177,DtTm  A600
+    177,DtTmData  D600
+    177,Posn  A700
+    177,PosnData  D700
+    177,PVT  A800
+    177,PVTData D800
+    177,unknow A900+A902+A903
 }
 
           # must not differ on the Link and DevCmd protocols
@@ -448,6 +539,7 @@ array set PSDIFF {
     77  {73 {Prx A400} {PrxData D403}}
     77a {59 {ALData D501}}
     130 {111 {RTHeader D202}}
+    111a {111 {WPData D109} {RTWPData D109} {PrxWPData D109}}
 }
 
 ## descriptions, positions in Garmin structures of GPSMan data
@@ -480,6 +572,9 @@ array set DATAFOR {
     D108,ns {DispOpt Symbol Posn Alt Name Commt}
     D108,ps {2 4 6 7 12 13}
 
+    D109,ns {DispOpt Symbol Posn Alt Name Commt}
+    D109,ps {2 4 6 7 13 14}
+
     D150,ns {Name Posn Alt Commt}
     D150,ps {0 3 4 8}
 
@@ -496,8 +591,10 @@ array set DATAFOR {
     D155,ps {0 1 3 8 12 13}
 }
 
-## descriptions, types, default values, positions in Garmin structures, and
-#   constraints of hidden attributes
+## hidden attributes:
+#   names, types, default values, positions in Garmin structures,
+#   constraints of hidden attributes and (possibly) preprocessing info
+#   and formatting info (see proc HiddenFormatVal)
 
  # positions must be in increasing order!
  # constraints assume that all attributes have been assigned to variables
@@ -509,12 +606,14 @@ array set HIDDENFOR {
     D106,vs {0 0 ""}
     D106,ps {0 1 5}
     D106,cs { { if { $class==0 } { lappend undef subclass } } }
+    D106,fm {{class enumd {user non_user}}}
 
     D107,ns {colour}
     D107,ts {byte}
     D107,vs {0}
     D107,ps {7}
     D107,cs {}
+    D107,fm {{colour enum {default red green blue}}}
 
     D108,ns {class colour attrs subclass depth state country facility
     city addr int_road}
@@ -530,6 +629,42 @@ array set HIDDENFOR {
 	{ if { $class!=0x83 } { lappend undef addr } }
 	{ if { $class!=0x82 } { lappend undef int_road } }
     }
+    D108,fm {{class envals {{0 user} {0x40 avn_airport} {0x41 avn_inters}
+                            {0x42 avn_NDB} {0x43 avn_VOR}
+			    {0x44 avn_airp_rway} {0x45 avn_airp_int}
+			    {0x46 avn_airp_NDB} {0x80 map_pt}
+			    {0x81 map_area} {0x82 map_int}
+			    {0x83 map_addr} {0x84 map_label}
+			    {0x85 map_line}}}
+	     {colour enumd {black dark_red dark_green dark_yellow dark_blue
+			    dark_magenta dark_cyan light_gray dark_gray
+			    red green yellow blue magenta cyan white default}}}
+
+    D109,ns {dtyp class colour attrs subclass depth state country ete facility
+    city addr int_road}
+    D109,ts {byte byte byte byte bytes=18 float charray=2 charray=2
+    long string string string string}
+    D109,vs {1 255 0x1f 0x70
+    "0 0 0 0 0 0 255 255 255 255 255 255 255 255 255 255 255 255"
+    1.0e25 "" "" 0xffffffff "" "" "" ""}
+    D109,ps {0 1 2 3 5 8 10 11 12 15 16 17 18}
+    D109,cs {
+	{ if { $class==0 || $class>0x46 } { lappend undef city facility } }
+	{ if { $class<0x80 } { lappend undef subclass } }
+	{ if { $class!=0x83 } { lappend undef addr } }
+	{ if { $class!=0x82 } { lappend undef int_road } }
+    }
+    D109,pp {{colour &0x1f}}
+    D109,fm {{class envals {{0 user} {0x40 avn_airport} {0x41 avn_inters}
+                            {0x42 avn_NDB} {0x43 avn_VOR}
+			    {0x44 avn_airp_rway} {0x45 avn_airp_int}
+			    {0x46 avn_airp_NDB} {0x80 map_pt}
+			    {0x81 map_area} {0x82 map_int}
+			    {0x83 map_addr} {0x84 map_label}
+			    {0x85 map_line}}}
+	     {colour enumd {black dark_red dark_green dark_yellow dark_blue
+			    dark_magenta dark_cyan light_gray dark_gray
+			    red green yellow blue magenta cyan white default}}}
 
     D150,ns {country class city state facility}
     D150,ts {charray=2 byte charray=24 charray=2 charray=30}
@@ -538,6 +673,8 @@ array set HIDDENFOR {
     D150,cs {
 	{ if { $class==4 } { lappend undef city state country facility } }
     }
+    D150,fm {{class enum {avn_airport avn_inters avn_NDB avn_VOR user
+                          avn_airp_rway avn_airp_int locked}}}
 
     D151,ns {facility city state country class}
     D151,ts {charray=30 charray=24 charray=2 charray=2 byte}
@@ -546,6 +683,7 @@ array set HIDDENFOR {
     D151,cs {
 	{ if { $class==2 } { lappend undef city state country facility } }
     }
+    D151,fm {{class enum {avn_airport avn_VOR user locked}}}
 
     D152,ns {facility city state country class}
     D152,ts {charray=30 charray=24 charray=2 charray=2 byte}
@@ -554,6 +692,7 @@ array set HIDDENFOR {
     D152,cs {
 	{ if { $class==4 } { lappend undef city state country facility } }
     }
+    D152,fm {{class enum {avn_airport avn_inters avn_NDB avn_VOR user locked}}}
 
     D154,ns {facility city state country class}
     D154,ts {charray=30 charray=24 charray=2 charray=2 byte}
@@ -562,6 +701,9 @@ array set HIDDENFOR {
     D154,cs {
 	{ if { $class==4 } { lappend undef city state country facility } }
     }
+    D154,fm {{class enum {avn_airport avn_inters avn_NDB avn_VOR user
+                          avn_airp_rway avn_airp_int avn_airp_NDB user_symbol
+                          locked}}}
 
     D155,ns {facility city state country class}
     D155,ts {charray=30 charray=24 charray=2 charray=2 byte}
@@ -570,6 +712,7 @@ array set HIDDENFOR {
     D155,cs {
 	{ if { $class==4 } { lappend undef city state country facility } }
     }
+    D155,fm {{class enum {avn_airport avn_inters avn_NDB avn_VOR user locked}}}
 
     D210,ns {class subclass}
     D210,ts {word bytes=18}
@@ -578,12 +721,17 @@ array set HIDDENFOR {
     D210,cs {
 	{ if { $class==3 || $class==0xff } { lappend undef subclass } }
     }
+    D210,fm {{class enum {line link net direct snap}}}
 
     D310,ns {colour display}
     D310,ts {byte boolean}
     D310,vs {255 0}
     D310,ps {0 1}
     D310,cs {}
+    D310,fm {{colour enumd {black dark_red dark_green dark_yellow dark_blue
+			    dark_magenta dark_cyan light_gray dark_gray
+                            red green yellow blue magenta cyan white default}}
+	     {display enumd {no  yes}}}
 }
 
 ### PVT status for D800
