@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2001 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2003 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -16,11 +16,12 @@
 #      You should have received a copy of the GNU General Public License
 #      along with this program.
 #
-#  File: gendials.c
-#  Last change:  5 December 2001
+#  File: gendials.tcl
+#  Last change:  6 February 2003
 #
-# Includes contributions by Brian Baulch (baulchb@onthenet.com.au)
-#  marked "BSB contribution"
+# Includes contributions by
+#  - Brian Baulch (baulchb@onthenet.com.au) marked "BSB contribution"
+#  - Stefan Heinen (stefan.heinen@djh-freeweb.de) marked "SH contribution"
 #
 
   # modal dialogs
@@ -28,13 +29,22 @@
 proc GMMessage {mess} {
     # create modal dialog for displaying message
     #  single button: OK; binding: return
-    global COLOUR EPOSX EPOSY TXT
+    global COLOUR EPOSX EPOSY TXT UNIX CMDLINE
 
+    if { $CMDLINE} {
+	puts stderr $mess
+	return
+    }
     set wait 1
     destroy .mess
     toplevel .mess
+    if { ! $UNIX } {
+	# SH contribution
+	focus .mess
+    }
+
     wm protocol .mess WM_DELETE_WINDOW { set wait 0 }
-    wm title .mess "GPS Manager: $TXT(message)"
+    wm title .mess "$TXT(message)/GPS Manager"
     wm transient .mess .
     wm geometry .mess +$EPOSX+$EPOSY
     bind .mess <Key-Return> { set wait 0 }
@@ -57,13 +67,14 @@ proc GMMessage {mess} {
 proc GMConfirm {mess} {
     # create modal dialog for displaying message
     #  buttons: OK, Cancel; bindings: return, delete
-    global Temp2 COLOUR EPOSX EPOSY TXT
+    global Temp2 COLOUR EPOSX EPOSY TXT CMDLINE
 
+    if { $CMDLINE } { return 1 }
     set wait2 1
     destroy .mess
     toplevel .mess
     wm protocol .mess WM_DELETE_WINDOW { set Temp2 0 ; set wait2 0 }
-    wm title .mess "GPS Manager: $TXT(message)"
+    wm title .mess "$TXT(message)/GPS Manager"
     wm transient .mess .
     wm geometry .mess +$EPOSX+$EPOSY
     bind .mess <Key-Return> { set Temp2 1 ; set wait2 0 }
@@ -104,7 +115,7 @@ proc GMSelect {mess blist vlist} {
     toplevel .mess
     wm protocol .mess WM_DELETE_WINDOW \
 	    "set Temp3 [lindex $vlist 0] ; set wait3 0"
-    wm title .mess "GPS Manager: $TXT(selection)"
+    wm title .mess "$TXT(selection)/GPS Manager"
     wm transient .mess .
     wm geometry .mess +$EPOSX+$EPOSY
     bind .mess <Key-Return> "set Temp3 [lindex $vlist 0] ; set wait3 0"
@@ -137,11 +148,11 @@ proc GMOpenFile {act wh mode} {
     #  buttons: OK, Cancel
     #  binding: return and double-left for commit, left-click for select
     global Temp4 COLOUR DPOSX DPOSY LISTHEIGHT File FileTypes TXT MESS \
-	    tcl_platform
+	    UNIX
 
     toplevel .fdlg
     wm protocol .fdlg WM_DELETE_WINDOW { set Temp4 cnc ; set wait4 0 }
-    wm title .fdlg "GPS Manager: $TXT(file)"
+    wm title .fdlg "$TXT(file)/GPS Manager"
     wm transient .fdlg .
     wm geometry .fdlg +$DPOSX+$DPOSY
     bind .fdlg <Key-Return> { set Temp4 ok ; set wait4 0 }
@@ -149,7 +160,7 @@ proc GMOpenFile {act wh mode} {
     frame .fdlg.fr -borderwidth 5 -bg $COLOUR(selbg)
     label .fdlg.fr.title -text [format $MESS(fileact) $act $TXT(name$wh)] \
 	    -relief sunken
-    if { "$tcl_platform(platform)" == "windows" } {
+    if { ! $UNIX } {
 	menubutton .fdlg.fr.vols -text $TXT(volume) -menu .fdlg.fr.vols.m
 	menu .fdlg.fr.vols.m
 	bind .fdlg.fr.vols <Button-1> {
@@ -186,7 +197,7 @@ proc GMOpenFile {act wh mode} {
 
     pack .fdlg.fr.bs.ok .fdlg.fr.bs.cnc -side left -pady 5
     pack .fdlg.fr.frbx.box .fdlg.fr.frbx.bscr -side left -fill y
-    if { "$tcl_platform(platform)" != "windows" } {
+    if { $UNIX } {
 	pack .fdlg.fr.title .fdlg.fr.wdir .fdlg.fr.frbx .fdlg.fr.fn \
 		.fdlg.fr.bs -side top -pady 5
     } else {
@@ -259,11 +270,11 @@ proc GMGetFileName {act wh mode vars vals} {
     #  buttons: OK, Cancel
     #  binding: return and double-left for commit, left-click for select
     global Temp5 COLOUR DPOSX DPOSY LISTHEIGHT File FileTypes TXT MESS \
-	    tcl_platform
+	    UNIX
 
     toplevel .fdlg
     wm protocol .fdlg WM_DELETE_WINDOW { set Temp5 cnc ; set wait5 0 }
-    wm title .fdlg "GPS Manager: $TXT(file)"
+    wm title .fdlg "$TXT(file)/GPS Manager"
     wm transient .fdlg .
     wm geometry .fdlg +$DPOSX+$DPOSY
     bind .fdlg <Key-Return> { set Temp5 ok ; set wait5 0 }
@@ -271,7 +282,7 @@ proc GMGetFileName {act wh mode vars vals} {
     frame .fdlg.fr -borderwidth 5 -bg $COLOUR(selbg)
     label .fdlg.fr.title -text [format $MESS(fileact) $act $TXT(name$wh)] \
 	    -relief sunken
-    if { "$tcl_platform(platform)" == "windows" } {
+    if { ! $UNIX } {
 	menubutton .fdlg.fr.vols -text $TXT(volume) -menu .fdlg.fr.vols.m
 	menu .fdlg.fr.vols.m
 	bind .fdlg.fr.vols <Button-1> {
@@ -313,7 +324,7 @@ proc GMGetFileName {act wh mode vars vals} {
 
     pack .fdlg.fr.bs.ok .fdlg.fr.bs.cnc -side left -pady 5
     pack .fdlg.fr.frbx.box .fdlg.fr.frbx.bscr -side left -fill y
-    if { "$tcl_platform(platform)" != "windows" } {
+    if { $UNIX } {
 	pack .fdlg.fr.title .fdlg.fr.wdir .fdlg.fr.frbx .fdlg.fr.fn \
 		.fdlg.fr.fopt .fdlg.fr.bs -side top -pady 5
     } else {
@@ -432,21 +443,24 @@ proc ChangeVolume {w vol} {
     return
 }
 
-proc GMSetupParams {w vars vals} {
+proc GMSetupParams {w vars descs} {
     # set-up widgets for setting parameters in a dialog
     #  $w is window parent
-    #  $vars is list of (global) vars to set
-    #  $vals is associated list of value descriptions as:
+    #  $vars is list of (global) vars to set; they must have a value
+    #    except those associated to entries which will be initialized to ""
+    #  $descs is associated list of value descriptions as:
     #      @TEXT   checkbutton with label TEXT, values 0 1
     #      =TEXT   entry with label TEXT
+    #      +TEXT/LIST radiobutton with possible values in LIST and label TEXT
     #      LIST    radiobutton with possible values in LIST
+    # LISTs above cannot have repeated elements
     # return list of entries, each as a pair: path from $w to entry and
     #  name of global variable to set; the list can be processed by
     #  proc GMUseEntries
     global COLOUR
 
     set i 0 ; set es ""
-    foreach v $vars os $vals {
+    foreach v $vars os $descs {
 	global $v
 	frame $w.f$i
 	switch -glob $os {
@@ -458,13 +472,26 @@ proc GMSetupParams {w vars vals} {
 	    }
 	    =* {
 		set os [string range $os 1 end]
-		label $w.f$i.l$v -text $os -width 12
+		label $w.f$i.l$v -text $os
 		entry $w.f$i.e$v -width 30
-		catch "$w.f$i.e$v insert 0 [set $v]"
+		if { [catch {set $v}] } {
+		    set $v ""
+		} else { $w.f$i.e$v insert 0 [set $v] }
 		TextBindings $w.f$i.e$v
 		pack $w.f$i.l$v $w.f$i.e$v -side left
 		lappend es "f$i.e$v $v"
 	    }
+	    +* {
+		regexp {^\+(.+)/(.+)$} $os m lab lst
+		label $w.f$i.l$v -text $lab
+		pack $w.f$i.l$v -side left
+		foreach o $lst {
+		    radiobutton $w.f$i.r$o -text $o -variable $v \
+			    -value $o -anchor w -selectcolor $COLOUR(check)
+		    pack $w.f$i.r$o -side left -padx 2
+		}
+		$w.f$i.r[lindex $lst 0] invoke
+	    }
 	    default {
 		set d 1
 		foreach o $os {
@@ -498,22 +525,25 @@ proc GMUseEntries {w es} {
 proc GMChooseFrom {how mess wd blist vlist args} {
     # create modal dialog for selecting elements from list $blist
     #  with associated return values in $vlist
-    #  $how in {single, many} defines number of elements that can be selected
+    #  $how in {single, many, many_0} defines number of elements that can
+    #   be selected, many_0 meaning that 0 is an alternative
     # a listbox is used with width $wd
-    #  $args if present is a pair with $vars $vals, suitable for use
+    #  $args if present is a pair with $vars $descs, suitable for use
     #   with proc GMSetupParams, so that parameters may be selected
-    #  buttons: OK, Cancel
-    #  bindings: return for commit, extended select mode on listbox,
-    #   make visible by initial char on listbox
+    # buttons: OK, Cancel
+    # bindings: return for commit, extended select mode on listbox,
+    #  make visible by initial char on listbox
+    # return list with selected values upon normal termination, and
+    #  an empty list or -1 if $how==many_0
     # (see also proc GMSelect for selection of only one element with buttons)
-    global TempChFr DPOSX DPOSY COLOUR TXT
+    global TempChFr DPOSX DPOSY COLOUR TXT UNIX
 
     set w .gmchoosefr
     if { [winfo exists $w] } { Raise $w ; bell ; return }
 
     toplevel $w
     wm protocol $w WM_DELETE_WINDOW "set TempChFr cnc ; set waitchfr 0"
-    wm title $w "GPS Manager: $mess"
+    wm title $w "$mess/GPS Manager"
     wm transient $w .
     wm geometry $w +$DPOSX+$DPOSY
     bind $w <Key-Return> "set TempChFr ok ; set waitchfr 0"
@@ -521,21 +551,25 @@ proc GMChooseFrom {how mess wd blist vlist args} {
     frame $w.fr -borderwidth 5 -bg $COLOUR(dialbg)
     label $w.fr.text -text "$mess"
 
-    if { [set l [llength $blist]] > 15 } {
-	set l 15
+    if { [set ll [llength $blist]] > 15 } {
+	set ll 15
     }
     frame $w.fr.frbx
-    if { "$how" == "many" } {
-	set mode extended
-    } else { set mode single }
-    listbox $w.fr.frbx.bx -height $l -width $wd -relief flat \
+    if { "$how" == "single" } {
+	set mode single
+    } else { set mode extended }
+    listbox $w.fr.frbx.bx -height $ll -width $wd -relief flat \
 	    -selectmode $mode -yscrollcommand "$w.fr.frbx.bscr set" \
 	    -exportselection 0
-    bind $w.fr.frbx.bx <Enter> { focus %W }
-    bind $w.fr.frbx.bx <Leave> "focus $w.fr.frbx"
+    # SH contribution: no such bindings in non-unix systems
+    if { $UNIX } {
+	bind $w.fr.frbx.bx <Enter> { focus %W }
+	bind $w.fr.frbx.bx <Leave> "focus $w.fr.frbx"
+    }
     bind $w.fr.frbx.bx <Key> { ScrollListIndex %W %A }
     scrollbar $w.fr.frbx.bscr -command "$w.fr.frbx.bx yview"
     foreach i $blist { $w.fr.frbx.bx insert end $i }
+    if { $ll == 1 } { $w.fr.frbx.bx selection set 0 }
 
     if { "$args" != "" } {
 	set opts 1
@@ -568,22 +602,79 @@ proc GMChooseFrom {how mess wd blist vlist args} {
 	    cnc { 
 		destroy $w
 		update idletasks
+		if { "$how" == "many_0" } { return -1 }
 		return ""
 	    }
 	    ok {
 		set ss [$w.fr.frbx.bx curselection]
-		if { "$ss" != "" } {
-		    set r ""
-		    foreach i $ss {
-			lappend r [lindex $vlist $i]
-		    }
-		    if { $opts } {
-			GMUseEntries $w.fr.fopt $es
-		    }
-		    destroy $w
-		    return $r
+		if { "$ss" == "" && "$how" != "many_0" } {
+		    bell
+		    continue
 		}
-		bell
+		set r ""
+		foreach i $ss {
+		    lappend r [lindex $vlist $i]
+		}
+		if { $opts } {
+		    GMUseEntries $w.fr.fopt $es
+		}
+		destroy $w
+		return $r
+	    }
+	}
+    }
+}
+
+proc GMChooseParams {mess vars descs} {
+    # create modal dialog for choosing parameters
+    #  $vars and $descs are as described in GMSetupParams
+    #  buttons: OK, Cancel
+    #  bindings: return for commit
+    # return 0 if cancelled
+    global TempChPrs DPOSX DPOSY COLOUR TXT
+
+    set w .gmchooseprsr
+    if { [winfo exists $w] } { Raise $w ; bell ; return }
+
+    toplevel $w
+    wm protocol $w WM_DELETE_WINDOW "set TempChPrs cnc ; set waitchprs 0"
+    wm title $w "$mess/GPS Manager"
+    wm transient $w .
+    wm geometry $w +$DPOSX+$DPOSY
+    bind $w <Key-Return> "set TempChPrs ok ; set waitchprs 0"
+
+    frame $w.fr -borderwidth 5 -bg $COLOUR(dialbg)
+    label $w.fr.text -text "$mess"
+
+    frame $w.fr.fopt
+    set es [GMSetupParams $w.fr.fopt $vars $descs]
+
+    frame $w.fr.frbt
+    button $w.fr.frbt.ok -text Ok -command "set TempChPrs ok ; set waitchprs 0"
+    button $w.fr.frbt.cnc -text $TXT(cancel) \
+	    -command "set TempChPrs cnc ; set waitchprs 0"
+
+    pack $w.fr.frbt.ok $w.fr.frbt.cnc -side left -pady 5
+    pack $w.fr.text $w.fr.fopt $w.fr.frbt -side top -pady 5
+    pack $w.fr
+
+    update idletasks
+    grab $w
+    RaiseWindow .fdlg
+    while 1 {
+	tkwait variable waitchprs
+
+	switch $TempChPrs {
+	    ""  { }
+	    cnc { 
+		destroy $w
+		update idletasks
+		return 0
+	    }
+	    ok {
+		GMUseEntries $w.fr.fopt $es
+		destroy $w
+		return 1
 	    }
 	}
     }
