@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2001 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2003 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: geod.tcl
-#  Last change:  19 June 2001
+#  Last change:  6 February 2003
 #
 
 ## Most of the geodetic information herein taken or adopted from
@@ -42,9 +42,10 @@
 ## Some more definitions taken from:
 #      - the PROJ4.0 package by Gerald I. Evenden (gie@kai.er.usgs.gov)
 #      - (Austrian Datum), http://homepage.ntlworld.com/anton.helm/bmn_mgi.html
+#      - GPSTrackMaker by Odilon Ferreira (www.gpstm.com)
 ##
 #
-## New way of representing datums with NDATUM and ELLPSDDEF arrays, and
+## New way of representing datums with GDATUM and ELLPSDDEF arrays, and
 #   proc EllipsdData based on contribution by Stefan Heinen
 #   (stefan.heinen@djh-freeweb.de)
 ##
@@ -62,6 +63,14 @@ proc EllipsdData {datum} {
     return [lreplace $d 0 0 [lindex $def 0] [expr 1.0/[lindex $def 1]]]
 }
 
+proc EllipsdOf {datum} {
+    # return ellipsoid name for $datum or "" on error
+    global GDATUM
+
+    if { [catch {set e [lindex $GDATUM($datum) 0]}] } { return "" }
+    return $e
+}
+
 proc DatumRefId {datum} {
     # return reference id of $datum or -1 if unknown datum
     # if the reference id is a number it is the one used by GPStrans
@@ -85,9 +94,11 @@ proc FillDatumMenu {menu commd} {
       [list "WGS 84" "WGS 72" \
 	--- \
 	@ [list Europe \
-                "Austrian (MGI)" "CH-1903" "Estonia Coord System 1937" "ED73" \
+                "Austrian (MGI)" "CH-1903" "Datum 73" \
+		"Estonia Coord System 1937" "ED73" \
 		@ [list "European 1950" \
-		   "European 1950" "European 1950; Cyprus" \
+		   "European 1950" "European 1950; Belgium" \
+		   "European 1950; Cyprus" \
 		   "European 1950; Egypt" "European 1950; England Channel" \
 		   "European 1950; England" "European 1950; Finland+Norway" \
 		   "European 1950; Greece" "European 1950; Iran" \
@@ -99,6 +110,7 @@ proc FillDatumMenu {menu commd} {
 		"Finland Hayford" "Graciosa Base SW 1948" "Hermannskogel" \
 		"Hermannskogel; old Yugoslavia" "Hjorsey 1955" "Ireland 1965" \
 		"Lisboa" "NTF (Nouvelle Triangulation de France)" \
+		"NTF (NTF ellipsoid)" \
 		"Observatorio 1966" \
 		@ [list "Ord Srvy Grt Britn" \
 		   "Ord Srvy Grt Britn" "Ord Srvy Grt Britn; England" \
@@ -107,7 +119,7 @@ proc FillDatumMenu {menu commd} {
 		   "Ord Srvy Grt Britn; Wales"] \
 		"Pico De Las Nieves" \
 		"Porto Santo 1936" Potsdam "Pulkovo 1942" "Rome 1940" \
-		"Rijks Driehoeksmeting" "RT 90" \
+		"Rome 1940; Luxembourg" "Rijks Driehoeksmeting" "RT 90" \
 		@ [list "S-42 (Pulkovo 1942)" \
 		   "S-42 (Pulkovo 1942); Albania" \
 		   "S-42 (Pulkovo 1942); Czechoslavakia" \
@@ -155,6 +167,7 @@ proc FillDatumMenu {menu commd} {
 		   "South American `69" "South American 69; Argentina" \
 		   "South American 69; Baltra" \
 		   "South American 69; Bolivia" "South American 69; Brazil" \
+		   "South American 69; Brazil/IBGE" \
 		   "South American 69; Chile" "South American 69; Colombia" \
 		   "South American 69; Ecuador" \
 		   "South American 69; Ecuador Galapagos" \
@@ -213,10 +226,12 @@ proc FillDatumMenu {menu commd} {
 		"Astro B4 Sorol Atoll" "Astro Beacon \"E\"" \
 		"Astronomic Stn `52" "Astro Tern Island (FRIG)" \
 		"Bellevue (IGN)" "Camp Area Astro" "Canton Astro 1966" \
-		"Chatham 1971" "Deception Island" "Djakarta (Batavia)" \
+		"Chatham 1971" "Deception Island" "Dionisos" \
+		"Djakarta (Batavia)" \
 		"DOS 1968" "Easter Island 1967" "Fort Thomas 1955" \
 		"Gandajika Base" "Guam 1963" \
-		"GUX 1 Astro" "ISTS 061 Astro 1968" "ISTS 073 Astro `69"] \
+		"GUX 1 Astro" Israeli "ISTS 061 Astro 1968" \
+		"ISTS 073 Astro `69"] \
 	@ [list "$TXT(others) \[J-Z\]" \
 		"Johnston Island" "Johnston Island 1961" "K12 Astro 1955" \
 		"Kerguelen Island" "Kertau 1948" "Kusaie Astro 1951" \
@@ -966,11 +981,11 @@ array set GDATUM {
 
 "Southeast Base" { "International 1924"
     -499 -249 314
-    92 ""}
+    92 "= Porto Santo 1936"}
 
 "Southwest Base" { "International 1924"
     -104 167 -38
-    93 ""}
+    93 "= Graciosa Base SW 1948"}
 
 "Timbalai 1948" { "Everest (Sabah Sarawak)"
     -679 669 -48
@@ -1085,7 +1100,7 @@ array set GDATUM {
 
 "Hu-Tzu-Shan" { "International 1924"
     -637 -549 -203
-    gm118 "Taiwan" 15 15 15 4 20 28 117 124}
+    gm118 "Taiwan; = TWD67" 15 15 15 4 20 28 117 124}
 
 "Indian (India, Nepal)" { "Everest (India 1956)"
     295 736 257
@@ -1149,15 +1164,16 @@ array set GDATUM {
 
 "Porto Santo 1936" { "International 1924"
     -499 -249 314
-    gm135 "Porto Santo, Madeira Islands" 25 25 25 2 31 35 -18 -15}
+    gm135 "Porto Santo, Madeira Islands; = Southeast Base"
+    25 25 25 2 31 35 -18 -15}
 
 "Pulkovo 1942" { "Krassovsky 1940"
     28 -130 -95
     gm136 "Russia" -1 -1 -1 0 36 89 -180 180}
 
 "Rijks Driehoeksmeting" { "Bessel 1841"
-    -593 -26 -478
-    gm137 "Netherlands"}
+    593.032 26 478.741
+    gm137 "Netherlands; also known as Amersfoort"}
 
 "S-42 (Pulkovo 1942); Albania" { "Krassovsky 1940"
     24 -130 -92
@@ -1237,7 +1253,7 @@ array set GDATUM {
 
 "Graciosa Base SW 1948" { "International 1924"
     -104 167 -38
-    gm150 "Azores (Faial, Graciosa, Pico, Sao Jorge, Terceira)"
+    gm150 "Azores (Faial, Graciosa, Pico, Sao Jorge, Terceira); = Southwest Base"
     3 3 3 5 37 41 -30 -26}
 
 "Hermannskogel" { "Bessel 1841 (Namibia)"
@@ -1255,6 +1271,34 @@ array set GDATUM {
 "Sierra Leone" { "Clarke 1880"
     -88 4 101 
     gm153 "" 15 15 15 8 1 16 -19 -4}
+
+"Israeli" { "Israeli"
+    -235 -85 264
+    gm154 "" -1 -1 -1 0}
+
+"South American 69; Brazil/IBGE" { "South American 1969"
+    -66.87 4.37 -39
+    gm155 "" -1 -1 -1 0}
+
+"Datum 73" { "International 1924"
+    223.237 110.193 -37
+    gm156 "Portugal" -1 -1 -1 0}
+
+"Dionisos" { "GRS 80"
+    -200 75 246
+    gm157 "" -1 -1 -1 0}
+
+"NTF (NTF ellipsoid)" { "NTF"
+    168 60 -320
+    gm158 "Nouvelle Triangulation de France" -1 -1 -1 0}
+
+"Rome 1940; Luxembourg" { "International 1924"
+    263 -76 -45
+    gm159 "" -1 -1 -1 0}
+
+"European 1950; Belgium" { "International 1924"
+    -126 80 -101
+    gm160 "" -1 -1 -1 0}
 }
 
 ###### known ellipsoids
@@ -1287,8 +1331,9 @@ proc FillEllipsoidMenu {menu commd} {
          {Helmert 1906} \
          @ [list Hough \
               {Hough 1956} {Hough 1960}] \
-         {IAU 1976} {Indonesian 1974} {International 1924} {Kaula 1961} \
-         {Krassovsky 1940} {Lerch 1979} {MERIT 1983} {Maupertius 1738} \
+         {IAU 1976} {Indonesian 1974} {International 1924} Israeli \
+	 {Kaula 1961} \
+         {Krassovsky 1940} {Lerch 1979} {MERIT 1983} {Maupertius 1738} NTF \
          NWL9D {Plessis 1817} SGS85 {South American 1969} {Southeast Asia} \
          @ [list WGS \
               {WGS 60} {WGS 66} {WGS 72} {WGS 84}] \
@@ -1373,6 +1418,8 @@ array set ELLPSDDEF {
 
 "International 1924" {6378388.0   297.0 "used in Europe"}
 
+"Israeli" {6377973 293.466001939}
+
 "Kaula 1961" {6378163 298.24 ""}
 
 "Krassovsky 1940" {6378245.0 298.3
@@ -1390,6 +1437,8 @@ array set ELLPSDDEF {
 
 "NWL9D" {6378145 298.25 "Naval Weapons Lab., 1965"}
 
+"NTF" {6378025 303.20855706 "Nouvelle Triangulation de France"}
+
 "Plessis 1817" {6376523 308.640997 "used in France"}
 
 "SGS85" {6378136 298.257 "Soviet Geodetic System 85"}
