@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2001 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2003 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,11 +17,12 @@
 #      along with this program.
 #
 #  File: langdeutsch.tcl
-#  Last change:  21 November 2001
-# German language file by Andreas Lange (andreas.lange@rhein-main.de)
-#  last input from him inserted: 21 November 2001
+#  Last change:  29 July 2002
+# German language file by Andreas Lange (Andreas.C.Lange@GMX.de)
+#  last input from him inserted: 31 January 2002
 #
-# Some translations by Sabine Broda / LIACC / Universidade do Porto
+# Support by Sabine Broda (sbb@ncc.up.pt) since 2002
+#  last input from her inserted: 28 February 2003
 
 # file langengl.tcl is consulted first; no need for duplicating entries here
 
@@ -77,7 +78,6 @@ array set MESS {
     undefWP   "Route %s besitzt undefinierte WPe; nicht gespeichert/exportiert"
     bigRT   "Route %s > max. Anzahl; nicht exportiert"
     unkndatum   "Unbekanntes Datum"
-    nogrids   "Gitter nicht implementiert"
     badcommdWP   "Ungltiger Befehl beim Laden der WPe; Zeile"
     notabsWP   "Ungltige WP Definition; keine Tabulatoren, Zeile"
     undefWP   "Referenz zu umbekanntem WP: %s; Zeile %d"
@@ -142,19 +142,15 @@ array set MESS {
     badserial "Kann serielle Schnittstelle %s nicht ffnen"
     nodata    "Kein %se im Empfnger"
     badimage "Ungltige Bild-Datei"
-    mapaskWPs "Bitte whlen Sie %d WPe zur Kartendarstellung"
     mapadjust "Bitte plazieren Sie die WPe auf der Karte; Ok zum Beenden"
     duplicate "%s bereits ausgewhlt"
     clrcurrmap "Aktuelle Karte lschen?"
-    cantfix "%d WPe werden bentigt, um die Karte einzumessen; bitte zuerst einige WPe laden oder definieren"
     mbkbaddatum "Kein oder unbekanntes Datum"
     mbkbadscale "Die Skala mu nicht-negativ sein"
     mbkbadat "Ungltige Argumente"
     edityourrisk "Bearbeiten auf eigene Gefahr!"
     okclrbkmap   "Ok zum Lschen des Karten-Hintergrundes"
     okclrbkim    "Ok zum Lschen des Bildes bei"
-    badWPfield "Falsches Options-Feld"
-    badWPattr "Unbekannter optionaler Feldname"
     badSYMBOLcode "Ungltiger Symbol-Code"
     badDISPOPTcode "Ungltiger Code der Anzeige-Optionen"
     goingdown "Prferenzen wurden gespeichert; bitte neu starten"
@@ -245,6 +241,40 @@ array set MESS {
     badinvproj "Nherungsfehler bei der Umkehrung der %s Projektion"
     negdlatlong "Lnge/Breite Werte drfen nicht negativ sein!"
     allundef "In der Gruppe sind keine Definitionen fr die WPe enthalten"
+    badfloats "Fliesskomma-Konvertierung funktioniert nicht korrekt; sind
+Sie sicher, dass Sie die Verbindung herstellen wollen?"
+    frgetGRcs "Gruppe mit allen Elementen lschen?!"
+    clrtrvlog "Reiseaufzeichnung lschen?"
+    badattr "Unbekannter %s optionaler Feldname: %s"
+    badattrval "Falscher %s optionaler Feldwert: %s"
+    couldntcd "Konnte nicht zu directory %s wechseln"
+    shpext "Falsche Endung %s; kann .shp, .shx, .dbf benutzt werden?"
+    shpcntopen "Shapefile-Dateien konnten nicht erzeugt/geffnet werden"
+    shpcntcrtfs "Shapefile .dbf Felder konnten nicht erzeugt werden"
+    shpcntwrtfs "Shapefile .dbf Felder konnten nicht gespeichert werden"
+    shpoutmem "Speicher ist voll!"
+    shpemptyfile "Leere Datei"
+    shpwrongfile "Ungltiger Dateientyp"
+    shplessdim "Dimension in Datei kleiner als erforderlich; weiter?"
+    shpbadWPinRT "%d. WP mit ungltigen Koordinaten ignoriert in RT %s"
+    badGTMvers "GTrackMaker Dateienversion ungltig"
+    badGTMfile "Falscher Anfang in GTrackMaker Datei"
+    badGTMcounts "Negative(r) Zhler in GTrackMaker Datei"
+    badGTMlat "Ungltige Breitenwerte in GTrackMaker Datei"
+    badGTMlong "Ungltige Lngenwerte in GTrackMaker Datei"
+    badGTMdatum "Ungltiges Datum in GTrackMaker Datei"
+    unobscmap "Fehler erfolgte warscheinlich wegen Fenster/Icon auf der Karte; nach Verzgerung wiederversuchen?"
+    cantwrtimg "Fehler whrend Bildspeicherung in Datei in %s Format"
+    TRsimplres "Vereinfachter TR mit Namen %s erzeugt"
+    cantsaveRTid "%d RT(n) nicht gespeichert: non-numerisches Id"
+    badtrvconf "Ungltige Konfiguration; Neustart ohne Elemente"
+    drvsimoff "Fahrsimulator: noch nicht gestartet!"
+    needWP "Fahrsimulater: bitte erst einige WPe laden/definieren"
+    chgrecprot "Bitte Empfnger-Protokoll ndern"
+    noprintcmd "Kein Druckkommando; bitte eins in den Optionen angeben"
+    cantexecasroot "GPSMan kann nicht von root ausgefhrt werden"
+    badargtofunc "%s Funktion mit ungltigem Argument"
+    redefproj "Benutzers %s Projektion lscht vordefinierte Projektion mit gleicher Abkrzung; bitte Definition ndern!"
 }
 
 set TXT(RTcompflds) "# WP {$DTUNIT} Grad m Etappe Bezeichnung"
@@ -346,7 +376,6 @@ array set TXT {
     chophd   "Anfang abschneiden"
     choptl   "Ende abschneiden"
     incb   "Einfgen vor"
-    mkRT   "Erzeuge RT"
     date   Datum
     newdate   "Neues Datum fr nchsten Punkt"
     endprTR   "Ende des vorhergehenden Tracks"
@@ -440,7 +469,7 @@ array set TXT {
     optMAPCOLOUR,anim  "Karten-Animation"
     optMAPCOLOUR,emptygrid  "Leeres Bild"
     optMAPCOLOUR,fullgrid   "Bestehendes Bild"
-    opt_Files Dateien
+    opt_Files "Seriell Schnittstelle & Dateien"
     optDEFSPORT "Seriell Schnittstelle"
     optPERMS   "Dateirechte"
     optPAPERSIZE "Papiergre"
@@ -469,7 +498,6 @@ array set TXT {
     joinGR   "Gruppe zusammenfgen"
     TRtoRT   "Umwandlung von TR nach RT"
     TRRTnpoints   "Anzahl der Punkte" 
-    TRRTdispl   "RT jetzt anzeigen"
     TRTRdispl   "TR jetzt anzeigen"
     WP   WP
     RT   RT
@@ -707,6 +735,7 @@ array set TXT {
     long0 "zentrale Lnge"
     gkklong0 "zentrale Lnge"
     kkjplong0 "zentrale Lnge"
+    twglong0 "zentrale Lnge"
     k0 "Skalenfaktor des Zentralmeridians"
     PRJUTM "UTM/UPS"
     PRJTM  "Transv. Mercatorproj."
@@ -811,6 +840,192 @@ array set TXT {
     collcntr "Erzeuge Mittelpunkte..."
     compclstr "Erzeuge Cluster..."
     crtgclstrgrs "Erstelle Gruppen..."
+    PRJStereogr "Stereographische Proj."
+    PRJTWG "Taiwan Gitter"
+    chgdatum "Datum ndern"
+    forgetGRcs "GR&Els lschen"
+    renres "Neubenannt"
+    zelev "Z-Mastab"
+    xyelev "XY-Mastab"
+    chggoal "Zum nchsten Ziel wechseln"
+    Ghidden_class Klasse
+    Ghidden_subclass Subklasse
+    Ghidden_lnk_ident "Etappen Id"
+    Ghidden_colour Farbe
+    Ghidden_attrs Attribute
+    Ghidden_depth Tiefe
+    Ghidden_state Staat
+    Ghidden_country Land
+    Ghidden_facility Facility
+    Ghidden_city Stadt
+    Ghidden_addr Adresse
+    Ghidden_int_road "Straenkreuzung"
+    Ghidden_dtyp "Anzeige Option+Typ"
+    Ghidden_ete "ETE"
+    Ghidden_display "Display?"
+    Ghidden_yes ja
+    Ghidden_no nein
+    Ghidden_user Benutzer
+    Ghidden_user_symbol "Benutzer (nur Symbol)"
+    Ghidden_non_user "Nichtbenutzer"
+    Ghidden_avn_airport Flughafen
+    Ghidden_avn_inters "Avn intersection"
+    Ghidden_avn_NDB "NDB"
+    Ghidden_avn_VOR "VOR"
+    Ghidden_avn_airp_rway "Airport runway threshold"
+    Ghidden_avn_airp_int "Airport intersection"
+    Ghidden_avn_airp_NDB "Airport NDB"
+    Ghidden_map_pt "Kartenpunkt"
+    Ghidden_map_area "Karten-Flche"
+    Ghidden_map_int "Karten-Kreuzung"
+    Ghidden_map_addr "Karten-Adresse"
+    Ghidden_map_label "Karten-Kennzeichen"
+    Ghidden_map_line "Karten-Linie"
+    Ghidden_locked blockiert
+    Ghidden_default "Vorgabe"
+    Ghidden_black Schwarz
+    Ghidden_white Weiss
+    Ghidden_red Rot
+    Ghidden_dark_red "Dunkelrot"
+    Ghidden_green Grn
+    Ghidden_dark_green "Dunkelgrn"
+    Ghidden_blue Blau
+    Ghidden_dark_blue "Dunkelblau"
+    Ghidden_yellow Gelb
+    Ghidden_dark_yellow "Dark Gelb"
+    Ghidden_magenta Magenta
+    Ghidden_dark_magenta "Dunkles Magenta"
+    Ghidden_cyan Cyan
+    Ghidden_dark_cyan "Dunkles Cyan"
+    Ghidden_light_gray "Hellgrau"
+    Ghidden_dark_gray "Dunkelgrau"
+    Ghidden_line Linie
+    Ghidden_link Etappe
+    Ghidden_net Netz
+    Ghidden_direct Direkt
+    Ghidden_snap Snap
+    numberid "Nummer/Id"
+    hiddendata "Verborgene Daten"
+    cwpsdef "Wieviele Kontroll WPe definieren"
+    nextTP "Nchster TP"
+    generate Erzeugen
+    generateall "Alle erzeugen"
+    optSERIALBAUD "Baud Rate"
+    optDEFTRTWIDTH "RT Liniendicke"
+    optDEFTTRWIDTH "TR Liniendicke"
+    width Dicke
+    TRtoTR   "TR Vereinfachung"
+    TRlinedispl   "Ergebnis jetzt zeigen"
+    obsTRsimpl "TR nach Vereinfachung"
+    simplTRto "Vereinfachen zu"
+    exstglog "Existigerender log"
+    contnsly "fortgesetzt"
+    animate "animieren"
+    animabbrev "anim."
+    noanabbr "nicht anim."
+    notext "kein Text"
+    view "ansehen"
+    sideview "Seitenansicht"
+    persptv "Perspektive"
+    SYgeocache "Geocache"
+    SYgeocache_fnd "Geocache entdeckt"
+    optMAPCOLOUR,trvtrk "TRK Zeiger"
+    optMAPCOLOUR,trvtrn "TRN Zeiger"
+    optMAPCOLOUR,trvcts "CTS Zeiger"
+    optMAPCOLOUR,trvcts2 "2. CTS Zeiger"
+    optMAPCOLOUR,trvvel_z "Hoch/Runter Zeiger"
+    optMAPCOLOUR,trvwrnimportant "Wichtige Warnung (nav)"
+    optMAPCOLOUR,trvwrnnormal "Warnung (nav)"
+    optMAPCOLOUR,trvwrninfo "Information (nav)"
+    travel Reise
+    notravel "Reise unterbrechen"
+    optTRAVELFONTSIZE "Schriftgre der Reisenanzeige"
+    travdisplay "Anzeige konfigurieren"
+    travchgdisplay "Zu Anzeige %s wechseln"
+    travdsetup "Reisenanzeige konfigurieren"
+    navMOB "MOB: Mann ber Bord!"
+    startnav "Navigate"
+    navWP "Zu WP gehen"
+    goback "Zurckgehen"
+    follow "%s folgen"
+    exactly "exakt"
+    fromnrst "vom nhesten Punkt"
+    inrvrs "umgekehrt"
+    forgetgoal "Ziel lschen"
+    suspend "unterbrechen"
+    resume "weiter"
+    TRVfix "Fix"
+    TRVhour "Uhrzeit"
+    TRVspeed "Geschw."
+    TRVpos "Pos"
+    TRValt "Hhe"
+    TRVtrk "TRK"
+    TRVnxtWP "Zu"
+    TRVprvWP "Von"
+    TRVete "ETE"
+    TRVeta "ETA"
+    TRVvmg "VMG"
+    TRVxtk "XTK"
+    TRVcts "CTS"
+    TRVtrn "TRN"
+    TRVvel_z "V Geschw."
+    TRVtrkcts "TRK, CTS"
+    TRVdist "Dist"
+    TRVc_trkcts "TRK/CTS Zeiger"
+    TRVc_trn "TRN Zeiger"
+    TRVc_vel_z "Hoch/runter Zeiger"
+    add "Hinzufgen"
+    addlabelled "Mit Beschriftung hinzufuegen"
+    remove "Lschen"
+    mindist "Ankunftsnhe"
+    chginggoal "Wechsel zum nchsten Ziel"
+    chggoalhlp "Wann von diesem zum\nnchsten Ziel wechseln\nbeim Folgen von RT/TR"
+    soon frh
+    late spt
+    warnings "Warnungen"
+    dowarn "Warnungen ausstellen"
+    warnconf "Warnungen konfigurieren"
+    priority Vorrang
+    high hoch
+    medium mittel
+    low niedrig
+    warnprox "Entfernung zu WP <"
+    warnanchor "Entfernung zu WP >"
+    warnspeed "Geschwindigkeit >"
+    warntrn "TRN (abs)>"
+    warnvspeed "Vertikale Geschwindigkeit"
+    warnxtk "XTK (abs)>"
+    fntsize "Schriftgre"
+    trvhlpbox "Rechte Taste zur Wiederordnung von\nfolgenden Elementen benutzen"
+    trvhlpbxs "Rechte Taste zur Wiederordnung von\nElementen der Liste benutzen"
+    trvwarrv "Ankunft in %s!"
+    trvwleave "Abfahrt von %s!"
+    trvwspeed "Geschwindigkeit > %s!"
+    trvwtrn "TRN > %s!"
+    trvwvspeed "Vert. Geschwindigkeit nicht in [%s,%s]!"
+    trvwxtk "XTK > %s!"
+    trvwnolog "Echtzeitdatenaufnahme ausgeschaltet!"
+    trvwnopos "Keine vorherigen Positionen"
+    trvwuwps "RT hat undefinierte WP(e)"
+    trvwchg "Jetzt nach %s gehend"
+    TP TP
+    drivesim "Fahrsimulator"
+    startfrom "Startpunkt..."
+    outofctrl "Ausser Kontrolle!"
+    right Rechts
+    left Links
+    straight Geradeaus
+    rthlpdsim "Zeigertasten: steuern, Geschwindigkeit ndern\nLeertaste: geradeaus"
+    printopt "Druckoptionen"
+    optPRINTCMD "Druckkommandos"
+    optMAPFONTSIZE "Kartenschriftgre"
+    print Drucken
+    prevctr "Vorheriger Mittelpunkt"
+    PRJSOM "Swiss Oblique Mercator"
+    PRJLV03 "Swiss LV03 Grid"
+    PRJIcG "Iceland Grid"
+    PRJRDG "The Netherlands Grid"
+    chgmfsize "Kartenschriftgre ndern"
 }
 
     # the following definitions must be coherent with $TXT
