@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2002 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2003 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,10 +17,12 @@
 #      along with this program.
 #
 #  File: langengl.tcl
-#  Last change:  1 February 2002
+#  Last change:  12 February 2003
 #
 # Includes contributions by Brian Baulch (baulchb@onthenet.com.au)
 #
+# Includes contributions by Matt Martin (matt.martin@ieee.org)
+#
 
 # only 3 chars long names; check also ALLMONTH in file gpsman
 set MONTHNAMES "Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec"
@@ -130,19 +132,17 @@ array set MESS {
     badserial "Cannot open serial port %s"
     nodata    "No %ss in receiver"
     badimage "Bad image file"
-    mapaskWPs "Please choose %d WPs to place on map"
     mapadjust "Please place WPs on map; click Ok when finished"
     duplicate "%s already selected"
     clrcurrmap "Clear current map?"
-    cantfix "%d WPs are needed to fix the map; load or define some WPs first"
     mbkbaddatum "No or unknown datum"
     mbkbadscale "Scale must be non-negative"
     mbkbadat "Bad arguments"
     edityourrisk "Edit at your own risk!"
     okclrbkmap   "Ok to clear map background"
     okclrbkim    "Ok to clear image at"
-    badWPfield "Wrong optional field"
-    badWPattr "Unknown optional field name"
+    badattrval "Wrong %s optional field value: %s"
+    badattr "Unknown %s optional field name: %s"
     badSYMBOLcode "Bad symbol code"
     badDISPOPTcode "Bad display option code"
     goingdown "Preferences saved; please restart"
@@ -233,6 +233,37 @@ array set MESS {
     negdlatlong "Lat/long range cannot be negative!"
     allundef "There are no definitions for the WPs in the GR"
     badfloats "Floating-point conversions not working correctly; are you sure you want to connect?"
+    noprintcmd "No print command; give one in the options"
+    cantexecasroot "GPSMan cannot be executed by root"
+    badargtofunc "Bad argument to %s function"
+    redefproj "User defined %s projection deletes a pre-defined projection under the same short name; please change your definition!"
+    couldntcd "Failed to change to directory %s"
+    shpext "Bad extension %s; ok to use .shp, .shx, .dbf?"
+    shpcntopen "Could not create/open Shapefile files"
+    shpcntcrtfs "Could not create Shapefile .dbf fields"
+    shpcntwrtfs "Could not write Shapefile .dbf fields"
+    shpoutmem "Out of memory!"
+    shpemptyfile "Empty file"
+    shpwrongfile "File type invalid"
+    shplessdim "Dimension in file less than required; go on?"
+    shpbadWPinRT "%d-th WP with bad coordinates ignored in RT %s"
+    errorGTMread "Error when reading from GTrackMaker file"
+    badGTMvers "GTrackMaker file version not acceptable"
+    badGTMfile "Wrong initial string for GTrackMaker file"
+    badGTMcounts "Negative count(s) in GTrackMaker file"
+    badGTMlat "Latitude out of range in GTrackMaker file"
+    badGTMlong "Longitude out of range in GTrackMaker file"
+    badGTMdatum "Bad datum in GTrackMaker file"
+    unobscmap "Error probably because there is a window/icon over the map; retry after delay?"
+    cantwrtimg "Error writing image to file in %s format"
+    TRsimplres "TR resulting from simplification created under name %s"
+    cantsaveRTid "%d RT(s) not saved: non-numeric identifier"
+    badtrvconf "Corrupt configuration; restarting with empty one"
+    drvsimoff "Driving simulator: not started yet!"
+    needWP "Driving simulator: please load or define some WPs first"
+    chgrecprot "Please change the receiver protocol"
+    clrtrvlog "Clear travel log?"
+    frgetGRcs "Forget group and all its elements?!"
 }
 
 set TXT(RTcompflds) "# WP {$DTUNIT} deg m stage label"
@@ -315,6 +346,7 @@ array set TXT {
     startRT "Start RT"
     route   Route
     number   Number
+    numberid "Number/Id"
     insb   "Insert before"
     insa   "Insert after"
     del   Delete
@@ -328,7 +360,6 @@ array set TXT {
     chophd   "Chop head"
     choptl   "Chop tail"
     incb   "Include before"
-    mkRT   "Make RT"
     date   Date
     newdate   "New date for next point"
     endprTR   "End of previous track"
@@ -348,13 +379,15 @@ array set TXT {
     change   Change
     forget   Forget
     others   Others
-    opt_Interf  Interface
+    opt_Interf  "User interface"
     optLANG   Language
     optISOLATIN1   "Compose chars"
     optDELETE   "DEL deletes last char"
     optMWINDOWSCONF  "Main window"
+    optSERIALBAUD "Baud Rate"
     optGPSREC   "GPS Model"
     opt_GPSRecConf   "Receiver parameters"
+    optACCEPTALLCHARS "Accept all characters"
     optNAMELENGTH   "Max name length"
     optINTERVAL "Sampling interval"
     optCOMMENTLENGTH   "Max comment length"
@@ -425,11 +458,15 @@ array set TXT {
     optMAPCOLOUR,anim  "Animation on map"
     optMAPCOLOUR,emptygrid  "Empty image"
     optMAPCOLOUR,fullgrid   "Existing image"
-    opt_Files Files
+    optMAPFONTSIZE "Map font size"
+    optDEFTRTWIDTH "RT line width"
+    optDEFTTRWIDTH "TR line width"
+    opt_Files "Serial port and files"
     optDEFSPORT "Serial port"
     optSAVESTATE "Save state on exit"
     optDELSTATE "Delete files after restoring state"
     optPERMS   "File permissions"
+    optPRINTCMD "Print command"
     optPAPERSIZE "Paper size"
     red   Red
     green   Green
@@ -444,6 +481,7 @@ array set TXT {
     MMDDYYYY   MMDDYYYY
     DDMMMYYYY   DDMMMYYYY
     YYYY-MM-DD  YYYY-MM-DD
+    YYYY/MM/DD  YYYY/MM/DD
     mainwd   "Main window"
     distazim   "Dist and bearing"
     nearestWPs   "Nearest WPs"
@@ -459,8 +497,9 @@ array set TXT {
     insert   Insert
     joinGR   "Join Group"
     TRtoRT   "Conversion from TR to RT"
+    TRtoTR   "TR simplification"
     TRRTnpoints   "No. points to keep"
-    TRRTdispl   "Display RT now"
+    TRlinedispl   "Display result now"
     TRTRdispl   "Display TR now"
     WP   WP
     RT   RT
@@ -563,6 +602,8 @@ array set TXT {
     SYfreeway "Freeway"
     SYfuel "Fuel"
     SYfuel_store "Fuel & store"
+    SYgeocache "Geocache"
+    SYgeocache_fnd "Geocache found"
     SYgeo_name_land "Geo name, land"
     SYgeo_name_man "Geo name, man-made"
     SYgeo_name_water "Geo name, water"
@@ -676,6 +717,7 @@ array set TXT {
     contrib "With contributions by"
     errorsto "Error reports to:"
     obsTRToRT "WPs created by a TR to RT conversion"
+    obsTRsimpl "TR resulting from simplification"
     nameLists "Lists"
     nameData "Data"
     MWCmap "Map"
@@ -736,6 +778,11 @@ array set TXT {
     PRJAPOLY "American Polyconic"
     PRJStereogr Stereographic
     PRJTWG "Taiwan Grid"
+    PRJSOM "Swiss Oblique Mercator"
+    PRJLV03 "Swiss LV03 Grid"
+    PRJIcG "Iceland Grid"
+    PRJRDG "The Netherlands Grid"
+    PRJSchreiber Schreiber
     dontaskagain "Stop asking"
     rename "Use new name"
     oname "Original name"
@@ -764,6 +811,7 @@ array set TXT {
     stext "Simple Text"
     simul "simulator"
     lowrance Lowrance
+    magellan Magellan
     getlog "Get Log"
     stop Stop
     dolog Record
@@ -781,7 +829,7 @@ array set TXT {
     posfixsimul simul
     restart Restart
     mkTR "Make TR"
-    PVTflds "# t lat long alt fix EPE EPH EPV vel_x vel_y vel_z CMG"
+    PVTflds "# t lat long alt fix EPE EPH EPV vel_x vel_y vel_z TRK"
     namePVTData "Log data"
     mkavgWP "Make avg WP"
     move Move
@@ -839,6 +887,174 @@ array set TXT {
     compclstr "Computing clusters..."
     crtgclstrgrs "Creating groups..."
     chgdatum "Change datum..."
+    print Print
+    prevctr "Previous centre"
+    printopt "Print options"
+    chgmfsize "Change map font size"
+    cwpsdef "Control WPs to define now"
+    nextTP "Next TP"
+    generate Generate
+    generateall "Generate all"
+    width Width
+    simplTRto "Simplify to"
+    exstglog "Existing log"
+    contnsly "Continuously"
+    animate "animate"
+    animabbrev "anim."
+    noanabbr "no anim."
+    zelev "Z-scale"
+    xyelev "XY-scale"
+    notext "no text"
+    view "View"
+    sideview "Side-view"
+    persptv "Perspective"
+    optMAPCOLOUR,trvtrk "TRK arrow"
+    optMAPCOLOUR,trvtrn "TRN arrows"
+    optMAPCOLOUR,trvcts "CTS arrow"
+    optMAPCOLOUR,trvcts2 "2nd CTS arrow"
+    optMAPCOLOUR,trvvel_z "Up/down arrow"
+    optMAPCOLOUR,trvwrnimportant "Important warning (nav)"
+    optMAPCOLOUR,trvwrnnormal "Warning (nav)"
+    optMAPCOLOUR,trvwrninfo "Information (nav)"
+    optTRAVELFONTSIZE "Travel display font size"
+    travel Travel
+    notravel "Stop travelling"
+    travdisplay "Configure display"
+    travchgdisplay "Change to display %s"
+    travdsetup "Configure travel display"
+    navMOB "MOB: Man Over Board!"
+    startnav "Navigate"
+    navWP "Go to WP"
+    goback "Go back"
+    follow "Follow %s"
+    exactly "exactly"
+    fromnrst "from nearest"
+    inrvrs "in reverse"
+    forgetgoal "Forget goal"
+    suspend "Suspend"
+    resume "Resume"
+    TRVfix "Fix"
+    TRVhour "Time"
+    TRVspeed "Speed"
+    TRVpos "Pos"
+    TRValt "Alt"
+    TRVtrk "TRK"
+    TRVnxtWP "To"
+    TRVprvWP "From"
+    TRVete "ETE"
+    TRVeta "ETA"
+    TRVvmg "VMG"
+    TRVxtk "XTK"
+    TRVcts "CTS"
+    TRVtrn "TRN"
+    TRVvel_z "V speed"
+    TRVtrkcts "TRK, CTS"
+    TRVdist "Dist"
+    TRVc_trkcts "TRK/CTS arrows"
+    TRVc_trn "TRN arrows"
+    TRVc_vel_z "Up/down arrow"
+    add "Add"
+    addlabelled "Add with label"
+    remove "Remove"
+    mindist "Arrival distance"
+    chggoal "Change to next goal"
+    chginggoal "Changing to next goal"
+    chggoalhlp "When to change from\ncurrent to next goal\nwhen following RT/TR"
+    soon soon
+    late late
+    warnings "Warnings"
+    dowarn "Issue warnings"
+    warnconf "Configure warnings"
+    priority Priority
+    high high
+    medium medium
+    low low
+    warnprox "Distance to WP <"
+    warnanchor "Distance to WP >"
+    warnspeed "Speed >"
+    warntrn "TRN (abs)>"
+    warnvspeed "Vertical speed"
+    warnxtk "XTK (abs)>"
+    fntsize "Font size"
+    trvhlpbox "Use right-button to reorder elements below"
+    trvhlpbxs "Use right-button to reorder list elements"
+    trvwarrv "Arriving at %s!"
+    trvwleave "Leaving %s!"
+    trvwspeed "Speed > %s!"
+    trvwtrn "TRN > %s!"
+    trvwvspeed "Vert speed not in [%s,%s]!"
+    trvwxtk "XTK > %s!"
+    trvwnolog "Real-time logging is off!"
+    trvwnopos "Previous positions unavailable"
+    trvwuwps "RT has undefined WP(s)"
+    trvwchg "Going now to %s"
+    TP TP
+    drivesim "driving simulator"
+    startfrom "Start from..."
+    outofctrl "Out of control!"
+    right Right
+    left Left
+    straight Straight
+    rthlpdsim "Arrow keys: steer, change speed\nSpace bar: straight"
+    hiddendata "Hidden data"
+    Ghidden_class Class
+    Ghidden_subclass Subclass
+    Ghidden_lnk_ident "Stage id"
+    Ghidden_colour Colour
+    Ghidden_attrs Attributes
+    Ghidden_depth Depth
+    Ghidden_state State
+    Ghidden_country Country
+    Ghidden_facility Facility
+    Ghidden_city City
+    Ghidden_addr Address
+    Ghidden_int_road "Intersection road"
+    Ghidden_dtyp "Display opt+type"
+    Ghidden_ete "ETE"
+    Ghidden_display "Display?"
+    Ghidden_yes Yes
+    Ghidden_no No
+    Ghidden_user "User"
+    Ghidden_user_symbol "User (symbol only)"
+    Ghidden_non_user "Non-user"
+    Ghidden_avn_airport "Airport"
+    Ghidden_avn_inters "Avn intersection"
+    Ghidden_avn_NDB "NDB"
+    Ghidden_avn_VOR "VOR"
+    Ghidden_avn_airp_rway "Airport runway threshold"
+    Ghidden_avn_airp_int "Airport intersection"
+    Ghidden_avn_airp_NDB "Airport NDB"
+    Ghidden_map_pt "Map point"
+    Ghidden_map_area "Map area"
+    Ghidden_map_int "Map intersection"
+    Ghidden_map_addr "Map address"
+    Ghidden_map_label "Map label"
+    Ghidden_map_line "Map line"
+    Ghidden_locked Locked
+    Ghidden_default "Default"
+    Ghidden_black Black
+    Ghidden_white White
+    Ghidden_red Red
+    Ghidden_dark_red "Dark red"
+    Ghidden_green Green
+    Ghidden_dark_green "Dark green"
+    Ghidden_blue Blue
+    Ghidden_dark_blue "Dark blue"
+    Ghidden_yellow Yellow
+    Ghidden_dark_yellow "Dark yellow"
+    Ghidden_magenta Magenta
+    Ghidden_dark_magenta "Dark magenta"
+    Ghidden_cyan Cyan
+    Ghidden_dark_cyan "Dark cyan"
+    Ghidden_light_gray "Light grey"
+    Ghidden_dark_gray "Dark grey"
+    Ghidden_line Line
+    Ghidden_link Stage
+    Ghidden_net Net
+    Ghidden_direct Direct
+    Ghidden_snap Snap
+    renres "RENAMED"
+    forgetGRcs "Forget GR&Els"
 }
 
     # the following definitions must be coherent with $TXT
