@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2001 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2003 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,11 +17,11 @@
 #      along with this program.
 #
 #  File: langengl.tcl
-#  Last change:  22 November 2001
+#  Last change:  10 March 2003
 #
 # French language file by Valre Robin (valere.robin@wanadoo.fr)
 #  Last change by him:  11 November 2001
-#  last input from him inserted:  22 November 2001
+#  last input from him inserted:  10 March 2003
 #
 
 # file langengl.tcl is consulted first; no need for duplicating entries here
@@ -64,7 +64,6 @@ array set MESS {
     undefWP   "L'itinraire %s a des points (WPs) non dfinis; non sauv ou export"
     bigRT   "Itinraire %s > nombre max; non export"
     unkndatum   "Donne inconnue"
-    nogrids   "Grilles non implmentes"
     badcommdWP   "Mauvaise commande en chargeant les WPs; ligne"
     notabsWP   "Mauvaise dfinition d'un point d'itinraire; pas de tabulation, ligne"
     undefWP   "Rfrence  un point d'itinraire inconnu: %s; ligne %d"
@@ -129,19 +128,15 @@ array set MESS {
     badserial "Ouverture du port srie %s impossible"
     nodata    "Pas de %ss dans le rcepteur"
     badimage "Fichier image erron"
-    mapaskWPs "Choisir les %d points d'itinraire  placer sur la carte"
     mapadjust "Placer les points d'itinraire sur la carte puis cliquer sur Ok"
     duplicate "%s est dj slectionn"
     clrcurrmap "Effacement de la carte courante?"
-    cantfix "%d point sont ncessaires pour fixer la carte; commencer par charger ou dfinir des points d'itinraire"
     mbkbaddatum "Donnes absentes ou inconnues"
     mbkbadscale "L'chelle ne doit pas tre ngative"
     mbkbadat "Arguments errons"
     edityourrisk "Editez  vos risques!"
     okclrbkmap   "Ok pour effacer le fond de carte"
     okclrbkim    "Ok pour effacer l'image "
-    badWPfield "Champs optionnel erron"
-    badWPattr "Nom de champs optionnel inconnu"
     badSYMBOLcode "Code de symbole erron"
     badDISPOPTcode "Code d'option d'affichage erron"
     goingdown "Prfrences sauvegardes; redmarrer"
@@ -231,6 +226,39 @@ array set MESS {
     badinvproj "Erreur d'approximation dans l'inversion de la projection %s"
     negdlatlong "Interval lat/long erron : ne peut tre negative!"
     allundef "Dfinitions manquantes pour les points du groupe"
+    badfloats "Erreurs dans la conversion en virgule flottante; connecter tout de mme?"
+    noprintcmd "Commande d'impression absente;  positionner dans les options"
+    cantexecasroot "GPSMan ne peut tre excut par le super-utilisateur ROOT"
+    badargtofunc "Argument erron pour la fonction %s"
+    redefproj "La projection %s dfinie par l'utilisateur efface une projection prdfinie ayant le mme nom abbrg ; dfinition  modifier!"
+    badattr "Champ optionnel inconnu pour %s :  %s"
+    badattrval "Champ optionnel erron pour %s : %s "
+    couldntcd "Echec du changement de rpertoire %s"
+    shpext "Mauvaise extension %s; utilisation de .shp, .shx, .dbf?"
+    shpcntopen "Cration/Ouverture du fichier de profil impossible"
+    shpcntcrtfs "Cration des champs .dbf du profil impossible"
+    shpcntwrtfs "Ecriture des champs .dbf du profil impossible"
+    shpoutmem "Saturation mmoire!"
+    shpemptyfile "Fichier vide"
+    shpwrongfile "Type de fichier invalide"
+    shplessdim "Nombre de dimensions insuffisant dans le fichier; continuer?"
+    shpbadWPinRT "%d-ime WP aux coordonnes errones ignors dans la route %s"
+    badGTMvers "Version du fichier GTrackMaker inacceptable"
+    badGTMfile "Chane initiale errone dans le fichier GTrackMake"
+    badGTMcounts "Nombre(s) ngatif(s) dans le fichier GTrakMake"
+    badGTMlat "Dbordement de la latiture dans le fichier GTrackMaker"
+    badGTMlong "Dbordement de la longitude dans le fichier GTrackMaker"
+    badGTMdatum "Mauvaise donne dans le fichier GTrackMaker"
+    unobscmap "Erreur probablement cause par le recouvrement de la carte par une icne ou une fentre: recommencer aprs un dlai."
+    cantwrtimg "Erreur d'criture dans un fichier au format %s"
+    TRsimplres "Cration d'une trace simplifie %s"
+    cantsaveRTid "Route %s non sauvegarde : identifiant non numrique"
+    badtrvconf "Configuration corrompue; recommencer avec une configuration vide"
+    drvsimoff "Simulateur de conduite : pas encore dmarr"
+    needWP "Simulateur de conduite : charger ou dfinir des points de route"
+    chgrecprot "Changer le protocole du rcepteur"
+    frgetGRcs "Oubli du groupe et de tous ses lments?"
+    clrtrvlog "Effacement du journal de voyage?"
 }
 
 set TXT(RTcompflds) "# WP {$DTUNIT} deg m stage label"
@@ -325,7 +353,6 @@ array set TXT {
     chophd   "Supprimer avant"
     choptl   "Supprimer aprs"
     incb   "Inclure avant"
-    mkRT   "Faire une route"
     date   Date
     newdate   "Nouvelle date pour le point suivant"
     endprTR   "Fin de la trace prcdente"
@@ -345,7 +372,7 @@ array set TXT {
     change   Changer
     forget   Oublier
     others   Autres
-    opt_Interf  Interface
+    opt_Interf  "Interface utilisateur"
     optLANG   Langage
     optISOLATIN1   "Caractres composs"
     optDELETE   "DEL efface le dernier caractre"
@@ -422,7 +449,7 @@ array set TXT {
     optMAPCOLOUR,anim  "Animation sur la carte"
     optMAPCOLOUR,emptygrid  "Image vide"
     optMAPCOLOUR,fullgrid   "Image existante"
-    opt_Files Fichiers
+    opt_Files "Port srie et fichiers"
     optDEFSPORT "Port Srie"
     optSAVESTATE "Sauvegarde de l'tat en quittant"
     optDELSTATE "Destruction des fichiers aprs avoir restaur l'tat"
@@ -440,6 +467,7 @@ array set TXT {
     YYYYMMDD   AAAAMMJJ
     MMDDYYYY   MMJJAAAA
     DDMMMYYYY   JJMMAAAA
+    YYYY-MM-DD  AAAA-MM-JJ
     mainwd   "Fentre principate"
     distazim   "Distance et direction"
     nearestWPs   "Points les plus proches"
@@ -456,7 +484,6 @@ array set TXT {
     joinGR   "Joindre au groupe"
     TRtoRT   "Conversion de trace en route"
     TRRTnpoints   "Nombre de points  garder"
-    TRRTdispl   "Affichage de la route"
     TRTRdispl   "Affichage de la trace"
     WP   WP
     RT   RT
@@ -712,6 +739,7 @@ array set TXT {
     longF "Longitude de l'origine errone"
     gkklong0 "Longitude du centre"
     kkjplong0 "Longitude du centre"
+    twglong0 "Longitude du centre"
     k0 "Facteur d'chelle"
     PRJUTM "UTM/UPS"
     PRJTM "Mercator Transverse"
@@ -773,7 +801,7 @@ array set TXT {
     posfixsimul simul
     restart "Redmarrage"
     mkTR "Faire une route"
-    PVTflds "# t lat long alt fix EPE EPH EPV vel_x vel_y vel_z CMG"
+    PVTflds "# t lat long alt fix EPE EPH EPV vel_x vel_y vel_z TRK"
     namePVTData "Journaliser les donnes"
     mkavgWP "Calcul du point moyen"
     move Dplacer
@@ -830,6 +858,193 @@ array set TXT {
     collcntr "Dtection des centres..."
     compclstr "Calcul des groupements..."
     crtgclstrgrs "Cration des groupes..."
+    PRJStereogr "Strographique"
+    PRJTWG "Grille taiwanaise"
+    chgdatum "Remplacer datum..."
+    optPRINTCMD "Commande d'impression"
+    optMAPFONTSIZE "Taille de police pour la carte"
+    print Impression
+    prevctr "Centre prcdent"
+    PRJSOM "Mercator Oblique Suisse"
+    PRJLV03 "Grille suisseLV03"
+    PRJIcG "Grille islandaise"
+    PRJRDG "Grille nerlandaise"
+    chgmfsize "Changement de taille pour la police de la carte"
+    printopt "Options d'impression"
+    numberid "Numro/Identifiant"
+    hiddendata "Donne masque"
+    YYYY/MM/DD  YYYY/MM/DD
+    cwpsdef "Dfinir les point de contrle"
+    nextTP "Prochain point de trace"
+    generate "Gnrer"
+    generateall "Gnrer tout"
+    optSERIALBAUD "Vitesse de transfert"
+    optDEFTRTWIDTH "Largeur des routes"
+    optDEFTTRWIDTH "Largeur des traces"
+    width "Largeur"
+    TRtoTR   "Simplication d'une trace"
+    TRlinedispl   "Affichage des rsultats"
+    obsTRsimpl "Trace rsultant d'une simplification"
+    simplTRto "Simplifier en"
+    exstglog "Journal existant"
+    contnsly "en continu"
+    animate "animer"
+    animabbrev "anim."
+    noanabbr "pas d'anim."
+    zelev "Echelle-Z"
+    xyelev "Echelle-XY"
+    notext "sans texte"
+    view "vue"
+    sideview "vue de cot"
+    persptv "Perspective"
+    SYgeocache "Gocache"
+    SYgeocache_fnd "Gocache trouve"
+    optMAPCOLOUR,trvtrk "Flche de trace"
+    optMAPCOLOUR,trvtrn "Flche "
+    optMAPCOLOUR,trvcts "Flche de course"
+    optMAPCOLOUR,trvcts2 "Seconde flche de course"
+    optMAPCOLOUR,trvvel_z "Flche haut/bas"
+    optMAPCOLOUR,trvwrnimportant "Avertissement important (nav)"
+    optMAPCOLOUR,trvwrnnormal "Avertissement (nav)"
+    optMAPCOLOUR,trvwrninfo "Information (nav)"
+    travel "Voyage"
+    notravel "Arrt du voyage"
+    optTRAVELFONTSIZE "Taille de la police d'affichage des voyages"
+    travdisplay "Configuration de l'affichage"
+    travchgdisplay "Changement pour l'affichage %s"
+    travdsetup "Configuration de l'affichage du voyage"
+    navMOB "Homme  la mer"
+    startnav "Navigation"
+    navWP "Aller au point"
+    goback "Retour"
+    follow "Suivre %s"
+    exactly "exactement"
+    fromnrst "depuis le plus prs"
+    inrvrs " l'envers"
+    forgetgoal "Oubli du but"
+    suspend "Suspension"
+    resume "Reprise"
+    TRVfix "Fix"
+    TRVhour "Heure"
+    TRVspeed "Vitesse"
+    TRVpos "Pos."
+    TRValt "Alt."
+    TRVtrk "Dir."
+    TRVnxtWP "Vers"
+    TRVprvWP "Depuis"
+    TRVete "ETE"
+    TRVeta "ETA"
+    TRVvmg "VMG"
+    TRVxtk "XTK"
+    TRVcts "Dir."
+    TRVtrn "Rot."
+    TRVvel_z "Vitesse vert."
+    TRVtrkcts "Trace, dir."
+    TRVdist "Dist"
+    TRVc_trkcts "Flche"
+    TRVc_trn "Flche"
+    TRVc_vel_z "Haut/Bas"
+    add "Ajout"
+    addlabelled "Ajout avec tiquette"
+    remove "Suppression"
+    mindist "Distance cible"
+    chginggoal "Changement vers le but suivant"
+    chggoalhlp "Changement depuis le but\ncourant jusqu'au prochain\nsur un route"
+    soon "bientt"
+    late "tard"
+    warnings "Avertissements"
+    dowarn "Emission d'avertissements"
+    warnconf "Configuration d'avertissements"
+    priority "Priorit"
+    high "haute"
+    medium "mdiane"
+    low "basse"
+    warnprox "Distance au point <"
+    warnanchor "Distance au point >"
+    warnspeed "Vitesse >"
+    warntrn "Rotation (abs.) >"
+    warnvspeed "Vitesse verticale"
+    warnxtk "XTK (abs)>"
+    fntsize "Taille de police"
+    trvhlpbox "Utiliser le bouton droit pour rordonnancer les lments ci-dessous"
+    trvhlpbxs "Utiliser le bouton droit pour rordonnancer les lments de la liste"
+    trvwarrv "Arrive  %s!"
+    trvwleave "Dpart de %s!"
+    trvwspeed "Vitesse > %s!"
+    trvwtrn "Rotation > %s!"
+    trvwvspeed "Vitesse verticale en dehors de [%s,%s]!"
+    trvwxtk "XTK > %s!"
+    trvwnolog "Journalisation en temps-rel arrte"
+    trvwnopos "Positions prcdentes indisponibles"
+    trvwuwps "La route a des points indfinis."
+    trvwchg "Aller au prochain %s"
+    TP "Point de trace"
+    drivesim "simulateur de conduite"
+    startfrom "Dpart depuis..."
+    outofctrl "Hors de contrle"
+    right "Droite"
+    left "Gauche"
+    straight "Tout droit"
+    rthlpdsim "Flches : conduite, changement de vitesse\nEspace : tout droit"
+    forgetGRcs "Oubli du groupe+els"
+    renres "NOUV"
+    chggoal "Changer pour le nouveau but"
+    Ghidden_class Classe
+    Ghidden_subclass "Sous-Classe"
+    Ghidden_lnk_ident "Identifiant de scne"
+    Ghidden_colour Couleur
+    Ghidden_attrs Attributs
+    Ghidden_depth Profondeur
+    Ghidden_state "Etat"
+    Ghidden_country Pays
+    Ghidden_facility "Immeuble"
+    Ghidden_city Ville
+    Ghidden_addr Adresse
+    Ghidden_int_road "Croisement de rues"
+    Ghidden_dtyp "Affichage options et type"
+    Ghidden_ete "ETE"
+    Ghidden_display "Affichage?"
+    Ghidden_yes Oui
+    Ghidden_no Non
+    Ghidden_user "Utilisateur"
+    Ghidden_user_symbol "Utilisateur (symbole uniquement)"
+    Ghidden_non_user "Non utilisateur"
+    Ghidden_avn_airport "Aroport"
+    Ghidden_avn_inters "Avn intersection"
+    Ghidden_avn_NDB "NDB"
+    Ghidden_avn_VOR "VOR"
+    Ghidden_avn_airp_rway "Seuil de piste d'aroport"
+    Ghidden_avn_airp_int "Intersection aroport"
+    Ghidden_avn_airp_NDB "Aroport NDB"
+    Ghidden_map_pt "Point de carte"
+    Ghidden_map_area "Zone de carte"
+    Ghidden_map_int "Intersection de carte"
+    Ghidden_map_addr "Adresse de carte"
+    Ghidden_map_label "Etiquette de carte"
+    Ghidden_map_line "Ligne de carte"
+    Ghidden_locked "Verrouill"
+    Ghidden_default "Defaut"
+    Ghidden_black Noir
+    Ghidden_white Blanc
+    Ghidden_red Rouge
+    Ghidden_dark_red "Rouge fonc"
+    Ghidden_green Vert
+    Ghidden_dark_green "Vert fonc"
+    Ghidden_blue Bleu
+    Ghidden_dark_blue "Bleu fonc"
+    Ghidden_yellow Jaune
+    Ghidden_dark_yellow "Jaune fonc"
+    Ghidden_magenta Magenta
+    Ghidden_dark_magenta "Magenta fonc"
+    Ghidden_cyan Cyan
+    Ghidden_dark_cyan "Cyan fonc"
+    Ghidden_light_gray "Gris clair"
+    Ghidden_dark_gray "Gris fonc"
+    Ghidden_line Ligne
+    Ghidden_link Etape
+    Ghidden_net "Rseau"
+    Ghidden_direct Direct
+    Ghidden_snap Snap
 }
 
     # the following definitions must be coherent with $TXT
