@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2002 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2003 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,11 +17,9 @@
 #      along with this program.
 #
 #  File: langit.tcl
-#  Last change:  1 February 2002
-# Italian language file by Alessandro Palmas (alpalmas@tin.it)
-#  Last change by him: Sat Jul 22 17:06:06 CEST 2000
-#  ALPHA VERSION
-#  last input from him inserted: 31 January 2002
+#  Last change:  6 February 2003
+#  Italian language file by Alessandro Palmas (alpalmas@tin.it)
+#  last input from him inserted: 2 February 2003
 #
 
 # file langengl.tcl is consulted first; no need for duplicating entries here
@@ -131,19 +129,15 @@ array set MESS {
     badserial "Non posso aprire comunicazione su seriale %s"
     nodata    "Non ci sono %s nel ricevitore"
     badimage "File immagine scorretto"
-    mapaskWPs "Scegliere %d WP da posizionare sulla mappa"
     mapadjust "Posizionare i WP sulla mappa; click su Ok quando si ha finito"
     duplicate "%s gi selezionato"
     clrcurrmap "Cancellare la mappa corrente?"
-    cantfix "Per referenziare la mappa occorrono %d WP; dovete prima caricare o definire qualche WP"
     mbkbaddatum "Map Datum assente o sconosciuto"
     mbkbadscale "La scala NON deve essere negativa"
     mbkbadat "Argomenti scorretti"
     edityourrisk "Editate a vostro rischio e pericolo!"
     okclrbkmap   "Ok per cancellare la mappa di sfondo"
     okclrbkim    "Ok per cancellare immagine a"
-    badWPfield "Campo opzionale errato"
-    badWPattr "Nome di campo opzionale sconosciuto"
     goingdown "Preferenze salvate; si prega di riavviare"
     putwhat "Quali tipi di oggetti inviare?"
     readwhat "Quali tipi di oggetti leggere?"
@@ -235,8 +229,37 @@ array set MESS {
     badinvproj "Errore di approssimazione invertendo la proiezione %s"
     negdlatlong "L'escursione lat/long non deve essere negativa"
     allundef "I WP non sono definiti nel GR"
-    badfloats "Le conversioni in virgola mobile non funzionano correttamente; 
-siete sicuri di volervi connettere?"
+    badfloats "Le conversioni in virgola mobile non funzionano correttamente; siete sicuri di volervi connettere?"
+    noprintcmd "Comando di stampa non selezionato; selezionarne uno nelle opzioni"
+    cantexecasroot "GPSMan non pu essere eseguito da root"
+    badargtofunc "Argomenti non corretti per la funzione %s"
+    redefproj "La proiezione %s definita dall'utente sovrascrive una proiezione predefinita con lo stesso nome breve; Per cortesia cambiate la vostra definizione"
+    badattr "Nome di campo opzionale %s sconosciuto: %s"
+    badattrval "valore del capo opzionale %s errato: %s"
+    couldntcd "tentativo di andare nella directory %s fallito"
+    shpext "Extensione %si non corretta; cwva bene usare .shp, .shx, .dbf?"
+    shpcntopen "Non riesco a creare/aprire  file Shapefile"
+    shpcntcrtfs "Non riesco a creare i campi Shapefile .dbf"
+    shpcntwrtfs "Non riesco a scrivere i campi Shapefile .dbf"
+    shpoutmem "Memoria insufficiente!"
+    shpemptyfile "File vuoto"
+    shpwrongfile "Tipo di file non valido"
+    shplessdim "La dimensione nel file  inferiore a quanto richiesto; continuo?"
+    shpbadWPinRT "%d WP con coordinate errate ignorato nella RT %s"
+    badGTMvers "Versione file GTrackMaker non accettabile"
+    badGTMfile "Stringa iniziale errata per file GTrackMaker"
+    badGTMcounts "Contatore/i negativi nel file GTrackMaker"
+    badGTMlat "Latitudine fuori intervallo nel file GTrackMaker"
+    badGTMlong "Longitudine fuori intervallo nel file GTrackMaker"
+    badGTMdatum "Datum errato nel file GTrackMaker"
+    unobscmap "Errore, probabilmente perch c' una finestra/icona sulla mappa; ritentare dopo attesa?"
+    cantwrtimg "Errore nella scrittura dell'immagine su file in formato %s"
+    TRsimplres "TR risultanti dalla semplificazione creati sotto il nome %s"
+    cantsaveRTid "%d RT non salvata/e: identificatore non numerico"
+    badtrvconf "Configuratione corrotta; ripartire con una vuota"
+    drvsimoff "simulatore di guida: non ancora partito!"
+    needWP "Simulatore di guida: prego voler caricare o definire alcuni WP"
+    chgrecprot "Prego cambiare il protocollo del ricevitore"
 }
 
 set TXT(RTcompflds) "# WP {$DTUNIT} deg m stage label"
@@ -326,7 +349,6 @@ array set TXT {
     chophd   "Taglia la testa"
     choptl   "Taglia la coda"
     incb   "Includi Prima"
-    mkRT   "Costruisci RT"
     date   Data
     newdate   "Nuova data per il prossimo punto"
     endprTR   "Fine della traccia precedente"
@@ -352,7 +374,7 @@ array set TXT {
     optMWINDOWSCONF  "Finestra principale"
     opt_GPSRecConf   "Parametri del ricevitore"
     optGPSREC   "Modello GPS"
-    opt_Interf Interfaccia
+    opt_Interf "Interfaccia utente"
     optNAMELENGTH   "Max lungh nomi"
     optINTERVAL "Intervallo di campionamento"
     optCOMMENTLENGTH   "Max lungh commento"
@@ -415,7 +437,7 @@ array set TXT {
     optMAPCOLOUR,anim       "Animazione su mappa"
     optMAPCOLOUR,emptygrid  "Immagine vuota"
     optMAPCOLOUR,fullgrid   "Immagine esistente"
-    opt_Files Files
+    opt_Files "Serial port and files"
     optDEFSPORT "I/O seriale"
     optPERMS   "Permessi file"
     optPAPERSIZE "Formato carta"
@@ -444,7 +466,6 @@ array set TXT {
     joinGR   "Unisci Gruppi"
     TRtoRT   "Conversione da TR a RT"
     TRRTnpoints   "N. punti da conservare"
-    TRRTdispl   "Mostra RT ora"
     TRTRdispl   "Mostra TR ora"
     WP   WP
     RT   RT
@@ -789,6 +810,131 @@ array set TXT {
     PRJStereogr "Stereografica"
     PRJTWG "Griglia di Taiwan"
     chgdatum "Cambia datum"
+    optPRINTCMD "Comando di stampa"
+    optMAPFONTSIZE "Dimensioni font mappa"
+    print Stampa
+    prevctr "Centro precedente"
+    PRJSOM "Obliqua di Mercatore - Svizzera"
+    PRJLV03 "Griglia svizzera LV03"
+    PRJIcG "Griglia islandese"
+    PRJRDG "Griglia Olandese"
+    chgmfsize "Cambia dimensione font mappa"
+    printopt "Opzioni di stampa"
+    numberid "Num/Id"
+    hiddendata "Dati protetti"
+    YYYY/MM/DD  YYYY/MM/DD
+    cwpsdef "I WP di taratura vanno definiti ora"
+    nextTP "Prossimo TP"
+    generate Generare
+    generateall "Genera tutti"
+    optSERIALBAUD "Baud Rate"
+    optDEFTRTWIDTH "Larghezza linee RT"
+    optDEFTTRWIDTH "Larghezza linee TR"
+    width Larghezza
+    TRtoTR   "Semplificazione TR"
+    TRlinedispl   "Mostra il risultato adesso"
+    obsTRsimpl "TR risultante da semplificazione"
+    simplTRto "Semplifica in"
+    exstglog "Log esistente"
+    contnsly "Continuamente"
+    animate "anima"
+    animabbrev "anim."
+    noanabbr "no anim."
+    zelev "Scala rilievo"
+    xyelev "Ingrandimento piano orizz."
+    notext "no testo"
+    view "Mostra"
+    sideview "Profilo"
+    persptv "Prospettiva"
+    SYgeocache "Geocache"
+    SYgeocache_fnd "Geocache trovata"
+    optMAPCOLOUR,trvtrk "Freccia TRK"
+    optMAPCOLOUR,trvtrn "Frecce TRN"
+    optMAPCOLOUR,trvcts "Freccia CTS"
+    optMAPCOLOUR,trvcts2 "Seconda freccia CTS"
+    optMAPCOLOUR,trvvel_z "Freccia Su/gi"
+    optMAPCOLOUR,trvwrnimportant "Avviso importante (nav)"
+    optMAPCOLOUR,trvwrnnormal "Avviso (nav)"
+    optMAPCOLOUR,trvwrninfo "Informazione (nav)"
+    travel Viaggio
+    notravel "Stop navigazione"
+    optTRAVELFONTSIZE "Dimensione caratteri schermata viaggio"
+    travdisplay "Configura schermata"
+    travchgdisplay "Vai alla schermata %s"
+    travdsetup "Configurare schermata viaggio"
+    navMOB "MOB: Uomo In Mare! (Man Over Board)"
+    startnav "Navigare"
+    navWP "Vai a WP"
+    goback "Torna indietro"
+    follow "Segui %s"
+    exactly "esattamente"
+    fromnrst "Dal pi vicino"
+    inrvrs "al contrario"
+    forgetgoal "Dimentica la meta"
+    suspend "Sospendi"
+    resume "Riprendi"
+    TRVfix "Fix"
+    TRVhour "Tempo"
+    TRVspeed "Velocita"
+    TRVpos "Pos"
+    TRValt "Alt"
+    TRVtrk "TRK"
+    TRVnxtWP "A"
+    TRVprvWP "Da"
+    TRVete "ETE"
+    TRVeta "ETA"
+    TRVvmg "VMG"
+    TRVxtk "XTK"
+    TRVcts "CTS"
+    TRVtrn "TRN"
+    TRVvel_z "V speed"
+    TRVtrkcts "TRK, CTS"
+    TRVdist "Dist"
+    TRVc_trkcts "Frecce TRK/CTS"
+    TRVc_trn "Frecce TRN"
+    TRVc_vel_z "Freccia su/gi"
+    add "Aggiungi"
+    addlabelled "Aggingi con nome"
+    remove "Rimuovi"
+    mindist "Distanza minima per arrivo"
+    chginggoal "Cambia e vai alla prossima meta"
+    chggoalhlp "Quando cambiare dalla\nmeta attuale alla prossima\nseguendo una RT/TR"
+    soon presto
+    late tardi
+    warnings "Avvertimenti"
+    dowarn "Emetti avvertimenti"
+    warnconf "Configura avvertimenti"
+    priority Priorit
+    high alta
+    medium media
+    low bassa
+    warnprox "Distanza dal WP <"
+    warnanchor "Distanza dal WP >"
+    warnspeed "Velocit >"
+    warntrn "TRN (abs)>"
+    warnvspeed "Velocit verticale"
+    warnxtk "XTK (abs)>"
+    fntsize "Dimensione caratteri"
+    trvhlpbox "Usare il tasto destro del mouse per\nriordinare gli elementi sottostanti"
+    trvhlpbxs "Usare il tasto destro del mouse per\nriordinare gli elementi della lista"
+    trvwarrv "Stiamo per arrivare a %s!"
+    trvwleave "Stiamo lasciando %s!"
+    trvwspeed "Velocit > %s!"
+    trvwtrn "TRN > %s!"
+    trvwvspeed "Velocit vert. non entro [%s,%s]!"
+    trvwxtk "XTK > %s!"
+    trvwnolog "Real-time logging NON attivo!"
+    trvwnopos "Posizione precedente non disponibile"
+    trvwuwps "RT ha WP non definiti"
+    trvwchg "Ora andiamo verso %s"
+    TP TP
+    drivesim "simulatore di guida"
+    startfrom "Parti da..."
+    outofctrl "Fuori controllo!"
+    right Destra
+    left Sinistra
+    straight Dritto
+    rthlpdsim "Tasti frecce: sterza, accelera, decelera\nBarra spaziatrice: dritto"
 }
 
     # the following definitions must be coherent with $TXT
