@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2002 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2003 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: langport.tcl
-#  Last change:  1 February 2002
+#  Last change:  6 February 2003
 #
 
 # file langengl.tcl is consulted first; no need for duplicating entries here
@@ -130,19 +130,17 @@ array set MESS {
     badserial "Sem acesso  porta srie %s"
     nodata    "O receptor no tem %ss"
     badimage "Ficheiro de imagem no aceite"
-    mapaskWPs "Escolha %d PTs a colocar no mapa"
     mapadjust "Coloque os PTs no mapa; carregue depois em Ok"
     duplicate "%s j escolhido"
     clrcurrmap "Apagar mapa existente?"
-    cantfix "Precisa %d PTs para fixar o mapa; defina-os ou carregue-os primeiro"
     mbkbaddatum "Sem datum vlido"
     mbkbadscale "A escala no pode ser negativa"
     mbkbadat "Argumentos errados"
     edityourrisk "Mude  sua responsabilidade!"
     okclrbkmap   "Ok para apagar fundo do mapa"
     okclrbkim   "Ok para apagar imagem em"
-    badWPfield "Campo opcional invlido"
-    badWPattr "Nome de campo opcional desconhecido"
+    badattrval "Campo opcional invlido (%s): %s"
+    badattr "Nome de campo opcional desconhecido (%s): %s"
     badSYMBOLcode "Cdigo de smbolo errado"
     badDISPOPTcode "Cdigo errado de forma de mostrar errado"
     goingdown "Opes guardadas; recomear"
@@ -233,6 +231,37 @@ array set MESS {
     negdlatlong "Diferena em lat/long no pode ser negativa!"
     allundef "Nenhum dos PTs do GR est definido"
     badfloats "H erros nas converses de nmeros decimais; ligar mesmo assim?"
+    noprintcmd "Falta comando para imprimir; definir nas opes"
+    cantexecasroot "GPSMan no pode ser executado pela root"
+    badargtofunc "Argumento errado na funo %s"
+    redefproj "Abreviatura da projeco %s coincide com o de projeco pr-definida, apagando-a; mude a sua definio!"
+    couldntcd "Impossvel mudar para o directrio %s"
+    shpext "Extenso %s errada; ok para usar .shp, .shx, .dbf?"
+    shpcntopen "Impossvel abrir/criar ficheiros Shapefile"
+    shpcntcrtfs "Impossvel criar campos Shapefile .dbf"
+    shpcntwrtfs "Impossvel escrever campos Shapefile .dbf"
+    shpoutmem "Falta memria!"
+    shpemptyfile "Ficheiro vazio"
+    shpwrongfile "Tipo de ficheiro errado"
+    shplessdim "Dimenso no ficheiro menor que a pedida; continuar?"
+    shpbadWPinRT "WP no. %d com coordenadas erradas ignorado na RT %s"
+    errorGTMread "Erro ao ler de ficheiro GTrackMaker"
+    badGTMvers "Verso no suportada do GTrackMaker"
+    badGTMfile "Incio errado no ficheiro GTrackMaker"
+    badGTMcounts "Contador(es) negativos no ficheiro GTrackMaker"
+    badGTMlat "Latitude errada no ficheiro GTrackMaker"
+    badGTMlong "Longitude errada no ficheiro GTrackMaker"
+    badGTMdatum "Datum invlido no ficheiro GTrackMaker"
+    unobscmap "Erro talvez por haver 1 janela/cone sobre o mapa; esperar e voltar a tentar?"
+    cantwrtimg "Erro ao guardar imagem em ficheiro no formato %s"
+    TRsimplres "TR resultante da simplificao criado com nome %s"
+    cantsaveRTid "%d RT(s) por salvar: identificador no numrico"
+    badtrvconf "Configurao inconsistente substituda por uma vazia"
+    drvsimoff "Simulador de conduo: falta iniciar!"
+    needWP "Simulador de conduo:  preciso definir ou ler PTs"
+    chgrecprot " favor seleccionar outro protocolo do receptor"
+    clrtrvlog "Apagar registo da viagem?"
+    frgetGRcs "Esquecer grupo e todos os elementos?!"
 }
 
 set TXT(RTcompflds) "# PT {$DTUNIT} grau m etapa etiq"
@@ -313,6 +342,7 @@ array set TXT {
     startRT "Iniciar RT"
     route   Rota
     number   Nmero
+    numberid "Nmero/Id"
     insb   "Inserir antes"
     insa   "Inserir depois"
     del   Apagar
@@ -326,7 +356,6 @@ array set TXT {
     chophd   "Cortar cabea"
     choptl   "Cortar cauda"
     incb   "Incluir antes"
-    mkRT   "Transf em Rota"
     date   Data
     newdate   "Nova data para o ponto seguinte"
     endprTR   "Fim do trajecto anterior"
@@ -346,12 +375,15 @@ array set TXT {
     change   Mudar
     forget   Esquecer
     others   Outros
+    opt_Interf "Interface do utilizador"
     optLANG   Lngua
     optISOLATIN1   "Acentos e cedilha"
     optDELETE   "DEL apaga ltimo caracter"
     optMWINDOWSCONF  "Janela principal"
+    optSERIALBAUD "Baud rate"
     optGPSREC   "Modelo do GPS"
     opt_GPSRecConf   "Parmetros do Receptor"
+    optACCEPTALLCHARS "Aceitar qualquer caracter"
     optNAMELENGTH   "Compr mx p/ nomes"
     optINTERVAL "Intervalo de amostragem"
     optCOMMENTLENGTH   "Compr mx p/ comentrios"
@@ -422,12 +454,16 @@ array set TXT {
     optMAPCOLOUR,anim "Animao no mapa"
     optMAPCOLOUR,emptygrid  "Sem imagem"
     optMAPCOLOUR,fullgrid   "Com imagem"
-    opt_Files Ficheiros
+    optMAPFONTSIZE "Tamanho de letra, mapa"
+    optDEFTRTWIDTH "Espessura RT"
+    optDEFTTRWIDTH "Espessura TR"
+    opt_Files "Porta srie e ficheiros"
     optDEFSPORT "Porta srie"
     optSAVESTATE "Guardar estado ao sair"
     optDELSTATE "Apagar ficheiros de estado"
     optPERMS   "Permisses de ficheiro"
     optPAPERSIZE "Tamanho do papel"
+    optPRINTCMD "Comando para imprimir"
     red   Verm
     green   Verde
     blue   Azul
@@ -441,6 +477,7 @@ array set TXT {
     MMDDYYYY   MMDDAAAA
     DDMMMYYYY   DDMMMAAAA
     YYYY-MM-DD  AAAA-MM-DD
+    YYYY/MM/DD  AAAA/MM/DD
     mainwd   "Janela principal"
     distazim   "Dist e azimute"
     nearestWPs   "PTs prximos"
@@ -456,9 +493,10 @@ array set TXT {
     insert   Inserir
     joinGR   "Juntar Grupo"
     TRtoRT   "Converso de TR para RT"
+    TRtoTR   "Simplificao de TR"
     TRRTnpoints   "No. de pontos a reter"
-    TRRTdispl   "Desenhar RT j"
-    TRTRdispl   "Desenhar TR j"
+    TRlinedispl   "Desenhar resultado"
+    TRTRdispl   "Desenhar TR"
     WP   PT
     RT   RT
     TR   TR
@@ -549,6 +587,8 @@ array set TXT {
     SYfreeway "Via rpida"
     SYfuel "Gasolina"
     SYfuel_store "Gasolina & loja"
+    SYgeocache "Geocache"
+    SYgeocache_fnd "Geocache descoberta"
     SYgeo_name_land "Nome geogr, terra"
     SYgeo_name_man "Nome geogr, homem"
     SYgeo_name_water "Nome geogr, gua"
@@ -658,6 +698,7 @@ array set TXT {
     contrib "Com contribuies de"
     errorsto "Em caso de erro, contactar:"
     obsTRToRT "PTs criados pela converso de TR em RT"
+    obsTRsimpl "TR obtido por simplificao"
     nameLists "Listas"
     nameData "Dados"
     MWCmap "Mapa"
@@ -716,6 +757,10 @@ array set TXT {
     PRJAPOLY "Policnica Americana"
     PRJStereogr "Estereogrfica"
     PRJTWG "Grelha de Taiwan"
+    PRJSOM "Oblqua de Mercator Suia"
+    PRJLV03 "Grelha Suia LV03"
+    PRJIcG "Grelha Islandesa"
+    PRJRDG "Grelha Holandesa"
     dontaskagain "Deixar de confirmar"
     rename "Usar nome diferente"
     oname "Nome original"
@@ -749,7 +794,7 @@ array set TXT {
     posfixerror erro
     restart Recomear
     mkTR "Criar TR"
-    PVTflds "# t lat long alt qual EPE EPH EPV vel_x vel_y vel_z CMG"
+    PVTflds "# t lat long alt qual EPE EPH EPV vel_x vel_y vel_z rumo"
     namePVTData Registo
     mkavgWP "Criar PT mdio"
     move Recolocar
@@ -799,6 +844,175 @@ array set TXT {
     compclstr "A agrupar vizinhos..."
     crtgclstrgrs "A criar grupos..."
     chgdatum "Mudar datum..."
+    print Imprimir
+    prevctr "Centro anterior"
+    printopt "Opes impresso"
+    chgmfsize "Mudar tamanho das letras"
+    cwpsdef "PTs de controle a definir agora"
+    nextTP "Prximo PTR"
+    generate Gerar
+    generateall "Gerar todos"
+    width Espessura
+    simplTRto "Simplificar p/"
+    exstlgog "Registo existente"
+    contnsly "Continuamente"
+    animate "animar"
+    animabbrev "anim."
+    noanabbr "s/ anim."
+    notext "s/ legendas"
+    lockscale "fixar escala"
+    zelev "inclinao Z"
+    xyelev "inclinao XY"
+    view "Vista"
+    sideview "Vista lateral"
+    persptv "Perspectiva"
+    optMAPCOLOUR,trvtrk "Seta TRK"
+    optMAPCOLOUR,trvtrn "Setas TRN"
+    optMAPCOLOUR,trvcts "Seta CTS"
+    optMAPCOLOUR,trvcts2 "2a seta CTS"
+    optMAPCOLOUR,trvvel_z "Seta para cima/baixo"
+    optMAPCOLOUR,trvwrnimportant "Aviso importante (nav)"
+    optMAPCOLOUR,trvwrnnormal "Aviso (nav)"
+    optMAPCOLOUR,trvwrninfo "Informao (nav)"
+    optTRAVELFONTSIZE "Tamanho de letra, viagem"
+    travel Viagem
+    notravel "Fim de viagem"
+    travdisplay "Configurar mostrador"
+    travchgdisplay "Mudar para mostrador %s"
+    travdsetup "Configurar mostrador de viagem"
+    navMOB "Homem ao mar (MOB)!"
+    startnav "Navegar"
+    navWP "Ir para PT"
+    goback "Regressar"
+    follow "Seguir %s"
+    exactly "exactamente"
+    fromnrst "do ponto mais prximo"
+    inrvrs "em sentido inverso"
+    forgetgoal "Desistir do objectivo"
+    suspend "Suspender"
+    resume "Recomear"
+    TRVfix "Sinal"
+    TRVhour "Tempo"
+    TRVspeed "Vel"
+    TRVpos "Pos"
+    TRValt "Alt"
+    TRVtrk "TRK"
+    TRVnxtWP "Para"
+    TRVprvWP "De"
+    TRVete "ETE"
+    TRVeta "ETA"
+    TRVvmg "VMG"
+    TRVxtk "XTK"
+    TRVcts "CTS"
+    TRVtrn "TRN"
+    TRVvel_z "Vel vert"
+    TRVtrkcts "TRK, CTS"
+    TRVdist "Dist"
+    TRVc_trkcts "Setas TRK/CTS"
+    TRVc_trn "Setas TRN"
+    TRVc_vel_z "Setas cima/baixo"
+    add "Acrescentar"
+    addlabelled "Acresc com nome"
+    remove "Remover"
+    mindist "Distncia de chegada"
+    chggoal "Objectivo seguinte"
+    chginggoal "Mudana de objectivo"
+    chggoalhlp "Quando mudar de um\nobjectivo para o seguinte\nao seguir RT/TR"
+    soon cedo
+    late tarde
+    warnings "Avisos"
+    dowarn "Fazer avisos"
+    warnconf "Configurar avisos"
+    priority Prioridade
+    high alta
+    medium mdia
+    low baixa
+    warnprox "Distncia a PT <"
+    warnanchor "Distncia a PT >"
+    warnspeed "Velocidade >"
+    warntrn "TRN (abs)>"
+    warnvspeed "Vel vertical"
+    warnxtk "XTK (abs)>"
+    fntsize "Tamanho da letra"
+    trvhlpbox "Usar boto direito para reordenar elementos abaixo"
+    trvhlpbxs "Usar boto direito para\nreordenar elementos das listas"
+    trvwarrv "Chegada a %s!"
+    trvwleave "Deixando %s!"
+    trvwspeed "Velocidade > %s!"
+    trvwtrn "TRN > %s!"
+    trvwvspeed "Vel vert fora de [%s,%s]!"
+    trvwxtk "XTK > %s!"
+    trvwnolog "Registo em tempo real desligado!"
+    trvwnopos "No h posies anteriores"
+    trvwuwps "RT tem PT(s) no definidos"
+    trvwchg "Indo para %s"
+    TP TP
+    drivesim "simulador de conduo"
+    startfrom "Comear de..."
+    outofctrl "Sem control!"
+    right Direita
+    left Esquerda
+    straight "Em frente"
+    rthlpdsim "Teclas de seta: guiar, des/acelerar\nEspao: em frente"
+    hiddendata "Dados ocultos"
+    Ghidden_class Classe
+    Ghidden_subclass Sub-classe
+    Ghidden_lnk_ident "Id etapa"
+    Ghidden_colour Cor
+    Ghidden_attrs Atributos
+    Ghidden_depth Profundidade
+    Ghidden_state Estado
+    Ghidden_country Pas
+    Ghidden_facility Facility
+    Ghidden_city Cidade
+    Ghidden_addr Endereo
+    Ghidden_int_road "Cruzamento"
+    Ghidden_dtyp "Mostrar+tipo"
+    Ghidden_ete "ETE"
+    Ghidden_display "Mostrar?"
+    Ghidden_yes Sim
+    Ghidden_no No
+    Ghidden_user "Utilizador"
+    Ghidden_user_symbol "Utilizador (apenas smbolo)"
+    Ghidden_non_user "Interno"
+    Ghidden_avn_airport "Aeroporto"
+    Ghidden_avn_inters "Interseco (av)"
+    Ghidden_avn_NDB "NDB"
+    Ghidden_avn_VOR "VOR"
+    Ghidden_avn_airp_rway "Limite de pista (aeroporto)"
+    Ghidden_avn_airp_int "Interseco (aeroporto)"
+    Ghidden_avn_airp_NDB "NDB (aeroporto)"
+    Ghidden_map_pt "Ponto (mapa)"
+    Ghidden_map_area "rea (mapa)"
+    Ghidden_map_int "Interseco (mapa)"
+    Ghidden_map_addr "Endereo (mapa)"
+    Ghidden_map_label "Etiqueta (mapa)"
+    Ghidden_map_line "Linha (mapa)"
+    Ghidden_locked Bloqueado
+    Ghidden_default "Normal"
+    Ghidden_red Vermelho
+    Ghidden_green Verde
+    Ghidden_blue Azul
+    Ghidden_black Preto
+    Ghidden_dark_red "Vermelho escuro"
+    Ghidden_dark_green "Verde escuro"
+    Ghidden_dark_yellow "Amarelo escuro"
+    Ghidden_dark_blue "Azul escuro"
+    Ghidden_dark_magenta "Magenta escuro"
+    Ghidden_dark_cyan "Ciano escuro"
+    Ghidden_light_gray "Cinzento claro"
+    Ghidden_dark_gray "Cinzento escuro"
+    Ghidden_yellow Amarelo
+    Ghidden_magenta Magenta
+    Ghidden_cyan Ciano
+    Ghidden_white Branco
+    Ghidden_line Linha
+    Ghidden_link Etapa
+    Ghidden_net Rede
+    Ghidden_direct Directo
+    Ghidden_snap Colado
+    renres "NOVOS NOMES"
+    forgetGRcs "Esquecer GR&Els"
 }
 
     # the following definitions must be coherent with $TXT
