@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2001 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2003 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,15 +17,17 @@
 #      along with this program.
 #
 #  File: main.tcl
-#  Last change:  20 November 2001
+#  Last change:  20 March 2003
 #
-# Includes contributions by Brian Baulch (baulchb@onthenet.com.au)
-#  marked "BSB contribution"
+# Includes contributions by
+#  - Brian Baulch (baulchb@onthenet.com.au) marked "BSB contribution"
+#  - Matt Martin (matt.martin@ieee.org) marked "MGM contribution"
+#  - Valere Robin (valere.robin@wanadoo.fr) marked "VR contribution"
 #
 
 set VERSIONDATE(day) 20
-set VERSIONDATE(month) 11
-set VERSIONDATE(year) 2001
+set VERSIONDATE(month) 3
+set VERSIONDATE(year) 2003
 
       # this test here prevents errors in the lang*.tcl files
 if { [lsearch -exact "KM NAUTMILE STATMILE" $DISTUNIT] == -1 } {
@@ -69,16 +71,28 @@ set SUBDSCALE $DSCALEFOR(sub,$DISTUNIT)
 set ASCALE $ASCALEFOR($DISTUNIT)
 
 set MAPDISTS $MAPDISTSFOR($DISTUNIT)
+set MAPFTSIZES "Tcl/Tk 9 10 11 12 14 18 24 36"
 
-set KNOWNLANGS {engl fr deutsch it port}
+set KNOWNLANGS {engl fr deutsch id it nl port}
+
+# know date formats are the indices of this array (for their widths in chars)
+array set DATEW {
+    YYYYMMDD   19
+    YYYY-MM-DD 21
+    MMDDYYYY   19
+    DDMMMYYYY  20
+    YYYY/MM/DD 19
+}
 
 # names of known languages in their own language
 array set TXT {
-    deutsch  Deutsch
-    engl   English
-    fr     Franais
-    it     Italiano
-    port   Portugus
+    LANGdeutsch  Deutsch
+    LANGengl   English
+    LANGfr     Franais
+    LANGid     {Bahasa Indonesia}
+    LANGit     Italiano
+    LANGnl     Nederlands
+    LANGport   Portugus
 }
 
 # other source files
@@ -108,7 +122,7 @@ if { int($TimeOffset) != $TimeOffset } {
     exit 1
 }
 
-set VERSION 5.4.1
+set VERSION 6.0.1
 
 set UDatums "" ; set UEllipsoids ""
 set WindowStack ""
@@ -123,15 +137,22 @@ proc AboutInfo {w} {
 	label $w.fr.im -image $Logo -relief sunken
 	pack $w.fr.im
     }
-    set d [lindex [FormatDate $DateFormat $VERSIONDATE(year) \
-	               $VERSIONDATE(month) $VERSIONDATE(day) 0 0 0] 0]
+    set d [FormatDay $DateFormat $VERSIONDATE(year) $VERSIONDATE(month) \
+	             $VERSIONDATE(day)]
     label $w.fr.title -text "$TXT(GMtit) $VERSION / $d" -relief sunken
     message $w.fr.text -aspect 800 \
 	    -text "Copyright (c) $VERSIONDATE(year) \
 Miguel Filgueiras / DCC-FC & LIACC / Universidade do Porto\n\
-$TXT(contrib) Brian Baulch (baulchb@onthenet.com.au)\n\
-$TXT(contrib) Andreas Lange (andreas.lange@rhein-main.de)\n\
-$TXT(contrib) Alessandro Palmas (alpalmas@tin.it)\n\n\
+$TXT(contrib):\n\
+*   Brian Baulch (baulchb@onthenet.com.au)\n\
+*   Andreas Lange (Andreas.C.Lange@GMX.de)\n\
+*   Alessandro Palmas (alpalmas@tin.it)\n\
+*   Valre Robin (valere.robin@wanadoo.fr)\n\
+*   Rob Buitenhuis (rob@buitenhs.demon.nl)\n\
+*   Tri Agus Prayitno (acuss@bk.or.id)\n\
+*   Matt Martin (matt.martin@ieee.org)\n\
+*   Stefan Heine (stefan.heinen@djh-freeweb.de)\n\
+*   Sabine Broda (sbb@ncc.up.pt)\n\n\
 $TXT(errorsto) mig@ncc.up.pt"
 
     pack $w.fr -side top
@@ -139,35 +160,26 @@ $TXT(errorsto) mig@ncc.up.pt"
     return
 }
 
-proc MakeDir {path} {
-    # make directory under Unix(-like) system
-    # take care of "~" replacement
-    # return 0 on failure
-
-    if { [string first ~ $path] == 0 } {
-	set e [exec env]
-	if { [set i [lsearch -glob $e HOME*]] == -1 } { return 0 }
-	regsub HOME= [lindex $e $i] "" h
-	set path ${h}[string range $path 1 end]
-    }
-    set a [exec mkdir $path]
-    if { "$a" == "" } { return 1 }
-    return 0
-}
-
-### images needed for start up
+### images needed when starting up
 InitSymbolImages
 
-if { [catch "set Logo [image create photo \
-	-file [file join $SRCDIR gmicons gpsman-logo.gif]]"] } {
-    set Logo ""
+foreach v "Logo SmallLogo" f "gpsman-logo.gif gpsman-logo-small.gif" {
+    if { [catch {set $v [image create photo \
+	    -file [file join $SRCDIR gmicons $f]]}] } {
+	set $v ""
+    }
 }
 
-### if no user data directory force one being created
+### on Unix systems GPSMan cannot be executed as root for security reasons
+if { $UNIX && "$env(USER)" == "root" } {
+    GMMessage $MESS(cantexecasroot)
+    exit 1
+}
+
+### if no user GPSMan-data directory force one being created
 if { $InitDir } {
-    if { "$tcl_platform(platform)" != "unix" || \
-	    ! [GMConfirm [format $MESS(oktomkdir) $USERDIR]] || \
-	    ! [MakeDir $USERDIR] } {
+    if { ! [GMConfirm [format $MESS(oktomkdir) $USERDIR]] || \
+	    [catch {file mkdir $USERDIR}] } {
 	GMMessage [format $MESS(createdir) $USERDIR]
 	exit 1
     }
@@ -194,6 +206,11 @@ foreach f $SRCFILESFOR($MYGPS) {
     source [file join $SRCDIR $f.tcl]
 }
 
+  # files that may depend on the preferences file
+foreach f $SRCFILESEND {
+    source [file join $SRCDIR $f.tcl]
+}
+
   # conditional files
 foreach p $SRCFILESCOND {
     if { [set [lindex $p 0]] } {
@@ -201,11 +218,18 @@ foreach p $SRCFILESCOND {
     }
 }
 
-  # files that may depend on the preferences file
-foreach f $SRCFILESEND {
-    source [file join $SRCDIR $f.tcl]
+  # user code
+set ucode [file join $USERDIR patch.tcl]
+if { [file exists $ucode] } {
+    source $ucode
+    set VERSION "$VERSION-patched"
 }
 
+##### Img library
+
+ # xbm gives black images
+set ImgOutFormats {bmp gif jpeg png tiff xpm}
+
 ##### initialize interface
 
 set NAMEWIDTH [expr $NAMELENGTH+2]
@@ -214,10 +238,6 @@ set COMMENTWIDTH [expr $COMMENTLENGTH+2]
 set OBSWIDTH 40
 set OBSHEIGHT 3
 
-set DATEW(YYYYMMDD) 19
-set DATEW(MMDDYYYY) 19
-set DATEW(DDMMMYYYY) 20
-
 set DATEWIDTH $DATEW($DateFormat)
 
 set SUBDTUNIT $DLUNIT($DISTUNIT,subdist)
@@ -251,15 +271,16 @@ proc GMInit {} {
     # set up main window(s)
     global MAPHEIGHT MAPWIDTH LISTWIDTH LISTHEIGHT COLOUR MAPCOLOUR \
 	    VERSION SRCDIR LPOSX LPOSY MPOSX MPOSY RPOSX RPOSY \
-	    MAPSCALE MAPDISTS MAPSCLENGTH MWINDOWSCONF TYPES RECTYPES MYGPS \
-	    Title Temp1 List ListInds EdWindow GPSLabel PositionFormat \
-	    Datum GPSState Map MapBounds TXT MESS DISTUNIT DTUNIT DSCALE \
-	    SUBDTUNIT SUBDSCALE DLUNIT MAPDISTUNITS MapScale \
+	    MAPSCALE MAPDISTS MAPDISTVALS MAPSCLENGTH MWINDOWSCONF TYPES \
+	    RECTYPES MYGPS Temp1 List ListInds EdWindow GPSLabel \
+	    PositionFormat Datum GPSState Map MapBounds TXT MESS DISTUNIT \
+	    DTUNIT DSCALE SUBDTUNIT SUBDSCALE DLUNIT MAPDISTUNITS MapScale \
 	    MpW LsW RcW LsWTit MpWTit RcWTit WConf OVx OVy XCoord YCoord \
 	    MapZone MapProjTitle MapTransfTitle MapPFormat MapRange \
 	    MapWPMoving MapMakingRT MapLoading MapScInitVal MapImageItems \
-	    GetDispl MAPKNOWNTRANSFS RECPROTOCOLS SYMBOLIMAGE RcMenu \
-	    GPSProtocol GPSProtocolExt RealTimeLogAnim PVTState USvState
+	    GetDispl MAPKNOWNPROJS RECPROTOCOLS SYMBOLIMAGE RcMenu \
+	    GPSProtocol GPSProtocolExt RealTimeLogAnim PVTState USvState \
+	    MAPFTSIZES NoGSHP NoImgLib ImgOutFormats SmallLogo UNIX
 
     GlobalOptionsBindings
 
@@ -269,14 +290,12 @@ proc GMInit {} {
 	set GM${type}Show 0
     }
 
-    set Title "GPS Manager"
     set MapBounds "0 0 $MAPWIDTH $MAPHEIGHT"
     set MapRange(x) $MAPWIDTH ; set MapRange(y) $MAPHEIGHT
     set MapRange(x0) 0 ; set MapRange(y0) 0
     set OVx 0 ; set OVy 0 ; set XCoord "" ; set YCoord "" ; set MapZone ""
     set MapWPMoving -1 ; set MapMakingRT 0 ; set MapLoading 0
     set MapImageItems ""
-    set GetDispl 0
 
     option add *Foreground $COLOUR(fg)
     option add *Background $COLOUR(bg)
@@ -301,7 +320,7 @@ proc GMInit {} {
 		set ${t}Tit "GPS Manager"
 		toplevel $w
 		wm protocol $w WM_DELETE_WINDOW "lower $w"
-		wm title $w "GPS Manager: $TXT($z)"
+		wm title $w "$TXT($z)/GPS Manager"
 		# because of some window managers do not iconify windows
 		# wm geometry $w +[set ${p}POSX]+[set ${p}POSY]
 		# wm iconify $w
@@ -310,12 +329,25 @@ proc GMInit {} {
 		wm geometry $w +[set ${p}POSX]+[set ${p}POSY]
 		lower $w .
 		frame [set $t] -borderwidth 10
-		button $w.tit -textvariable ${t}Tit -width $mt \
-			-command "Raise . ; $w.tit configure -state normal"
-		bind $w.tit <Enter> "set ${t}Tit {$TXT(mainwd)}"
-		bind $w.tit <Leave> "set ${t}Tit {GPS Manager}"
 	    }
 
+	    button .rcw.tit -textvariable RcWTit -width $mt \
+		    -command "Raise . ; .rcw.tit configure -state normal"
+	    bind .rcw.tit <Enter> "set RcWTit {$TXT(mainwd)}"
+	    bind .rcw.tit <Leave> "set RcWTit {GPS Manager}"
+
+	    frame .mpw.top
+	    frame .mpw.top.frNT
+	    set ft .mpw.top.frNT
+	    # to be filled in by proc ToTravel
+	    frame .mpw.top.frT
+	    set WConf(travel,fr) .mpw.top.frT
+	    set WConf(travel,alt) $ft
+	    button $ft.tit -textvariable MpWTit -width $mt \
+		    -command "Raise . ; $ft.tit configure -state normal"
+	    bind $ft.tit <Enter> "set MpWTit {$TXT(mainwd)}"
+	    bind $ft.tit <Leave> "set MpWTit {GPS Manager}"
+
 	    frame .lsw.frmb -borderwidth 2
 	    menubutton .lsw.frmb.dtitle -text Datum -menu .lsw.frmb.dtitle.m
 	    menu .lsw.frmb.dtitle.m \
@@ -357,7 +389,7 @@ proc GMInit {} {
 		set ${t}Tit "GPS Manager"
 		toplevel $w
 		wm protocol $w WM_DELETE_WINDOW "lower $w"
-		wm title $w "GPS Manager: $TXT($z)"
+		wm title $w "$TXT($z)/GPS Manager"
 		# because of some window managers do not iconify windows
 		# wm geometry $w +[set ${p}POSX]+[set ${p}POSY]
 		# wm iconify $w
@@ -379,6 +411,12 @@ proc GMInit {} {
 	    button .lsw.frbl.frb.load -text $TXT(load) \
 		    -command { LoadFile Data ; \
 		    .lsw.frbl.frb.load configure -state normal }
+	    set m .lsw.frbl.frb.import.m
+	    menubutton .lsw.frbl.frb.import -text $TXT(import) -menu $m
+	    menu $m
+	    foreach fmt "GTrackMaker" {
+		$m add command -label $fmt -command "ImportFile Data $fmt"
+	    }
 	    button .lsw.frbl.frb.save -text $TXT(save) -state disabled \
 		    -command { SaveFile all Data ; \
 		    .lsw.frbl.frb.save configure -state normal }
@@ -416,7 +454,7 @@ proc GMInit {} {
 	    -window $MpW.frm.frmap3.cv.val
     menubutton $MpW.frm.frmap3.mn -text $TXT(change) -menu $MpW.frm.frmap3.mn.m
     menu $MpW.frm.frmap3.mn.m
-    set nf 1 ; set nmd ""
+    set nf 1 ; set nmd "" ; set MAPDISTVALS ""
     set u $SUBDTUNIT ; set f $SUBDSCALE ; set ims [lindex $MAPSCALE 0]
     set imsu [lreplace $MAPSCALE 0 0]
     # map scale in meters/pixel
@@ -430,7 +468,7 @@ proc GMInit {} {
 	    set u $DTUNIT ; set f 1
 	}
 	set ad [expr $v*$f] ; set t "$v $u"
-	lappend nmd $t
+	lappend nmd $t ; lappend MAPDISTVALS $ad
 	$MpW.frm.frmap3.mn.m add radiobutton -label $t \
 		-selectcolor $COLOUR(check) -command "MapScaleSet $ad"
 	if { $v == $ims } {
@@ -449,31 +487,26 @@ proc GMInit {} {
 	set MapScInitVal 1
 	$MpW.frm.frmap3.cv.val configure -text "1 $DTUNIT"
     }
+    # labels in map scale menu aligned with km values in $MAPDISTVALS    
     set MAPDISTS $nmd
 
     frame $MpW.frm.frmap3.sep -height 6 -bg $COLOUR(dialbg) -width 5
     foreach op "loc disp clr" lb "locate displ clear" exc "GR _ GR" \
-	    fp "FillMappedMenus FillDispMenus FillMappedMenus" \
-	    cm "Locate {} UnMap" {
+	    fp "SelectApplyMapped SelectApplyUnmapped SelectApplyMapped" \
+	    cm "Locate PutMap UnMap" mode "single many many" {
 	set mn $MpW.frm.frmap3.$op.m
 	menubutton $MpW.frm.frmap3.$op -text $TXT($lb) -menu $mn \
 		-state disabled
 	menu $mn
 	foreach wh $TYPES {
 	    if { "$wh" != "$exc" } {
-		set m $mn.w$wh
-		$mn add cascade -label $TXT(name$wh) -menu $m
-		menu $m
+		$mn add command -label $TXT(name$wh) \
+			-command "$fp $wh $mode $cm"
 	    }
 	}
-	if { "$cm" != "" } {
-	    bind $MpW.frm.frmap3.$op <Button-1> \
-		    "$fp $MpW.frm.frmap3.$op.m $cm"
-	} else {
-	    bind $MpW.frm.frmap3.$op <Button-1> \
-		    "$fp $MpW.frm.frmap3.$op.m"
-	}
     }
+    $MpW.frm.frmap3.loc.m insert 0 command -label $TXT(prevctr) \
+	    -command LocatePrevious
     set WConf(mapstate) "$MpW.frm.frmap3.loc $MpW.frm.frmap3.clr"
     set WConf(mapstatetype) "menubutton menubutton"
     lappend WConf(datastate) [list menubutton $MpW.frm.frmap3.disp]
@@ -485,8 +518,9 @@ proc GMInit {} {
 	    set WConf(mapdatum) "$MpW.frmi.frcoords.dtitle \
 		    $MpW.frmi.frcoords.ptitle"
 	    lappend WConf(mapstate) $MpW.frmi.frmbs.msave \
-		    $MpW.frmi.frmbs.mclear
-	    lappend WConf(mapstatetype) button button
+		    $MpW.frmi.frmbs.mprint $MpW.frmi.frmbs.mclear \
+		    $MpW.frmi.frmbs.mftsize
+	    lappend WConf(mapstatetype) button button button menubutton
 	    set WConf(mapstateback) $MpW.frmi.frmbs.mback.m
 	    set WConf(additemstate) ""
 
@@ -506,9 +540,24 @@ proc GMInit {} {
 		    -relief sunken
 	    label $MpW.frmi.frmbs.ycoord -textvariable YCoord -width 11 \
 		    -relief sunken
-	    button $MpW.frmi.frmbs.msave -text "$TXT(saveto) PS" \
-		    -command "SaveMap ; \
+	    if { $NoImgLib } {
+		button $MpW.frmi.frmbs.msave -text "$TXT(saveto) PS" \
+			-command "SaveMap PS ; \
 		              $MpW.frmi.frmbs.msave configure -state normal" \
+			-state disabled -width $bl
+	    } else {
+		set m $MpW.frmi.frmbs.msave.m
+		menubutton $MpW.frmi.frmbs.msave -text "$TXT(saveto)..." \
+			-menu $m -state disabled -width $bl
+		menu $m
+		$m add command -label PS -command { SaveMap PS }
+		foreach f $ImgOutFormats {
+		    $m add command -label $f -command "SaveMap $f"
+		}
+	    }
+	    button $MpW.frmi.frmbs.mprint -text $TXT(print) \
+		    -command "PrintMap ; \
+		              $MpW.frmi.frmbs.mprint configure -state normal" \
 		    -state disabled -width $bl
 	    menubutton $MpW.frmi.frmbs.mback -text $TXT(backgrnd) -width $bl \
 		    -menu $MpW.frmi.frmbs.mback.m
@@ -525,6 +574,13 @@ proc GMInit {} {
 		    -width $bl \
 		    -command "ClearMap ; \
 		    $MpW.frmi.frmbs.mclear configure -state normal"
+	    menubutton $MpW.frmi.frmbs.mftsize -text $TXT(chgmfsize) \
+		    -menu $MpW.frmi.frmbs.mftsize.m -state disabled
+	    menu $MpW.frmi.frmbs.mftsize.m
+	    foreach s $MAPFTSIZES {
+		$MpW.frmi.frmbs.mftsize.m add command -label $s \
+			-command "MapChangeFontSize $s"
+	    }
 	    frame $MpW.frmi.frcoords -borderwidth 2
 	    menubutton $MpW.frmi.frcoords.dtitle -text Datum \
 		    -menu $MpW.frmi.frcoords.dtitle.m
@@ -546,14 +602,24 @@ proc GMInit {} {
 	    set defsmnbt $MpW.frmi.frcoords.udefs
 	}
 	map {
-	    frame $MpW.frm.frmap0 -borderwidth 2
-	    set fr0 $MpW.frm.frmap0
+	    frame $MpW.frm.top -borderwidth 2
+	    frame $MpW.frm.top.frmap0
+	    # to be filled in by proc ToTravel
+	    frame $MpW.frm.top.frmapT
+	    set WConf(travel,fr) $MpW.frm.top.frmapT
+	    set WConf(travel,alt) [set fr0 $MpW.frm.top.frmap0]
 	    set gtit $fr0.title
 
 	    menubutton $fr0.db -text $TXT(nameData) -width $mt -menu $fr0.db.m
 	    menu $fr0.db.m
 	    $fr0.db.m add command -label "$TXT(load) ..." \
 		    -command "LoadFile Data"
+	    set m $fr0.db.m.import
+	    menu $m
+	    $fr0.db.m add cascade -label "$TXT(import) ..." -menu $m
+	    foreach fmt "GTrackMaker" {
+		$m add command -label $fmt -command "ImportFile Data $fmt"
+	    }
 	    $fr0.db.m add command -label "$TXT(save) ..." \
 		    -command "SaveFile all Data" -state disabled
 	    $fr0.db.m add command -label $TXT(nameLists) \
@@ -564,35 +630,47 @@ proc GMInit {} {
 		set m $fr0.db.m.e$i
 		$fr0.db.m add cascade -label $TXT(name$i) -menu $m
 		menu $m
-		switch $i {
-		    GR {
-			set tits [list $TXT(newGR) $TXT(clearall) \
+		if { "$i" == "GR" } {
+		    set tits [list $TXT(newGR) $TXT(clearall) \
 			       "$TXT(loadgrels) ..." $TXT(count)]
-			set coms "NewItem ClearList LoadGREls Count"
-			set sts "normal disabled disabled normal"
-			set im 3
-			set imp importgrels ; set impst disabled
-			set imppr ImportGREls ; set fmts "GPStrans Fugawi"
-			set acts "save saveels exportels"
-			set prs "SaveFile SaveGREls ExportGREls"
+		    set coms "NewItem ClearList LoadGREls Count"
+		    set sts "normal disabled disabled normal"
+		    set im 3
+		    set imp importgrels ; set impst disabled
+		    set imppr ImportGREls
+		    # incorporates VR contribution
+		    set ifmts "GPStrans GD2 Fugawi EasyGPS"
+		    set acts "save saveels"
+		    set prs "SaveFile SaveGREls"
+		    set exp exportels
+		    set exppr ExportGREls ; set efmts "GPStrans"
+		    if { ! $NoGSHP } {
+			lappend efmts Shapefile_2D Shapefile_3D
 		    }
-		    WP {
-			set tits [list $TXT(new$i) $TXT(clearall) $TXT(count)]
-			set coms "NewItem ClearList Count"
-			set sts "normal disabled normal"
-			set im 2
-			set imp import ; set impst normal
-			set imppr ImportFile ; set fmts "GPStrans Fugawi"
-			set acts "save export" ; set prs "SaveFile ExportFile"
+		} else {
+		    set tits [list $TXT(new$i) $TXT(clearall) $TXT(count)]
+		    set coms "NewItem ClearList Count"
+		    set sts "normal disabled normal"
+		    set im 2
+		    set imp import ; set impst normal
+		    set imppr ImportFile ; set ifmts "GPStrans GD2"
+		    if { $i == "WP" } {
+			# incorporates VR contribution
+			lappend ifmts Fugawi EasyGPS
+		    } elseif { $i == "RT" } {
+			lappend ifmts MapGuide
 		    }
-		    default {
-			set tits [list $TXT(new$i) $TXT(clearall) $TXT(count)]
-			set coms "NewItem ClearList Count"
-			set sts "normal disabled normal"
-			set im 2
-			set imp import ; set impst normal
-			set imppr ImportFile ; set fmts "GPStrans"
-			set acts "save export" ; set prs "SaveFile ExportFile"
+		    set acts save ; set prs SaveFile
+		    set exp export
+		    set exppr ExportFile ; set efmts "GPStrans"
+		    if { "$MYGPS" == "Magellan" } {
+			# based on MGM contribution
+			lappend ifmts MapSend Meridian
+			lappend efmts MapSend Meridian
+		    }
+		    if { ! $NoGSHP } {
+			lappend ifmts Shapefile_2D Shapefile_3D
+			lappend efmts Shapefile_2D Shapefile_3D
 		    }
 		}
 		foreach l $tits c $coms s $sts {
@@ -602,8 +680,9 @@ proc GMInit {} {
 		    $m insert $im cascade -label "$TXT($ip) ..." \
 			    -menu $m.$ip -state $s
 		    menu $m.$ip
-		    foreach fmt $fmts {
-			$m.$ip add command -label $fmt -command "$p $i $fmt"
+		    foreach fmt $ifmts {
+			regsub -all { } $fmt {_} gfmt
+			$m.$ip add command -label $fmt -command "$p $i $gfmt"
 		    }
 		    incr im
 		}
@@ -616,14 +695,42 @@ proc GMInit {} {
 			    -command "$p select $i"
 		    incr im
 		}
+		foreach ep $exp p $exppr {
+		    $m insert $im cascade -label "$TXT($ep) ..." \
+			    -menu $m.$ep -state disabled
+		    menu $m.$ep
+		    foreach fmt $efmts {
+			regsub -all { } $fmt {_} gfmt
+			$m.$ep add cascade -label $fmt -menu $m.$ep.f$gfmt
+			menu $m.$ep.f$gfmt
+			$m.$ep.f$gfmt add command -label $TXT(all) \
+				-command "$p all $gfmt $i"
+			$m.$ep.f$gfmt add command -label "$TXT(select) ..." \
+				-command "$p select $gfmt $i"
+		    }
+		    incr im
+		}
 	    }
 
 	    set RcMenu $fr0.rcw.m
 	    menubutton $fr0.rcw -text $TXT(GPSrec) -width $mt -menu $RcMenu
 	    menubutton $fr0.map -text $TXT(nameMap) -width $mt -menu $fr0.map.m
 	    menu $fr0.map.m
-	    # order of entries used in file map.tcl
-	    $fr0.map.m add command -label "$TXT(saveto) PS" -command SaveMap \
+	    # order of entries used in file map.tcl (proc SetMapBounds)
+	    if { $NoImgLib } {
+		$fr0.map.m add command -label "$TXT(saveto) PS" \
+			-command { SaveMap PS } -state disabled
+	    } else {
+		set m $fr0.map.mapsave
+		$fr0.map.m add cascade -label "$TXT(saveto)..." -menu $m \
+			 -state disabled
+		menu $m
+		$m add command -label PS -command { SaveMap PS }
+		foreach f $ImgOutFormats {
+		    $m add command -label $f -command "SaveMap $f"
+		}
+	    }
+	    $fr0.map.m add command -label $TXT(print) -command PrintMap \
 		    -state disabled
 	    $fr0.map.m add cascade -label $TXT(backgrnd) -menu $fr0.map.mback
 	    menu $fr0.map.mback
@@ -635,6 +742,13 @@ proc GMInit {} {
 	    }
 	    $fr0.map.m add command -label $TXT(clear) -command ClearMap \
 		    -state disabled
+	    $fr0.map.m add cascade -label $TXT(chgmfsize) \
+		    -menu $fr0.map.mftsize -state disabled
+	    menu $fr0.map.mftsize
+	    foreach s $MAPFTSIZES {
+		$fr0.map.mftsize add command -label $s \
+			-command "MapChangeFontSize $s"
+	    }
 
 	    set defsmnbt $fr0.udefs
 
@@ -675,7 +789,7 @@ proc GMInit {} {
 	    set WConf(mapstateback) $fr0.map.mback
 	    set WConf(additemstate) $fr0.db.m.e
 	    lappend WConf(datastate) \
-		    [list menu [list [list $fr0.db.m [list 1 3]]]] \
+		    [list menu [list [list $fr0.db.m [list 2 4]]]] \
 		    [list button [list .lsw.frbl.frb.save \
 		                       .lsw.frbl.frb.search]]
 	}
@@ -704,19 +818,14 @@ proc GMInit {} {
 	    -postcommand "FillEllipsoidMenu $mn.ell.mn OpenEllipsoid"
     $mn.ell add cascade -label "$TXT(open)..." -menu $mn.ell.mn
 
-    if { [catch "set gim [image create photo \
-	    -file [file join $SRCDIR gmicons gpsman-logo-small.gif]]"] } {
-	set Title "GPS Manager"
-	button $gtit -textvariable Title -width $mt \
-		-command "QuitNow ; $gtit configure -state normal"
-	bind $gtit <Enter> "set Title $TXT(exit)"
-	bind $gtit <Leave> { set Title "GPS Manager" }
+    if { $SmallLogo == "" } {
+	menubutton $gtit -text "GPS Manager" -menu $gtit.m
     } else {
-	menubutton $gtit -image $gim -menu $gtit.m
-	menu $gtit.m
-	$gtit.m add command -label $TXT(about) -command About
-	$gtit.m add command -label $TXT(exit) -command QuitNow
+	menubutton $gtit -image $SmallLogo -menu $gtit.m
     }
+    menu $gtit.m
+    $gtit.m add command -label $TXT(about) -command About
+    $gtit.m add command -label $TXT(exit) -command QuitNow
 
     set tw [Measure $TXT(nameWP)]
     set bw [Measure $TXT(clear)]
@@ -732,8 +841,11 @@ proc GMInit {} {
 	listbox $LsW.frl$i.frl.box -height $LISTHEIGHT -width $LISTWIDTH \
  	    -yscrollcommand "$LsW.frl$i.frl.bscr set" \
  	    -selectmode single -exportselection 1
-	bind $LsW.frl$i.frl.box <Enter> { focus %W }
-	bind $LsW.frl$i.frl.box <Leave> "focus $LsW"
+	# SH contribution: no such bindings in non-unix systems
+	if { $UNIX } {
+	    bind $LsW.frl$i.frl.box <Enter> { focus %W }
+	    bind $LsW.frl$i.frl.box <Leave> "focus $LsW"
+	}
 	bind $LsW.frl$i.frl.box <Double-1> "OpenListItem $i"
 	bind $LsW.frl$i.frl.box <Key> { ScrollListIndex %W %A }
 	scrollbar $LsW.frl$i.frl.bscr -command "$LsW.frl$i.frl.box yview"
@@ -741,37 +853,48 @@ proc GMInit {} {
 	Mscroll $LsW.frl$i.frl.box
 
 	# order of menu entries is used elsewhere!
-	switch $i {
-	    GR {
-		set tits [list $TXT(newGR) $TXT(clearall) "$TXT(load) ..." \
+	if { "$i" == "GR" } {
+	    set tits [list $TXT(newGR) $TXT(clearall) "$TXT(load) ..." \
 			       "$TXT(loadgrels) ..." $TXT(count)]
-		set coms "NewItem ClearList LoadFile LoadGREls Count"
-		set sts "normal disabled normal disabled normal"
-		set im 4
-		set imp importgrels ; set impst disabled
-		set imppr ImportGREls ; set fmts "GPStrans Fugawi"
-		set acts "save saveels exportels"
-		set prs "SaveFile SaveGREls ExportGREls"
+	    set coms "NewItem ClearList LoadFile LoadGREls Count"
+	    set sts "normal disabled normal disabled normal"
+	    set im 4
+	    set imp importgrels ; set impst disabled
+	    set imppr ImportGREls
+	    # incorporates VR contribution
+	    set ifmts "GPStrans GD2 Fugawi EasyGPS"
+	    set acts "save saveels"
+	    set prs "SaveFile SaveGREls"
+	    set exp exportels
+	    set exppr ExportGREls ; set efmts "GPStrans"
+	    if { ! $NoGSHP } {
+		lappend efmts Shapefile_2D Shapefile_3D
 	    }
-	    WP {
-		set tits [list $TXT(new$i) $TXT(clearall) "$TXT(load) ..." \
+	} else {
+	    set tits [list $TXT(new$i) $TXT(clearall) "$TXT(load) ..." \
 		               $TXT(count)]
-		set coms "NewItem ClearList LoadFile Count"
-		set sts "normal disabled normal normal"
-		set im 3
-		set imp import ; set impst normal
-		set imppr ImportFile ; set fmts "GPStrans Fugawi"
-		set acts "save export" ; set prs "SaveFile ExportFile"
+	    set coms "NewItem ClearList LoadFile Count"
+	    set sts "normal disabled normal normal"
+	    set im 3
+	    set imp import ; set impst normal
+	    set imppr ImportFile ; set ifmts "GPStrans GD2"
+	    if { $i == "WP" } {
+		# incorporates VR contribution
+		lappend ifmts Fugawi EasyGPS
+	    } elseif { $i == "RT" } {
+		lappend ifmts MapGuide
 	    }
-	    default {
-		set tits [list $TXT(new$i) $TXT(clearall) "$TXT(load) ..." \
-		               $TXT(count)]
-		set coms "NewItem ClearList LoadFile Count"
-		set sts "normal disabled normal normal"
-		set im 3
-		set imp import ; set impst normal
-		set imppr ImportFile ; set fmts "GPStrans"
-		set acts "save export" ; set prs "SaveFile ExportFile"
+	    set acts save ; set prs SaveFile
+	    set exp export
+	    set exppr ExportFile ; set efmts "GPStrans"
+	    if { "$MYGPS" == "Magellan" } {
+		# based on MGM contribution
+		lappend ifmts MapSend Meridian
+		lappend efmts MapSend Meridian
+	    }
+	    if { ! $NoGSHP } {
+		lappend ifmts Shapefile_2D Shapefile_3D
+		lappend efmts Shapefile_2D Shapefile_3D
 	    }
 	}
 	set m $LsW.frl$i.frb.file.m
@@ -781,7 +904,7 @@ proc GMInit {} {
 	foreach ip $imp s $impst p $imppr {
 	    $m insert $im cascade -label "$TXT($ip) ..." -menu $m.$ip -state $s
 	    menu $m.$ip
-	    foreach fmt $fmts {
+	    foreach fmt $ifmts {
 		$m.$ip add command -label $fmt -command "$p $i $fmt"
 	    }
 	    incr im
@@ -794,6 +917,20 @@ proc GMInit {} {
 	    $m.$a add command -label "$TXT(select) ..." -command "$p select $i"
 	    incr im
 	}
+	foreach ep $exp p $exppr {
+	    $m insert $im cascade -label "$TXT($ep) ..." \
+		    -menu $m.$ep -state disabled
+	    menu $m.$ep
+	    foreach fmt $efmts {
+		$m.$ep add cascade -label $fmt -menu $m.$ep.f$fmt
+		menu $m.$ep.f$fmt
+		$m.$ep.f$fmt add command -label $TXT(all) \
+			-command "$p all $fmt $i"
+		$m.$ep.f$fmt add command -label "$TXT(select) ..." \
+			-command "$p select $fmt $i"
+	    }
+	    incr im
+	}
     }
     # cannot use $TYPES here!!!
     bind $LsW.frlWP.frl.box <Button-3> {
@@ -831,7 +968,7 @@ proc GMInit {} {
     set fprt $RcW.frgps.prt
     menubutton $fprt.title -text $TXT(protcl) -menu $fprt.title.m
     menu $fprt.title.m
-    set GPSProtocolExt $TXT([set GPSProtocol [lindex $RECPROTOCOLS 0]])
+    set GPSProtocolExt $TXT($GPSProtocol)
     foreach p $RECPROTOCOLS {
 	$fprt.title.m add command -label $TXT($p) \
 		-command "GPSChangeProtocol $p"
@@ -839,31 +976,47 @@ proc GMInit {} {
 		-selectcolor $COLOUR(check) -command "GPSChangeProtocol $p"
     }
     $RcMenu.pm invoke 0
-    label $fprt.prot -textvariable GPSProtocolExt -width 12
+    label $fprt.prot -textvariable GPSProtocolExt -width 16
 
-    frame $RcW.frgps.rlt -borderwidth 2 -bg $COLOUR(messbg)
-    set frlt $RcW.frgps.rlt
-    label $frlt.title -text $TXT(realtimelog)
-    menu $RcMenu.rtm
-    $RcMenu add cascade -label $TXT(realtimelog) -menu $RcMenu.rtm
-    $RcMenu.rtm add command -label $TXT(getlog) -command GPSRealTimeLogOnOff
-    $RcMenu.rtm add command -label $TXT(dolog) -command { set PVTState on }
-    $RcMenu.rtm add command -label $TXT(animation) \
-	    -command { set RealTimeLogAnim 1 }
-    button $frlt.onoff -text $TXT(getlog) -width 10 \
-	    -command "GPSRealTimeLogOnOff ; \
-	    $frlt.onoff configure -state normal"
-    button $frlt.show -text $TXT(dolog) \
-	    -command "set PVTState on ; $frlt.show configure -state normal"
-    button $frlt.anim -text $TXT(animation) \
-	    -command "set RealTimeLogAnim 1 ; \
-	    $frlt.anim configure -state normal"
-    set WConf(realtime) [list $frlt.onoff [list $RcMenu.rtm 0]]
-    set WConf(realtimetype) "button menuentry"
-    grid configure $frlt.title -row 0 -column 0 -columnspan 2 -sticky news
-    grid configure $frlt.onoff -row 1 -column 0 -rowspan 2 -sticky ew
-    grid configure $frlt.show -row 1 -column 1 -sticky news
-    grid configure $frlt.anim -row 2 -column 1 -sticky news
+    
+    if { "$MYGPS" != "Magellan" } {
+	frame $RcW.frgps.rlt -borderwidth 2 -bg $COLOUR(messbg)
+	set frlt $RcW.frgps.rlt
+	label $frlt.title -text $TXT(realtimelog)
+	menu $RcMenu.rtm
+	$RcMenu add cascade -label $TXT(realtimelog) -menu $RcMenu.rtm
+	$RcMenu.rtm add command -label $TXT(getlog) \
+		-command GPSRealTimeLogOnOff
+	$RcMenu.rtm add command -label $TXT(dolog) -command { set PVTState on }
+	$RcMenu.rtm add command -label $TXT(animation) \
+		-command { set RealTimeLogAnim 1 }
+	# Travel entry added below if Garmin
+
+	button $frlt.onoff -text $TXT(getlog) -width 10 \
+		-command "GPSRealTimeLogOnOff ; \
+		$frlt.onoff configure -state normal"
+	button $frlt.show -text $TXT(dolog) \
+		-command "set PVTState on ; $frlt.show configure -state normal"
+	button $frlt.anim -text $TXT(animation) \
+		-command "set RealTimeLogAnim 1 ; \
+		$frlt.anim configure -state normal"
+	set WConf(realtime) [list $frlt.onoff [list $RcMenu.rtm 0]]
+	set WConf(realtimetype) "button menuentry"
+	grid configure $frlt.title -row 0 -column 0 -columnspan 2 -sticky news
+	grid configure $frlt.onoff -row 1 -column 0 -rowspan 2 -sticky ew
+	grid configure $frlt.show -row 1 -column 1 -sticky news
+	grid configure $frlt.anim -row 2 -column 1 -sticky news
+	if { $MYGPS == "Garmin" } {
+	    $RcMenu.rtm add separator
+	    $RcMenu.rtm add command -label $TXT(travel) -command ToTravel
+	    button $frlt.trv -text $TXT(travel) \
+		    -command "$frlt.trv configure -state normal ; ToTravel"
+	    grid configure $frlt.trv -row 3 -column 0 -columnspan 2
+	}
+    } else {
+	set WConf(realtime) ""
+	set WConf(realtimetype) ""
+    }
 
     frame $RcW.frgps.bs -borderwidth 2
     set GPSState offline ; set GPSLabel $TXT(offline)
@@ -943,9 +1096,13 @@ proc GMInit {} {
 
     # packing
     if { "$MWINDOWSCONF" == "map" } {
-	pack $gtit $fr0.db $fr0.rcw $fr0.map $defsmnbt $fr0.options \
-		-side left -padx 3
-	pack $fr0
+	set c -1
+	foreach b \
+	    "$gtit $fr0.db $fr0.rcw $fr0.map $defsmnbt $fr0.options" {
+	    grid $b -row 0 -column [incr c] -ipadx 3
+	}
+	grid $fr0
+	pack $MpW.frm.top
     }
     pack $MpW.frm.frmap1.mvscr -side right -fill y
     pack $Map -side left -expand yes -fill both
@@ -976,7 +1133,8 @@ proc GMInit {} {
 	    pack $MpW.frmi.frmbs.mtitle $MpW.frmi.frmbs.grid \
 		    $MpW.frmi.frmbs.zone $MpW.frmi.frmbs.xcoord \
 		    $MpW.frmi.frmbs.ycoord $MpW.frmi.frmbs.msave \
-		    $MpW.frmi.frmbs.mback $MpW.frmi.frmbs.mclear -pady 5
+		    $MpW.frmi.frmbs.mprint $MpW.frmi.frmbs.mback \
+		    $MpW.frmi.frmbs.mclear $MpW.frmi.frmbs.mftsize -pady 5
 
 	    pack $MpW.frmi.frcoords -side top
 	    pack $MpW.frmi.frmbs -side bottom
@@ -989,8 +1147,8 @@ proc GMInit {} {
 	    pack $fr4 -pady 2
 	    pack $MpW.frm
 	    pack $MpW
-	    pack .lsw.frbl.frb.load .lsw.frbl.frb.save .lsw.frbl.frb.search \
-		    -side left -padx 3
+	    pack .lsw.frbl.frb.load .lsw.frbl.frb.import .lsw.frbl.frb.save \
+		    .lsw.frbl.frb.search -side left -padx 3
 	    pack .lsw.frbl.frb $LsW -side top -pady 3
 	    pack .lsw.tit .lsw.frbl -side top -pady 5
 	}
@@ -998,8 +1156,13 @@ proc GMInit {} {
 
     pack $RcW.frgps.prt.title $RcW.frgps.prt.prot -side left
     pack $RcW.frgps.bs.state $RcW.frgps.bs.off -side left -pady 2
-    pack $RcW.frgps.title $RcW.frgps.prt $RcW.frgps.rlt $RcW.frgps.bs \
-	    -side top -pady 5
+    if { "$MYGPS" != "Magellan" } {
+	pack $RcW.frgps.title $RcW.frgps.prt $RcW.frgps.rlt $RcW.frgps.bs \
+		-side top -pady 5
+    } else {
+	pack $RcW.frgps.title $RcW.frgps.prt $RcW.frgps.bs \
+		-side top -pady 5
+    }
     pack $RcW.frget.frget1.title $RcW.frget.frget1.displ -side left -padx 5
     foreach i $RECTYPES {
 	pack $RcW.frget.frget2.get$i -side left -pady 2
@@ -1026,7 +1189,9 @@ proc GMInit {} {
 	    pack $LsW .lsw.frmb -side left -fill y
 	    pack $gtit .lsw -side top -pady 3
 
-	    pack .mpw.tit $MpW -side top -pady 3
+	    grid .mpw.top.frNT.tit -row 0 -column 0
+	    grid .mpw.top.frNT
+	    pack .mpw.top $MpW -side top -pady 3
 	}
 	map {
 	    pack $RcW.frgps $RcW.frget $RcW.frput -side top -pady 5
@@ -1064,7 +1229,7 @@ proc About {} {
     set wait 1
     toplevel .about
     wm protocol .about WM_DELETE_WINDOW { set wait 0 }
-    wm title .about "GPS Manager: $TXT(message)"
+    wm title .about "$TXT(message)/GPS Manager"
     wm transient .about
     wm geometry .about +$EPOSX+$EPOSY
     bind .about <Key-Return> { set wait 0 }
@@ -1088,31 +1253,31 @@ proc About {} {
 
 proc GMStart {} {
     # initialize (most) global variables
-    global Index Number Storage File Proc WorkDir FileTypes FDDatum GFLegend \
+    global Index Number Storage File Proc WorkDir FileTypes FDDatum \
 	    TYPES PROCTYPES CursorsChanged MAPWIDTH MAPHEIGHT MAPW2 MAPH2 \
 	    AzimuthDegrees MapEmpty DataDefault DataIndex PositionFormat \
 	    DEFAULTSYMBOL DEFAULTDISPOPT Datum EMPTYSTR AnimNo \
-	    BalloonX BalloonY MAPKNOWNPROJS MAPKNOWNTRANSFS USERDIR \
-	    UProjs UPrGrFile RealTimeLogOn RealTimeLogAnim PVTState \
-	    UDtElFile USvState USvData USvMap BITMAPS SERIALPORT DEFSPORT \
-	    tcl_platform
+	    BalloonX BalloonY USERDIR UProjs UPrGrFile RealTimeLogOn \
+	    RealTimeLogAnim PVTState UDtElFile USvState USvData USvMap \
+	    BITMAPS SERIALPORT DEFSPORT tcl_platform DEFTRTWIDTH DEFTTRWIDTH \
+	    GPSProtocol RECPROTOCOLS GetDispl UNIX MAPCOLOUR MapFont \
+	    MAPFONTSIZE Travelling Travel TRAVELFONTSIZE NAMEWIDTH \
+	    MapMeasure
 	    
     # BSB contribution: globals needed for Lowrance receivers
     global UnusedICInx UnusedWPInx MAX MYGPS
 
     # serial port
-    if { "$tcl_platform(platform)" == "unix" && "$SERIALPORT" == "" } {
+    if { $UNIX && "$SERIALPORT" == "" } {
 	set SERIALPORT $DEFSPORT
     }
+    set GPSProtocol [lindex $RECPROTOCOLS 0]
+    set GetDispl 0
 
     # projections, datums and ellipsoids
     if { [file readable [set UDtElFile [file join $USERDIR datums]]] } {
 	SetUpUserDatums
     }
-    set MAPKNOWNPROJS \
-	    {UTM TM BNG BWI CMP GKK ITM KKJY KKJP SEG
-             LCC1 LCC2 Merc1 Merc2 CS APOLY}
-    set MAPKNOWNTRANSFS {Affine AffineConf NoRot}
     SetUpNZGrids
     set UProjs {}
     if { [file readable [set UPrGrFile [file join $USERDIR projs]]] } {
@@ -1120,9 +1285,13 @@ proc GMStart {} {
     }
 
     # map
-    set MapEmpty 1
+    set MapEmpty 1 ; set MapMeasure ""
     set MAPW2 [expr $MAPWIDTH/2.0] ; set MAPH2 [expr $MAPHEIGHT/2.0]
     set AnimNo 0
+    foreach x "high medium low" y "important normal info" {
+	set MAPCOLOUR(trvwrn$x) $MAPCOLOUR(trvwrn$y)
+    }
+    set MapFont [FixedFont $MAPFONTSIZE]
 
     MapProjectionIs UTM
 
@@ -1132,16 +1301,18 @@ proc GMStart {} {
            #  and the last one the display state
            # WPNum needed only for Lowrance receivers
            # WPRoute is set separately because cannot be edited
-    set Storage(WP) {WPName WPNum WPCommt WPObs WPPFrmt WPPosn WPDatum \
+    set Storage(WP) {WPName WPNum WPCommt WPObs WPPFrmt WPPosn WPDatum
 	             WPDate WPSymbol WPDispOpt WPAlt WPHidden WPDispl}
     set DataDefault(WP) [list "" -1 "" "" $PositionFormat "" $Datum \
 	    "" $DEFAULTSYMBOL $DEFAULTDISPOPT "" "" 0]
-    set Storage(RT) {RTIdNumber RTCommt RTObs RTWPoints RTStages RTDispl}
-    set DataDefault(RT) [list "" "" "" "" "" 0]
+    set Storage(RT) {RTIdNumber RTCommt RTObs RTWPoints RTStages RTWidth
+                     RTDispl}
+    set DataDefault(RT) [list "" "" "" "" "" $DEFTRTWIDTH 0]
     set stRS {RScommt RSlabel RShidden}
     set DataDefault(RS) [list "" "" ""]
-    set Storage(TR) {TRName TRObs TRDatum TRTPoints TRHidden TRDispl}
-    set DataDefault(TR) [list "" "" $Datum "" "" 0]
+    set Storage(TR) {TRName TRObs TRDatum TRTPoints TRSegStarts TRHidden
+                     TRWidth TRDispl}
+    set DataDefault(TR) [list "" "" $Datum "" "" "" $DEFTTRWIDTH 0]
     set stTP {TPlatd TPlongd TPlatDMS TPlongDMS TPdate TPsecs TPalt TPdepth}
     set DataDefault(TP) [list "" "" "" "" "01-Jan-1988 00:00:00" 0 "" ""]
     set Storage(GR) {GRName GRObs GRConts GRDispl}
@@ -1165,15 +1336,105 @@ proc GMStart {} {
                    Map Plot MapBkInfo Image PVTData}
     foreach t $FileTypes { set File($t) "" }
     set FDDatum ""
-    set GFLegend ""
     set WorkDir [pwd]
     set USvState [file join $USERDIR sstate]
     set USvData [file join $USERDIR sdata]
     set USvMap [file join $USERDIR smap]
 
-    # real-time log
+    # real-time and travel/navigation
     set RealTimeLogOn 0 ; set RealTimeLogAnim 0
     set PVTState abort
+    set Travelling 0
+    set Travel(font) [FixedFont $TRAVELFONTSIZE]
+    array set Travel {
+	tosave {conf,1 conf,2 travel,cdsp font warn warn,* mindist chggparam
+	        chggwparam chggix}
+	conf,1  {lab+fix lab+speed c_trkcts c_trn c_vel_z lab+hour
+	lab+alt lab+nxtWP lab+prvWP lab+dist lab+vmg lab+ete lab+eta
+	lab+xtk lab+cts}
+	conf,2  {lab+fix lab+speed c_trkcts lab+hour lab+pos lab+alt lab+trk
+	         c_vel_z}
+	travel,cdsp 1
+	warn  1
+	warn,prox 0
+	warn,prox,wpn ""
+	warn,prox,dst 1
+	warn,prox,level medium
+	warn,anchor 0
+	warn,anchor,wpn ""
+	warn,anchor,dst 1
+	warn,anchor,level medium
+	warn,speed 0
+	warn,speed,max 50
+	warn,speed,level high
+	warn,vspeed 0
+	warn,vspeed,min -6
+	warn,vspeed,max 6
+	warn,vspeed,level medium
+	warn,trn 0
+	warn,trn,max 60
+	warn,trn,level low
+	warn,xtk 0
+	warn,xtk,max 5
+	warn,xtk,level low
+	mindist 0.1
+	chggparam 0.8
+	chggwparam 0.9
+	chggix 2
+    }
+    trace variable Travel(chggix) w TravelChgGParam
+    set Travel(elsizes) "4 4 8 23 5 4 $NAMEWIDTH $NAMEWIDTH 9 9 4 4 4 4 4"
+    array set Travel {
+	els
+	  {fix speed hour pos alt trk nxtWP prvWP ete eta vmg xtk cts trn dist}
+	cvss {c_trkcts c_trn c_vel_z}
+	trav,els {fix speed hour pos alt trk}
+	trav,cvels {{c_vel_z vel_z}}
+	displays {1 2}
+	warnings {prox anchor speed trn vspeed xtk}
+	nav 0
+	nav,els {nxtWP prvWP ete eta vmg xtk cts trn dist}
+	nav,cvels {{c_trkcts cts}}
+	nav,over land
+	nav,datum {WGS 84}
+	nav,maxdtime 5
+	posns {}
+	prevtime -1
+	prevposn {}
+	warncancel {}
+	nav,pmode 1
+	nav,pnear 0
+	nav,prvrs 0
+	chggvals {0.95 0.9 0.8 0.7 0.6}
+	chggwvals {0.98 0.95 0.9 0.8 0.7}
+	chggmaxix 4
+    }
+    # conditions for issuing warnings and their contents
+    #  variables assumed to be defined in the context of execution,
+    #  apart from $TXT():
+    #    $posn, $datum, $speed (user units), $vel_z (m/s), $trn (-180..180),
+    #    $xtk (signed, user units)
+    #  any of these, except $posn, $datum, may be "" for undefined
+    array set Travel {
+	warn:prox,cond {
+	    [ComputeDist $posn $Travel(warn,prox,pos) $datum] < $Travel(warn,prox,dst)
+	}
+	warn:prox,cont {[format $TXT(trvwarrv) $Travel(warn,prox,wpn)]}
+	warn:anchor,cond {
+	    [ComputeDist $posn $Travel(warn,anchor,pos) $datum] > $Travel(warn,anchor,dst)
+	}
+	warn:anchor,cont {[format $TXT(trvwleave) $Travel(warn,anchor,wpn)]}
+	warn:speed,cond { $speed != {} && $speed > $Travel(warn,speed,max) }
+	warn:speed,cont {[format $TXT(trvwspeed) $Travel(warn,speed,max)]}
+	warn:trn,cond { $trn != {} && abs($trn) > $Travel(warn,trn,max) }
+	warn:trn,cont {[format $TXT(trvwtrn) $Travel(warn,trn,max)]}
+	warn:vspeed,cond {
+	    $vel_z != {} && ($vel_z < $Travel(warn,vspeed,min) || $vel_z > $Travel(warn,vspeed,max))
+	}
+	warn:vspeed,cont {[format $TXT(trvwvspeed) $Travel(warn,vspeed,min) $Travel(warn,vspeed,max)]}
+	warn:xtk,cond { $xtk != {} && abs($xtk) > $Travel(warn,xtk,max) }
+	warn:xtk,cont {[format $TXT(trvwxtk) $Travel(warn,xtk,max)]}
+    }
 
     # varia
     set CursorsChanged 0
