@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2001 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2003 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: options.tcl
-#  Last change:  14 November 2001
+#  Last change:  26 January 2003
 #
 
 # when inserting new data here, define TXT(opt*)
@@ -29,6 +29,7 @@
 #      nat        natural number (=nonnegative integer); as an entry
 #      float      any number; as an entry
 #      any        any non-empty string; as an entry
+#      any_empty  any string or empty; as an entry
 #      colour     a special dialog is used for selection
 #      perms      file permissions; a special dialog is used for selection
 #      oneof      as a radiobutton; one must define $OPTVALS($i) as a
@@ -78,8 +79,10 @@ set OPTTYPE(MWINDOWSCONF) fixedtextmenu
 set OPTMENUCONTS(MWINDOWSCONF) {map lists}
 set OPTMENUNAMES(MWINDOWSCONF) TXT
 set OPTMENUPREFIX(MWINDOWSCONF) MWC
-set OPTTYPE(LANG) oneof
-set OPTVALS(LANG) $KNOWNLANGS
+set OPTTYPE(LANG) fixedtextmenu
+set OPTMENUCONTS(LANG) $KNOWNLANGS
+set OPTMENUNAMES(LANG) TXT
+set OPTMENUPREFIX(LANG) LANG
 set OPTTYPE(ISOLATIN1) boolean
 set OPTTYPE(DELETE) boolean
 set OPTTYPE(BalloonHelp) boolean
@@ -91,9 +94,10 @@ set OPTMENUPROC(GPSREC) FillRecModelsMenu
 # the _GPSRecConf description may be changed by proc RecModelChange
 #  in file recmodels.tcl when $GPSREC changes
 set OPTTYPE(_GPSRecConf) group
-set OPTGRPL(_GPSRecConf) {NAMELENGTH COMMENTLENGTH MAXWPOINTS MAXROUTES
-                      MAXWPINROUTE MAXTPOINTS CREATIONDATE NOLOWERCASE
-                      DEFAULTSYMBOL DEFAULTDISPOPT}
+set OPTGRPL(_GPSRecConf) {ACCEPTALLCHARS NAMELENGTH COMMENTLENGTH MAXWPOINTS
+                      MAXROUTES MAXWPINROUTE MAXTPOINTS CREATIONDATE
+                      NOLOWERCASE DEFAULTSYMBOL DEFAULTDISPOPT}
+set OPTTYPE(ACCEPTALLCHARS) boolean
 set OPTTYPE(NAMELENGTH) nat
 set OPTTYPE(COMMENTLENGTH) nat
 set OPTTYPE(MAXWPOINTS) nat
@@ -135,8 +139,10 @@ set OPTVALS(DISTUNIT) "KM NAUTMILE STATMILE"
 set OPTTYPE(PositionFormat) fixedmenu
 set OPTMENUCONTS(PositionFormat) $PFORMATS
 
-set OPTTYPE(DateFormat) oneof
-set OPTVALS(DateFormat) "YYYYMMDD MMDDYYYY DDMMMYYYY"
+set OPTTYPE(DateFormat) fixedtextmenu
+set OPTMENUCONTS(DateFormat) [lsort -dictionary [array names DATEW]]
+set OPTMENUNAMES(DateFormat) TXT
+set OPTMENUPREFIX(DateFormat) {}
 
 set OPTTYPE(ACCFORMULAE) boolean
 
@@ -145,7 +151,8 @@ set OPTTYPE(ASKPROJPARAMS) boolean
 set OPTTYPE(_MapGeom) group
 set OPTGRPL(_MapGeom) {MAPWIDTH MAPHEIGHT _sep
                        MAPSCLENGTH MAPSCALE _sep
-                       DPOSRTMAP}
+                       DPOSRTMAP _sep
+                       MAPFONTSIZE TRAVELFONTSIZE DEFTRTWIDTH DEFTTRWIDTH}
 
 set OPTTYPE(_Geom) group
 set OPTGRPL(_Geom) {MAXMENUITEMS LISTWIDTH LISTHEIGHT _sep
@@ -168,6 +175,14 @@ set OPTTYPE(EPOSY) nat
 set OPTTYPE(DPOSX) nat
 set OPTTYPE(DPOSY) nat
 set OPTTYPE(DPOSRTMAP) float
+set OPTTYPE(MAPFONTSIZE) fixedmenu
+set OPTMENUCONTS(MAPFONTSIZE) $MAPFTSIZES
+set OPTTYPE(TRAVELFONTSIZE) fixedmenu
+set OPTMENUCONTS(TRAVELFONTSIZE) $MAPFTSIZES
+set OPTTYPE(DEFTRTWIDTH) fixedmenu
+set OPTMENUCONTS(DEFTRTWIDTH) {1 2 3 4 5 6 7 8}
+set OPTTYPE(DEFTTRWIDTH) fixedmenu
+set OPTMENUCONTS(DEFTTRWIDTH) {1 2 3 4 5 6 7 8}
 set OPTTYPE(LISTWIDTH) nat
 set OPTTYPE(LISTHEIGHT) nat
 
@@ -178,20 +193,24 @@ set OPTELS(COLOUR) {fg bg messbg confbg selbg dialbg offline online check
 
 set OPTTYPE(MAPCOLOUR) array
 set OPTELTYPE(MAPCOLOUR) colour
-set OPTELS(MAPCOLOUR) {mapsel WP RT mkRT TR TP mapleg anim emptygrid fullgrid}
+set OPTELS(MAPCOLOUR) {mapsel WP RT mkRT TR TP mapleg anim emptygrid fullgrid
+                       trvtrk trvtrn trvcts trvcts2 trvvel_z trvwrnimportant
+                       trvwrnnormal trvwrninfo}
 
 set OPTTYPE(_Files) group
 if { "$tcl_platform(platform)" == "unix" } {
-    set OPTGRPL(_Files) {DEFSPORT _sep SAVESTATE DELSTATE _sep PERMS PAPERSIZE}
+    set OPTGRPL(_Files) {DEFSPORT _sep SAVESTATE DELSTATE _sep PERMS PRINTCMD
+                         PAPERSIZE}
     set OPTTYPE(DEFSPORT) any
 } else {
-    set OPTGRPL(_Files) {SAVESTATE DELSTATE _sep PERMS PAPERSIZE}
+    set OPTGRPL(_Files) {SAVESTATE DELSTATE _sep PERMS PRINTCMD PAPERSIZE}
 }
 set OPTTYPE(SAVESTATE) oneof
 set OPTVALS(SAVESTATE) {never ask always}
 set OPTTYPE(DELSTATE) oneof
 set OPTVALS(DELSTATE) {never ask always}
 set OPTTYPE(PERMS) perms
+set OPTTYPE(PRINTCMD) any_empty
 set OPTTYPE(PAPERSIZE) fixedmenu
 set OPTMENUCONTS(PAPERSIZE) [array names PAGEWIDTH]
 
@@ -201,7 +220,7 @@ proc OutDatedOptions {} {
     # check if options read from preferences file are outdated
     global OPTFILEVERSION VERSION MESS GPSREC MWINDOWSCONF
 
-    if { [catch "set OPTFILEVERSION"] } {
+    if { [catch {set OPTFILEVERSION}] } {
 	# this is a pre-4.0 preferences file
 	AboutInfo ""
 	GMMessage $MESS(outdatedprefs)
@@ -237,7 +256,7 @@ proc SetOptions {} {
 
     toplevel $w
     wm protocol $w WM_DELETE_WINDOW { set TempOpts cnc ; set waitopts 0 }
-    wm title $w "GPS Manager: $TXT(options)"
+    wm title $w "$TXT(options)/GPS Manager"
     wm transient $w .
     wm geometry $w +$DPOSX+$DPOSY
     bind $w <Key-Return> { set TempOpts ok ; set waitopts 0 }
@@ -287,9 +306,8 @@ proc SetOptions {} {
 		    set v [lindex $e 1]
 		    global $v
 		    switch $OPTTYPE($v) {
-			nat -
-			float -
-			any {
+			nat -  float -  any -
+			any_empty {
 			    set val [[lindex $e 0] get]
 			    if { [WrongValue $OPTTYPE($v) $val] } {
 				GMMessage "$TXT(wrgval) $TXT(opt$v)"
@@ -300,7 +318,7 @@ proc SetOptions {} {
 		    }
 		}
 		if { $ok } {
-		    if { [catch "set f [open $USEROPTIONS w]"] } {
+		    if { [catch {set f [open $USEROPTIONS w]}] } {
 			GMMessage $MESS(cantwrtopt)
 			destroy $w
 			update idletasks
@@ -350,9 +368,8 @@ proc ShowOption {v ref val type vf es lv} {
 	    if { [set $val] } { $vf.f select }
 	    pack $vf.f -anchor w
 	}
-	nat -
-	float -
-	any {
+	nat -  float -  any -
+	any_empty {
 	    global $v
 	    set OptOld[set lv]($ref) [set $val]
 	    label $vf.l -text $TXT(opt$ref)
@@ -380,7 +397,8 @@ proc ShowOption {v ref val type vf es lv} {
 	menu {
 	    global $v
 	    set OptOld[set lv]($ref) [set $val]
-	    menubutton $vf.mb -text $TXT(opt$ref) -menu $vf.mb.m$ref
+	    menubutton $vf.mb -text $TXT(opt$ref) -relief raised \
+		    -direction below -menu $vf.mb.m$ref
 	    menu $vf.mb.m$ref
 	    set OptMenuVar($vf.mb.m$ref) $ref
 	    $OPTMENUPROC($v) $vf.mb.m$ref ChangeMenuOption
@@ -390,7 +408,8 @@ proc ShowOption {v ref val type vf es lv} {
 	textmenu {
 	    global $v $OPTMENUNAMES($v)
 	    set OptOld[set lv]($ref) [set $val]
-	    menubutton $vf.mb -text $TXT(opt$ref) -menu $vf.mb.m$ref
+	    menubutton $vf.mb -text $TXT(opt$ref) -relief raised \
+		    -direction below -menu $vf.mb.m$ref
 	    set mw $vf.mb.m$ref
 	    menu $mw
 	    set OptMenuVar($mw) $ref
@@ -405,7 +424,8 @@ proc ShowOption {v ref val type vf es lv} {
 	fixedmenu {
 	    global $v
 	    set OptOld[set lv]($ref) [set $val]
-	    menubutton $vf.mb -text $TXT(opt$ref) -menu $vf.mb.m$ref
+	    menubutton $vf.mb -text $TXT(opt$ref) -relief raised \
+		    -direction below -menu $vf.mb.m$ref
 	    menu $vf.mb.m$ref
 	    set OptMenuVar($vf.mb.m$ref) $ref
 	    set mw $vf.mb.m$ref ; set n 0 ; set m 0
@@ -425,7 +445,8 @@ proc ShowOption {v ref val type vf es lv} {
 	fixedtextmenu {
 	    global $v $OPTMENUNAMES($v)
 	    set OptOld[set lv]($ref) [set $val]
-	    menubutton $vf.mb -text $TXT(opt$ref) -menu $vf.mb.m$ref
+	    menubutton $vf.mb -text $TXT(opt$ref) -relief raised \
+		    -direction below -menu $vf.mb.m$ref
 	    set mw $vf.mb.m$ref
 	    menu $mw
 	    set OptMenuVar($mw) $ref
@@ -518,7 +539,7 @@ proc ShowMoreOptions {g} {
 
     toplevel $w
     wm protocol $w WM_DELETE_WINDOW { set TempMOpts cnc ; set waitmopts 0 }
-    wm title $w "GPS Manager: $TXT(options)"
+    wm title $w "$TXT(options)/GPS Manager"
     wm transient $w .opts
     wm geometry $w +$DPOSX+$DPOSY
     bind $w <Key-Return> { set TempMOpts ok ; set waitmopts 0 }
@@ -578,9 +599,8 @@ proc ShowMoreOptions {g} {
 		    set v [lindex $e 1]
 		    global $v
 		    switch $OPTTYPE($v) {
-			nat -
-			float -
-			any {
+			nat -  float -  any -
+			any_empty {
 			    set val [[lindex $e 0] get]
 			    if { [WrongValue $OPTTYPE($v) $val] } {
 				GMMessage "$TXT(wrgval) $TXT(opt$v)"
@@ -613,7 +633,7 @@ proc ShowOptionsArray {a} {
 
     toplevel $w
     wm protocol $w WM_DELETE_WINDOW { set TempAOpts cnc ; set waitaopts 0 }
-    wm title $w "GPS Manager: $TXT(options)"
+    wm title $w "$TXT(options)/GPS Manager"
     wm transient $w .opts
     wm geometry $w +$DPOSX+$DPOSY
     bind $w <Key-Return> { set TempAOpts ok ; set waitaopts 0 }
@@ -672,9 +692,8 @@ proc ShowOptionsArray {a} {
 		    set i [expr 1+[string first , $ref]]
 		    set ix [string range $ref $i end]
 		    switch $OPTELTYPE($a) {
-			nat -
-			float -
-			any {
+			nat -  float -  any -
+			any_empty {
 			    set val [[lindex $e 0] get]
 			    if { [WrongValue $OPTELTYPE($a) $val] } {
 				GMMessage "$TXT(wrgval) $TXT(opt$ref)"
@@ -735,15 +754,16 @@ proc WrongValue {type val} {
 
     switch $type {
 	nat {
-	    if { [catch "set neq [expr $val!=round($val)]"] || \
+	    if { [catch {set neq [expr $val!=round($val)]}] || \
 		    $neq || $val<0 } { return 1 }
 	}
 	float {
-	    if { [catch "set val [expr $val]"] } { return 1 }
+	    if { [catch {set val [expr $val]}] } { return 1 }
 	}
 	any {
 	    if { "$val" == "" } { return 1 }
 	}
+	any_empty { return 0 }
     }
     return 0
 }
@@ -767,7 +787,7 @@ proc GenOption {f v} {
 	}
 	perms {
 	    global $v
-	    if { [catch "set OptPerms(owner,fread,$v)"] } {
+	    if { [catch {set OptPerms(owner,fread,$v)}] } {
 		puts $f "set $v [set $v]"
 	    } else {
 		puts -nonewline $f "set $v 0"
@@ -803,7 +823,7 @@ proc ChooseColour {v ref val bw} {
 
     toplevel $w
     wm protocol $w WM_DELETE_WINDOW { set TempCol cnc ; set waitcopts 0 }
-    wm title $w "GPS Manager: $TXT(options)"
+    wm title $w "$TXT(options)/GPS Manager"
     wm transient $w .opts
     set x [expr $DPOSX+100] ; set y [expr $DPOSY+100]
     wm geometry $w +$x+$y
@@ -830,9 +850,11 @@ proc ChooseColour {v ref val bw} {
 
     set self [frame $w.fr.fr1.sel]
     label $self.lab -text "$TXT(selection):" -anchor sw
-    entry $self.ent -textvariable ChColour -width 16
+    entry $self.ent -width 16
     TextBindings $self.ent
     bind $self.ent <Return> "ColSelChange $w ; break"
+    bind $self.ent <Any-Leave> "ColSelChange $w ; break"
+    $self.ent insert 0 $ChColour
     frame $self.f1 -relief sunken -bd 2
     canvas $self.f1.demo -bd 0 -width 100 -height 15 -bg $ChColour
 
@@ -886,6 +908,8 @@ proc RGBChange {w args} {
 
     set ChColour [DecToColour $ColComp(red) $ColComp(green) $ColComp(blue)]
     $w.fr.fr1.sel.f1.demo configure -bg $ChColour
+    $w.fr.fr1.sel.ent delete 0 end
+    $w.fr.fr1.sel.ent insert 0 $ChColour
     return
 }
 
@@ -895,7 +919,12 @@ proc ColSelChange {w} {
     global ChColour ColComp
 
     if { [set x [ColourToDec [$w.fr.fr1.sel.ent get]]] == -1 } {
-	bell ; return
+	$w.fr.fr1.sel.ent delete 0 end
+	$w.fr.fr1.sel.ent insert 0 $ChColour
+	$w.fr.fr1.sel.f1.demo configure -bg $ChColour
+	update idletasks
+	bell
+	return
     }
     set ChColour [eval DecToColour $x]
     $w.fr.fr1.sel.ent icursor end
@@ -909,51 +938,28 @@ proc ColourToDec {c} {
     # convert name to RGB values
     global RGBNamed SRCDIR WorkDir
 
+    set c [string trim $c " "]
     if { [string first # $c] == 0 } {
-	if {[scan $c "#%c%c%c%c%c%c" h0 h1 h2 h3 h4 h5]!=6 } { return -1 }
-	set b2 0 ; set b1 0 ; set b0 0
-	for { set i 0 } { $i<6 } { incr i } {
-	    set v b[expr int($i/2)]
-	    set $v [expr 16*[set $v]+[HexCharToDec [set h$i]]]
-	}
-    } else {
-	if {! [array exists RGBNamed] } {
-	    set d [pwd] ; cd $WorkDir
-	    source [file join $SRCDIR rgb.tcl]
-	    cd $d
-	}
-	if { "[array names RGBNamed $c]" == "" } { return -1 }
-	scan $RGBNamed($c) "%d %d %d" b0 b1 b2
+	set c [string tolower $c]
+	if {! [regexp \
+		{^#([0-9a-f][0-9a-f])([0-9a-f][0-9a-f])([0-9a-f][0-9a-f])$} \
+		$c x h2 h1 h0] } { return -1 }
+	scan $h2 "%x" b2 ; scan $h1 "%x" b1 ; scan $h0 "%x" b0
+	return [list $b2 $b1 $b0]
     }
-    return "$b0 $b1 $b2"
-}
-
-proc HexCharToDec {x} {
-    # convert hexadecimal character to decimal value
-
-    if { $x < 65 } {
-	return [expr $x-48]
-    } elseif { $x < 97 } {
-	return [expr $x-55]
+    if { ! [array exists RGBNamed] } {
+	set d [pwd] ; cd $WorkDir
+	source [file join $SRCDIR rgb.tcl]
+	cd $d
     }
-    return [expr $x-87]
+    if { "[array names RGBNamed $c]" == "" } { return -1 }
+    return $RGBNamed($c)
 }
 
 proc DecToColour {c2 c1 c0} {
     # convert RGB in decimal-triplet to hexadecimal representation
 
-    set d [expr 65536*$c2+256*$c1+$c0]
-    for { set i 0 } { $i<6 } { incr i } {
-	set h$i [DecToHexChar [expr $d%16]]
-	set d [expr int($d/16)]
-    }
-    return [format "#%c%c%c%c%c%c" $h5 $h4 $h3 $h2 $h1 $h0]
-}
-
-proc DecToHexChar {d} {
-    # convert RGB as decimal integer to hexadecimal representation
-
-    if { $d < 10 } { return [expr $d+48] } else { return [expr $d+87] }
+    return [format "#%06x" [expr 65536*$c2+256*$c1+$c0]]
 }
 
 proc PermsToList {p} {
