@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 1999 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2002 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,235 +17,233 @@
 #      along with this program.
 #
 #  File: rgb.tcl
-#  Last change:  20 April 1998
+#  Last change:  17 May 2002
 #
 
 # information taken from the X-Window file rgb.txt:
 # ! $XConsortium: rgb.txt,v 10.41 94/02/20 18:39:36 rws Exp $
 
 array set RGBNamed {
-	"snow"	        {255 250 250}
-	"ghost white"	{248 248 255}
-	"GhostWhite"	{248 248 255}
-	"white smoke"	{245 245 245}
+	"snow"	        {255 250 250} 
+	"ghost white"	{248 248 255}	"GhostWhite"	{248 248 255}
+	"white smoke"	{245 245 245}	"whitesmoke"	{245 245 245}
 	"WhiteSmoke"	{245 245 245}
 	"gainsboro"	{220 220 220}
-	"floral white"	{255 250 240}
+	"floral white"	{255 250 240}	"floralwhite"	{255 250 240}
 	"FloralWhite"	{255 250 240}
-	"old lace"	{253 245 230}
+	"old lace"	{253 245 230}	"oldlace"	{253 245 230}
 	"OldLace"    	{253 245 230}
 	"linen"   	{250 240 230}
-	"antique white"	{250 235 215}
-	"AntiqueWhite"	{250 235 215}
-	"papaya whip"	{255 239 213}
+	"antique white"	{250 235 215}	"AntiqueWhite"	{250 235 215}
+	"papaya whip"	{255 239 213}	"papayawhip"	{255 239 213}
 	"PapayaWhip"	{255 239 213}
-	"blanched almond"	{255 235 205}
+	"blanched almond"	{255 235 205}	"blanchedalmond" {255 235 205}
 	"BlanchedAlmond"	{255 235 205}
 	"bisque"  	{255 228 196}
-	"peach puff"	{255 218 185}
+	"peach puff"	{255 218 185}	"peachpuff"	{255 218 185}
 	"PeachPuff"	{255 218 185}
-	"navajo white"	{255 222 173}
+	"navajo white"	{255 222 173}	"navajowhite"	{255 222 173}
 	"NavajoWhite"	{255 222 173}
 	"moccasin"	{255 228 181}
 	"cornsilk"	{255 248 220}
 	"ivory"   	{255 255 240}
-	"lemon chiffon"	{255 250 205}
+	"lemon chiffon"	{255 250 205}	"lemonchiffon"	{255 250 205}
 	"LemonChiffon"	{255 250 205}
 	"seashell"	{255 245 238}
 	"honeydew"	{240 255 240}
-	"mint cream"	{245 255 250}
-	"MintCream"	{245 255 250}
+	"mint cream"	{245 255 250}	"MintCream"	{245 255 250}
 	"azure"   	{240 255 255}
-	"alice blue"	{240 248 255}
+	"alice blue"	{240 248 255}	"aliceblue"	{240 248 255}
 	"AliceBlue"	{240 248 255}
 	"lavender"	{230 230 250}
 	"lavender blush"	{255 240 245}
-	"LavenderBlush"	{255 240 245}
-	"misty rose"	{255 228 225}
+	"lavenderblush"	{255 240 245}	"LavenderBlush"	{255 240 245}
+	"misty rose"	{255 228 225}	"mistyrose"	{255 228 225}
 	"MistyRose"	{255 228 225}
 	"white"   	{255 255 255}
 	"black"	        {  0   0   0}
-	"dark slate gray"	{ 47  79  79}
+	"dark slate gray"	{ 47  79  79}	"darkslategray"	{ 47  79  79}
 	"DarkSlateGray"	{ 47  79  79}
-	"dark slate grey"	{ 47  79  79}
+	"dark slate grey"	{ 47  79  79}	"darkslategrey"	{ 47  79  79}
 	"DarkSlateGrey"	{ 47  79  79}
-	"dim gray"	{105 105 105}
+	"dim gray"	{105 105 105}	"dimgray"	{105 105 105}
 	"DimGray"  	{105 105 105}
-	"dim grey"	{105 105 105}
+	"dim grey"	{105 105 105}	"dimgrey"	{105 105 105}
 	"DimGrey" 	{105 105 105}
-	"slate gray"	{112 128 144}
+	"slate gray"	{112 128 144}	"slategray"	{112 128 144}
 	"SlateGray"	{112 128 144}
-	"slate grey"	{112 128 144}
+	"slate grey"	{112 128 144}	"slategrey"	{112 128 144}
 	"SlateGrey"	{112 128 144}
-	"light slate gray"	{119 136 153}
+	"light slate gray"	{119 136 153}	"lightslategray" {119 136 153}
 	"LightSlateGray"	{119 136 153}
-	"light slate grey"	{119 136 153}
+	"light slate grey"	{119 136 153}	"lightslategrey" {119 136 153}
 	"LightSlateGrey"	{119 136 153}
 	"gray"	{190 190 190}
 	"grey"	{190 190 190}
-	"light grey"	{211 211 211}
+	"light grey"	{211 211 211}	"lightgrey"	{211 211 211}
 	"LightGrey"	{211 211 211}
-	"light gray"	{211 211 211}
+	"light gray"	{211 211 211}	"lightgray"	{211 211 211}
 	"LightGray"	{211 211 211}
-	"midnight blue"	{ 25  25 112}
+	"midnight blue"	{ 25  25 112}	"midnightblue"	{ 25  25 112}
 	"MidnightBlue"	{ 25  25 112}
 	"navy"    	{  0   0 128}
-	"navy blue"	{  0   0 128}
+	"navy blue"	{  0   0 128}	"navyblue"	{  0   0 128}
 	"NavyBlue"	{  0   0 128}
-	"cornflower blue"	{100 149 237}
+	"cornflower blue"	{100 149 237}	"cornflowerblue" {100 149 237}
 	"CornflowerBlue"	{100 149 237}
-	"dark slate blue"	{ 72  61 139}
+	"dark slate blue"	{ 72  61 139}	"darkslateblue"	{ 72  61 139}
 	"DarkSlateBlue"	{ 72  61 139}
-	"slate blue"	{106  90 205}
+	"slate blue"	{106  90 205}	"slateblue"	{106  90 205}
 	"SlateBlue"	{106  90 205}
-	"medium slate blue"	{123 104 238}
+	"medium slate blue"	{123 104 238}	"mediumslateblue" {123 104 238}
 	"MediumSlateBlue"	{123 104 238}
-	"light slate blue"	{132 112 255}
+	"light slate blue"	{132 112 255}	"lightslateblue" {132 112 255}
 	"LightSlateBlue"	{132 112 255}
-	"medium blue"	{  0   0 205}
+	"medium blue"	{  0   0 205}	"mediumblue"	{  0   0 205}
 	"MediumBlue"	{  0   0 205}
-	"royal blue"	{ 65 105 225}
+	"royal blue"	{ 65 105 225}	"royalblue"	{ 65 105 225}
 	"RoyalBlue"	{ 65 105 225}
 	"blue"	{  0   0 255}
-	"dodger blue"	{ 30 144 255}
+	"dodger blue"	{ 30 144 255}	"dodgerblue"	{ 30 144 255}
 	"DodgerBlue"	{ 30 144 255}
-	"deep sky blue"	{  0 191 255}
+	"deep sky blue"	{  0 191 255}	"deepskyblue"	{  0 191 255}
 	"DeepSkyBlue"	{  0 191 255}
-	"sky blue"	{135 206 235}
+	"sky blue"	{135 206 235}	"skyblue"	{135 206 235}
 	"SkyBlue"	{135 206 235}
-	"light sky blue"	{135 206 250}
+	"light sky blue"	{135 206 250}	"lightskyblue"	{135 206 250}
 	"LightSkyBlue"	{135 206 250}
-	"steel blue"	{ 70 130 180}
+	"steel  blue"	{ 70 130 180}	"steelblue"	{ 70 130 180}
 	"SteelBlue"	{ 70 130 180}
-	"light steel blue"	{176 196 222}
+	"light steel blue"	{176 196 222}	"lightsteelblue" {176 196 222}
 	"LightSteelBlue"	{176 196 222}
-	"light blue"	{173 216 230}
+	"light blue"	{173 216 230}	"lightblue"	{173 216 230}
 	"LightBlue"	{173 216 230}
-	"powder blue"	{176 224 230}
+	"powder blue"	{176 224 230}	"powderblue"	{176 224 230}
 	"PowderBlue"	{176 224 230}
-	"pale turquoise"	{175 238 238}
+	"pale turquoise"	{175 238 238}	"paleturquoise"	{175 238 238}
 	"PaleTurquoise"	{175 238 238}
-	"dark turquoise"	{  0 206 209}
+	"dark turquoise"	{  0 206 209}	"darkturquoise"	{  0 206 209}
 	"DarkTurquoise"	{  0 206 209}
-	"medium turquoise"	{ 72 209 204}
+	"medium turquoise"	{ 72 209 204}	"mediumturquoise" { 72 209 204}
 	"MediumTurquoise"	{ 72 209 204}
 	"turquoise"	{ 64 224 208}
 	"cyan"	{  0 255 255}
-	"light cyan"	{224 255 255}
+	"light cyan"	{224 255 255}	"lightcyan"	{224 255 255}
 	"LightCyan"	{224 255 255}
-	"cadet blue"	{ 95 158 160}
+	"cadet blue"	{ 95 158 160}	"cadetblue"	{ 95 158 160}
 	"CadetBlue"	{ 95 158 160}
-	"medium aquamarine"	{102 205 170}
+	"medium aquamarine" {102 205 170} "mediumaquamarine" {102 205 170}
 	"MediumAquamarine"	{102 205 170}
 	"aquamarine"	{127 255 212}
-	"dark green"	{  0 100   0}
+	"dark green"	{  0 100   0}	"darkgreen"	{  0 100   0}
 	"DarkGreen"	{  0 100   0}
-	"dark olive green"	{ 85 107  47}
+	"dark olive green"	{ 85 107  47}	"darkolivegreen" { 85 107  47}
 	"DarkOliveGreen"	{ 85 107  47}
-	"dark sea green"	{143 188 143}
+	"dark sea green"	{143 188 143}	"darkseagreen"	{143 188 143}
 	"DarkSeaGreen"	{143 188 143}
-	"sea green"	{ 46 139  87}
+	"sea green"	{ 46 139  87}	"seagreen"	{ 46 139  87}
 	"SeaGreen"	{ 46 139  87}
-	"medium sea green"	{ 60 179 113}
+	"medium sea green"	{ 60 179 113}	"mediumseagreen" { 60 179 113}
 	"MediumSeaGreen"	{ 60 179 113}
-	"light sea green"	{ 32 178 170}
+	"light sea green"	{ 32 178 170}	"lightseagreen"	{ 32 178 170}
 	"LightSeaGreen"	{ 32 178 170}
-	"pale green"	{152 251 152}
+	"pale green"	{152 251 152}	"palegreen"	{152 251 152}
 	"PaleGreen"	{152 251 152}
-	"spring green"	{  0 255 127}
+	"spring green"	{  0 255 127}	"springgreen"	{  0 255 127}
 	"SpringGreen"	{  0 255 127}
-	"lawn green"	{124 252   0}
+	"lawn green"	{124 252   0}	"lawngreen"	{124 252   0}
 	"LawnGreen"	{124 252   0}
 	"green"	{  0 255   0}
 	"chartreuse"	{127 255   0}
-	"medium spring green"	{  0 250 154}
+	"medium spring green" {  0 250 154} "mediumspringgreen" {  0 250 154}
 	"MediumSpringGreen"	{  0 250 154}
-	"green yellow"	{173 255  47}
+	"green yellow"	{173 255  47}	"greenyellow"	{173 255  47}
 	"GreenYellow"	{173 255  47}
-	"lime green"	{ 50 205  50}
+	"lime green"	{ 50 205  50}	"limegreen"	{ 50 205  50}
 	"LimeGreen"	{ 50 205  50}
-	"yellow green"	{154 205  50}
+	"yellow green"	{154 205  50}	"yellowgreen"	{154 205  50}
 	"YellowGreen"	{154 205  50}
-	"forest green"	{ 34 139  34}
+	"forest green"	{ 34 139  34}	"forestgreen"	{ 34 139  34}
 	"ForestGreen"	{ 34 139  34}
-	"olive drab"	{107 142  35}
+	"olive drab"	{107 142  35}	"olivedrab"	{107 142  35}
 	"OliveDrab"	{107 142  35}
-	"dark khaki"	{189 183 107}
+	"dark khaki"	{189 183 107}	"darkkhaki"	{189 183 107}
 	"DarkKhaki"	{189 183 107}
 	"khaki"	{240 230 140}
-	"pale goldenrod"	{238 232 170}
+	"pale goldenrod"	{238 232 170}	"palegoldenrod"	{238 232 170}
 	"PaleGoldenrod"	{238 232 170}
 	"light goldenrod yellow"	{250 250 210}
+	"lightgoldenrodyellow"	{250 250 210}
 	"LightGoldenrodYellow"	{250 250 210}
-	"light yellow"	{255 255 224}
+	"light yellow"	{255 255 224}	"lightyellow"	{255 255 224}
 	"LightYellow"	{255 255 224}
 	"yellow"	{255 255   0}
-	"	gold"	{255 215   0}
-	"light goldenrod"	{238 221 130}
+	"gold"  	{255 215   0}
+	"light goldenrod"	{238 221 130}	"lightgoldenrod" {238 221 130}
 	"LightGoldenrod"	{238 221 130}
 	"goldenrod"	{218 165  32}
-	"dark goldenrod"	{184 134  11}
+	"dark goldenrod"	{184 134  11}	"darkgoldenrod"	{184 134  11}
 	"DarkGoldenrod"	{184 134  11}
-	"rosy brown"	{188 143 143}
+	"rosy brown"	{188 143 143}	"rosybrown"	{188 143 143}
 	"RosyBrown"	{188 143 143}
-	"indian red"	{205  92  92}
+	"indian red"	{205  92  92}	"indianred"	{205  92  92}
 	"IndianRed"	{205  92  92}
-	"saddle brown"	{139  69  19}
+	"saddle brown"	{139  69  19}	"saddlebrown"	{139  69  19}
 	"SaddleBrown"	{139  69  19}
 	"sienna"	{160  82  45}
 	"peru"	{205 133  63}
 	"burlywood"	{222 184 135}
 	"beige"	{245 245 220}
 	"wheat"	{245 222 179}
-	"sandy brown"	{244 164  96}
+	"sandy brown"	{244 164  96}	"sandybrown"	{244 164  96}
 	"SandyBrown"	{244 164  96}
 	"tan"	{210 180 140}
 	"chocolate"	{210 105  30}
 	"firebrick"	{178  34  34}
 	"brown"	{165  42  42}
-	"dark salmon"	{233 150 122}
+	"dark salmon"	{233 150 122}	"darksalmon"	{233 150 122}
 	"DarkSalmon"	{233 150 122}
 	"salmon"	{250 128 114}
-	"light salmon"	{255 160 122}
+	"light salmon"	{255 160 122}	"lightsalmon"	{255 160 122}
 	"LightSalmon"	{255 160 122}
 	"orange"	{255 165   0}
-	"dark orange"	{255 140   0}
+	"dark orange"	{255 140   0}	"darkorange"	{255 140   0}
 	"DarkOrange"	{255 140   0}
 	"coral"	{255 127  80}
-	"light coral"	{240 128 128}
+	"light coral"	{240 128 128}	"lightcoral"	{240 128 128}
 	"LightCoral"	{240 128 128}
 	"tomato"	{255  99  71}
-	"orange red"	{255  69   0}
+	"orange red"	{255  69   0}	"orangered"	{255  69   0}
 	"OrangeRed"	{255  69   0}
 	"red"	{255   0   0}
-	"hot pink"	{255 105 180}
+	"hot pink"	{255 105 180}	"hotpink"	{255 105 180}
 	"HotPink"	{255 105 180}
-	"deep pink"	{255  20 147}
+	"deep pink"	{255  20 147}	"deeppink"	{255  20 147}
 	"DeepPink"	{255  20 147}
 	"pink"	{255 192 203}
-	"light pink"	{255 182 193}
+	"light pink"	{255 182 193}	"lightpink"	{255 182 193}
 	"LightPink"	{255 182 193}
-	"pale violet red"	{219 112 147}
+	"pale violet red"	{219 112 147}	"palevioletred"	{219 112 147}
 	"PaleVioletRed"	{219 112 147}
 	"maroon"	{176  48  96}
-	"medium violet red"	{199  21 133}
+	"medium violet red"	{199  21 133}	"mediumvioletred" {199  21 133}
 	"MediumVioletRed"	{199  21 133}
-	"violet red"	{208  32 144}
+	"violet red"	{208  32 144}	"violetred"	{208  32 144}
 	"VioletRed"	{208  32 144}
 	"magenta"	{255   0 255}
 	"violet"	{238 130 238}
 	"plum"	{221 160 221}
 	"orchid"	{218 112 214}
-	"medium orchid"	{186  85 211}
+	"medium orchid"	{186  85 211}	"mediumorchid"	{186  85 211}
 	"MediumOrchid"	{186  85 211}
-	"dark orchid"	{153  50 204}
+	"dark orchid"	{153  50 204}	"darkorchid"	{153  50 204}
 	"DarkOrchid"	{153  50 204}
-	"dark violet"	{148   0 211}
+	"dark violet"	{148   0 211}	"darkviolet"	{148   0 211}
 	"DarkViolet"	{148   0 211}
-	"blue violet"	{138  43 226}
+	"blue violet"	{138  43 226}	"blueviolet"	{138  43 226}
 	"BlueViolet"	{138  43 226}
 	"purple"	{160  32 240}
-	"medium purple"	{147 112 219}
+	"medium purple"	{147 112 219}	"mediumpurple"	{147 112 219}
 	"MediumPurple"	{147 112 219}
 	"thistle"	{216 191 216}
 	"snow1"	{255 250 250}
@@ -762,18 +760,18 @@ array set RGBNamed {
 	"grey99"	{252 252 252}
 	"gray100"	{255 255 255}
 	"grey100"	{255 255 255}
-	"dark grey"	{169 169 169}
+	"dark grey"	{169 169 169}	"darkgrey"	{169 169 169}
 	"DarkGrey"	{169 169 169}
-	"dark gray"	{169 169 169}
+	"dark gray"	{169 169 169}	"darkgray"	{169 169 169}
 	"DarkGray"	{169 169 169}
-	"dark blue"	{0     0 139}
+	"dark blue"	{0     0 139}	"darkblue"	{0     0 139}
 	"DarkBlue"	{0     0 139}
-	"dark cyan"	{0   139 139}
+	"dark cyan"	{0   139 139}	"darkcyan"	{0   139 139}
 	"DarkCyan"	{0   139 139}
-	"dark magenta"	{139   0 139}
+	"dark magenta"	{139   0 139}	"darkmagenta"	{139   0 139}
 	"DarkMagenta"	{139   0 139}
-	"dark red"	{139   0   0}
+	"dark red"	{139   0   0}	"darkred"	{139   0   0}
 	"DarkRed"	{139   0   0}
-	"light green"	{144 238 144}
+	"light green"	{144 238 144}	"lightgreen"	{144 238 144}
 	"LightGreen"	{144 238 144}
-}
\ No newline at end of file
+}
