@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2001 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2003 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: search.tcl
-#  Last change:  24 June 2001
+#  Last change:  4 February 2003
 #
 
 proc Search {} {
@@ -39,7 +39,7 @@ proc Search {} {
 
     toplevel $w
     wm protocol $w WM_DELETE_WINDOW "set TempSearch cnc ; set waitsearch 0"
-    wm title $w "GPS Manager: $TXT(search)"
+    wm title $w "$TXT(search)/GPS Manager"
     wm transient $w .
     wm geometry $w +$DPOSX+$DPOSY
     bind $w <Key-Return> "set TempSearch ok ; set waitsearch 0"
@@ -503,7 +503,8 @@ proc SearchForAny {ids ixs wh} {
 		set ixs [SearchFilter WPCommt $ixs $SearchPattern(cmmt)]
 	    }
 	    if { $SearchSpec(symbol) } {
-		# this is safe only if symbol names are alpha-numeric
+		# this is safe only if symbol names have no meta-chars
+		#  used in "string match"
 		set ixs [SearchFilter WPSymbol $ixs $SearchWPSymbol]
 	    }
 	    if { $SearchSpec(dist) } {
@@ -703,24 +704,8 @@ proc SearchToggle {wh} {
 proc SearchChangeDatum {datum args} {
     # change datum of search window
     #  $args is not used but is needed as this is called-back from a menu
-    global SDatum INVTXT MESS
 
-    set w .gmsearch.fr.fWPTR.dist.wpp.p.p
-    if { "$SDatum" == "$datum" } { return }
-    set op [PosnGetCheck $w.frp $SDatum Ignore nil]
-    set pformt $INVTXT([$w.frp.pfmt cget -text])
-    if { "[set pt [PosType $pformt]]" == "grid" && \
-	    "[set gdatum [GridDatum $pformt]]" != "" && \
-	    "$datum" != "$gdatum" } {
-	GMMessage [format $MESS(cantchggriddatum) $gdatum]
-	return
-    }
-    if { "$op" != "nil" } {
-	set np [ConvertDatum [lindex $op 0] [lindex $op 1] \
-		$SDatum $datum $pformt]
-	RevertPos $w.frp $pformt $pt "$np"
-    }
-    set SDatum $datum
+    ChangeDatum $datum SDatum nil .gmsearch.fr.fWPTR.dist.wpp.p.p.frp
     return
 }
 
