@@ -1,11 +1,11 @@
 #!/bin/sh
-# This is a Tcl/Tk script to be interpreted by wish (Tk8.2 or better): \
+# This is a Tcl/Tk script to be interpreted by wish (Tk8.3 or better): \
 exec wish8.3 "$0" "$@"
 
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2002 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1998-2003 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -22,32 +22,53 @@ exec wish8.3 "$0" "$@"
 #
 ## Incorporates contributions by
 #  - Brian Baulch (baulchb@onthenet.com.au)
-#      Copyright (c) 1999-2000 by Brian Baulch
+#      Copyright (c) 2002 by Brian Baulch
 #      that allow for the support of Lowrance receivers
 #  - Alessandro Palmas (alpalmas@tin.it)
-#      Copyright (c) 2001 by Alessandro Palmas
-#      that implement elevation graph for tracks and routes
+#      Copyright (c) 2003 by Alessandro Palmas
+#      that implement 2D and 3D elevation graphs for tracks and routes
+#  - Matt Martin (matt.martin@ieee.org)
+#      Copyright (c) 2003 by Matt Martin
+#      implementing the support of Magellan receivers
+#  - Stefan Heinen (stefan.heinen@djh-freeweb.de)
+#      Copyright (c) 2002 by Stefan Heinen
+#      allowing for better usage under non-Unix-like systems
+#  - Valere Robin (valere.robin@wanadoo.fr)
+#      Copyright (c) 2003 by Valere Robin
+#      implementing importation of EasyGPS waypoint files
 ##
 #
-## German language support by Andreas Lange (andreas.lange@rhein-main.de)
-#      Copyright (c) 2002 by Andreas Lange
+## German language support:
+#      before version 6.0: by Andreas Lange (Andreas.C.Lange@GMX.de)
+#       Copyright (c) 2002 by Andreas Lange
+#      version 6.0: by Sabine Broda (sbb@ncc.up.pt) Copyright (c) 2003
+#       by Sabine Broda
 ##
 #
 ## Italian language support by Alessandro Palmas (alpalmas@tin.it)
-#      Copyright (c) 2002 by Alessandro Palmas
+#      Copyright (c) 2003 by Alessandro Palmas
 ##
 #
-## French language support by Valere Robin (valere.robin@wanadoo.fr)
-#      Copyright (c) 2002 by Valere Robin
+## French language support by Valere Robin
+#      (valere.robin@wanadoo.fr) Copyright (c) 2003 by Valere Robin
 ##
 #
 ## Dutch language support by Rob Buitenhuis (rob@buitenhs.demon.nl)
-#      Copyright (c) 2002 by Rob Buitenhuis
+#      Copyright (c) 2003 by Rob Buitenhuis
 ##
 #
-## Includes a translation of a Perl script by Niki Hammler
-#      (http://www.nobaq.net)
-#      that converts exported FUGAWI data to DDD GPSman data
+## Indonesian language support by Tri Agus Prayitno; (acuss@bk.or.id)
+#      Copyright (c) 2003 by Tri Agus Prayitno
+##
+#
+## Includes:
+#      - a translation of a Perl script by Niki Hammler
+#      (http://www.nobaq.net) that converts exported FUGAWI data to DDD
+#      GPSman data
+#
+#      - an adaptation of the script "mg2gpsman.tcl" by Heiko Thede
+#      (Heiko.Thede@gmx.de) that converts exported Map&Guide data to
+#      GPSman data
 ##
 #
 ## Some algorithms, formulae and geodetic information taken or adopted from
@@ -70,19 +91,38 @@ exec wish8.3 "$0" "$@"
 #  Guidance Note Number 7, European Petroleum Survey Group
 #      Revised November 1999
 #  Kenneth Foote pages, Department of Geography, The University of
-#    Colorado at Boulder
-#    http://www.colorado.edu/geography/gcraft/notes/datum/edlist.html
+#      Colorado at Boulder
+#      http://www.colorado.edu/geography/gcraft/notes/datum/edlist.html
 #  geotrans - an open source coordinate transformation tool from the
-#    USA National Imagery and Mapping Agency (NIMA)
-#    http://www.remotesensing.org
+#      USA National Imagery and Mapping Agency (NIMA)
+#      http://www.remotesensing.org
 #  Computation of area of spherical polygon adapted from sph_poly.c in
-#   "Graphics Gems IV", edited by Paul Heckbert, Academic Press, 1994.
+#      "Graphics Gems IV", edited by Paul Heckbert, Academic Press, 1994.
 #  Formula for ellipsoid radius from
-#   "Ellipsoidal Area Computations of Large Terrestrial Objects"
-#   by Hrvoje Lukatela
-#   http://www.geodyssey.com/papers/ggelare.html
+#      "Ellipsoidal Area Computations of Large Terrestrial Objects"
+#      by Hrvoje Lukatela
+#      http://www.geodyssey.com/papers/ggelare.html
+#  "Formulas and constants for the calculation of the Swiss conformal
+#      cylindrical projection and for the transformation between coordinate
+#      systems", September 2001
+#      http://www.swisstopo.ch/pub/data/geo/refsyse.pdf
+#  "Het stelsel van de Rijksdriehoeksmeting en het European Terrestrial
+#      Reference System 1989", September 2000 (containing formulas and
+#      constants for the Schreiber projection and the RD grid, used in
+#      The Netherlands; partial English translation kindly provided by
+#      Rob Buitenhuis, rob@buitenhs.demon.nl)
+#      http://www.rdnap.nl
+#
+# look for these notices in the corresponding files
+##
+#
+## This program uses the following Tcl libraries if they are installed:
+#    - Img, written by Jan Nijtmans
+#      http://www.xs4all.nl/~nijtmans/img.html
+#      and available as a Debian package under the name libtk-img
+#    - gpsmanshp, written by Miguel Filgueiras
+#      http://www.ncc.up.pt/gpsmanshp
 #
-# look for this notice in the corresponding files
 ##
 #
 ## Some formulae and geodetic information kindly provided by
@@ -98,7 +138,7 @@ exec wish8.3 "$0" "$@"
 ##
 #
 #  File: gpsman.tcl
-#  Last change:  1 February 2002
+#  Last change:  19 March 2003
 #
 
 ############ configuration parameters
@@ -112,16 +152,26 @@ exec wish8.3 "$0" "$@"
 
 switch $tcl_platform(platform) {
     unix {
+	set UNIX 1
 	# on Unix systems the path may be passed as an argument
-	set SERIALPORT [lindex $argv 0]
+	if { [llength $argv] < 2 } {
+	    set SERIALPORT [lindex $argv 0]
+	    set CMDLINE 0
+	} else {
+	    set SERIALPORT ""
+	    set CMDLINE 1
+	}
 	# otherwise the default is
 	set DEFSPORT /dev/cuaa0
 	# path to directory containing user data
 	set USERDIR ~/.gpsman-dir
 	# name of user preferences file
 	set USEROPTIONS gpsman-options
+	# default print command
+	set PRINTCMD "/usr/bin/lpr"
     }
     default {
+	set UNIX 0 ; set CMDLINE 0
 	# on Apple Macintoshes the serial port cannot be used under Tcl/Tk
 	# on MS-Windows it could be as follows
 	set SERIALPORT com2:
@@ -129,6 +179,8 @@ switch $tcl_platform(platform) {
 	set USERDIR gpmandir
 	# name of user preferences file
 	set USEROPTIONS gpmanopt
+	# default print command
+	set PRINTCMD ""
     }
 }
 
@@ -153,13 +205,26 @@ set DELETE 1
 set MWINDOWSCONF map
 
  # GPS receiver trade mark and model (if applicable): give trade mark
- #   (one of: Garmin, Lowrance) followed by model name.
+ #   (one of: Garmin, Lowrance, Magellan) followed by model name.
  #   See file recmodels.tcl for list of known models
 
 set GPSREC "Garmin"
 
+ # default baud rate for serial port
+switch $GPSREC {
+    Garmin {
+	set SERIALBAUD 9600
+    }
+    Magellan {
+	set SERIALBAUD 115200
+    }
+}
+
  # GPS receiver dependent values (set to Garmin GPS II)
 
+       # accept all characters in names/comments; this may be risky!
+set ACCEPTALLCHARS 0
+
 set NAMELENGTH 6
 set COMMENTLENGTH 16
 set MAXWPOINTS 250
@@ -177,6 +242,10 @@ set DEFAULTSYMBOL WP_dot
     #  and symbol display options (GPSMan convention; see symbols.tcl)
 set DEFAULTDISPOPT s_name
 
+  # default line widths for routes and tracks
+set DEFTRTWIDTH 2
+set DEFTTRWIDTH 2
+
   # count to show number of track point on map; 0 means no numbers shown
 set TRNUMBERINTVL 10
 
@@ -207,10 +276,12 @@ set Datum "WGS 84"
          # difference in hours to UTC (must be an integer)
 set TimeOffset 1
 
-         # possible date formats: YYYYMMDD  (1998.03.20 09:35:23),
+         # possible date and time formats:
+         #                        YYYYMMDD  (1998.03.20 09:35:23),
          #                        YYYY-MM-DD  (1998-03-20 09:35:23),
          #                        MMDDYYYY  (03/20/1998 09:35:23),
          #                        DDMMMYYYY (20-Mar-1998 09:35:23)
+         #                        YYYY/MM/DD (1998/03/20-09:35:23)
 set DateFormat DDMMMYYYY
 
   # formulae: either more accurate or faster
@@ -233,6 +304,10 @@ set MAPSCLENGTH 300
          #      else: 150, 300, 600, 2400 ft/$MAPSCLENGTH pixel
          # actual distance and unit (from the values above) for the scale arrow
 set MAPSCALE "4 km"
+  # map font size in points or "Tcl/Tk" for the default of Tcl/Tk
+set MAPFONTSIZE Tcl/Tk
+  # travel/navigation font size in points or "Tcl/Tk" for the default of Tcl/Tk
+set TRAVELFONTSIZE 12
 
   # menus
 set MAXMENUITEMS 20
@@ -245,7 +320,7 @@ set LISTHEIGHT 22
      # lists window
 set LPOSX 40 ; set LPOSY 25
      # map window
-set MPOSX 5 ; set MPOSY 40
+set MPOSX 5 ; set MPOSY 0
      # receiver window
 set RPOSX 10 ; set RPOSY 250
      # errors, messages, warnings
@@ -299,6 +374,21 @@ set MAPCOLOUR(emptygrid) white
 set MAPCOLOUR(selemptygrid) "#ffe080"
 set MAPCOLOUR(fullgrid) "#00d8d8"
 set MAPCOLOUR(selfullgrid) "#ffd8d8"
+       # travel/navigation
+       # TRK arrow
+set MAPCOLOUR(trvtrk) "#ffcc00"
+       # vertical speed arrows
+set MAPCOLOUR(trvvel_z) "#ffcc00"
+       # TRN arrows
+set MAPCOLOUR(trvtrn)  red
+       # CTS arrow
+set MAPCOLOUR(trvcts)  red
+       # 2nd CTS arrow
+set MAPCOLOUR(trvcts2) "#c5fbd5"
+       # warnings
+set MAPCOLOUR(trvwrnimportant) red
+set MAPCOLOUR(trvwrnnormal) blue
+set MAPCOLOUR(trvwrninfo) darkgreen
 
  # save state on exit, one of: never, ask (when quitting), always
 set SAVESTATE ask
@@ -328,14 +418,14 @@ set ALLMONTH(1) "Jan Gen jan"
 set ALLMONTH(2) "Feb Fev feb"
 set ALLMONTH(3) "Mar Mr mrt"
 set ALLMONTH(4) "Apr Abr Avr apr"
-set ALLMONTH(5) "May Mai Mag mei"
+set ALLMONTH(5) "May Mai Mag mei Mei"
 set ALLMONTH(6) "Jun Giu jun"
 set ALLMONTH(7) "Jul Lug jul"
-set ALLMONTH(8) "Aug Ago Aou aug"
+set ALLMONTH(8) "Aug Ago Aou aug Agt"
 set ALLMONTH(9) "Sep Set sep"
 set ALLMONTH(10) "Oct Okt Out Ott okt"
-set ALLMONTH(11) "Nov nov"
-set ALLMONTH(12) "Dec Dez Dic dec"
+set ALLMONTH(11) "Nov nov Nop"
+set ALLMONTH(12) "Dec Dez Dic dec Des"
 
 ###### NO CONFIGURABLE VALUES AFTER THIS LINE ##############################
 
@@ -373,17 +463,54 @@ if { $ISOLATIN1 } { lappend SRCFILESBEGIN isolatin1 }
 set SRCFILESREC "recdefs"
 
 # source files depending on receiver brand
-set SRCFILESFOR(Garmin) "garmin_protocols garmin_symbols garmin_nmea garmin"
-set SRCFILESFOR(Lowrance) "lowrance_symbols lowrance_nmea lowrance"
+set SRCFILESFOR(Garmin) "serial garmin_protocols garmin_symbols \
+	garmin_nmea garmin"
+set SRCFILESFOR(Lowrance) "lowrance_symbols lowrance_nmea lowrance \
+	lowrance_patches"
+# MGM contribution
+set SRCFILESFOR(Magellan) "serial magellan"
 
-# conditional source files
-set SRCFILESCOND [list "ACCFORMULAE acccomp"]
 # other generic source files
-set SRCFILESEND "wrtdials search lists files gpsinfo \
-	maptransf map mapanim realtime know trtort gdata cluster"
+set SRCFILESEND "wrtdials search lists files files_foreign gpsinfo \
+	maptransf map mapanim realtime know trtort gdata cluster \
+	elevation navigate"
+# conditional source files
+set SRCFILESCOND [list "ACCFORMULAE acccomp" "CMDLINE command"]
+
+if { $tcl_version == 8.4 } {
+    # Tk8.4 is incompatible with Img < 1.3
+    set NoImgLib [catch {package require Img 1.3}]
+} else { set NoImgLib  [catch {package require Img}] }
+
+set NoGSHP [catch {package require gpsmanshp}]
+
+#####
+
+if { $CMDLINE } {
+    source [file join $SRCDIR command_parse.tcl]
+    if { [BadCommandLine] } { exit 1 }
+    if { $COMMAND(prefsfile) != "" } { source $COMMAND(prefsfile) }
+}
 
 source [file join $SRCDIR main.tcl]
 
-GMStart
-GMInit
+##### execution
+
+if { $CMDLINE } {
+    ShowGPSMan
+    set  CmdClock [clock seconds]
+    GMStart
+    if { [set r [ExecCommand]] != "wait" } {
+	if { $r == 0 && \
+		[set d [expr 100*(6-[clock seconds]+$CmdClock)]] > 0 } {
+	    after $d
+	}
+	exit $r
+    }
+} else {
+    # normal use: initialize and launch graphical interface
+    GMStart
+    GMInit
+}
+
 
