@@ -4,14 +4,14 @@ exec wish "$0" "$@"
 
 #  mb2gmn --- convert MapBlast files into GPSManager files
 #
-#  Copyright (c) 2002 Martin Ostermann (ost@brainaid.dascon.de) and
+#  Copyright (c) 2003 Martin Ostermann (ost@brainaid.dascon.de) and
 #                     Miguel Filgueiras (mig@ncc.up.pt)
 #
 #  To be used with the source of
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2002 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2003 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@ exec wish "$0" "$@"
 #
 #
 #  File: mb2gmn.tcl
-#  Last change:  31 January 2002
+#  Last change:  20 February 2003
 #
 
 ############ configuration parameters
@@ -105,6 +105,8 @@ set RTCount 0
 
 set WindowStack ""
 
+set UNIX [expr ! [string compare $tcl_platform(platform) "unix"]]
+
 ### conversion
 
 proc MapBlastToGPSMan {infile outfile} {
